Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryStatusReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Status data for battery. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDevicePowerStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_BATTERY_REPORT

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1BatteryStatusReport

Returns a new instance of GoogleChromeManagementV1BatteryStatusReport.



511
512
513
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#battery_healthString

Output only. Battery health. Corresponds to the JSON property batteryHealth

Returns:

  • (String)


483
484
485
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 483

def battery_health
  @battery_health
end

#cycle_countFixnum

Output only. Cycle count. Corresponds to the JSON property cycleCount

Returns:

  • (Fixnum)


488
489
490
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 488

def cycle_count
  @cycle_count
end

#full_charge_capacityFixnum

Output only. Full charge capacity (mAmpere-hours). Corresponds to the JSON property fullChargeCapacity

Returns:

  • (Fixnum)


493
494
495
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 493

def full_charge_capacity
  @full_charge_capacity
end

#report_timeString

Output only. Timestamp of when the sample was collected on device Corresponds to the JSON property reportTime

Returns:

  • (String)


498
499
500
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 498

def report_time
  @report_time
end

#sampleArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatterySampleReport>

Output only. Sampling data for the battery sorted in a decreasing order of report_time. Corresponds to the JSON property sample



504
505
506
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 504

def sample
  @sample
end

#serial_numberString

Output only. Battery serial number. Corresponds to the JSON property serialNumber

Returns:

  • (String)


509
510
511
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 509

def serial_number
  @serial_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



516
517
518
519
520
521
522
523
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 516

def update!(**args)
  @battery_health = args[:battery_health] if args.key?(:battery_health)
  @cycle_count = args[:cycle_count] if args.key?(:cycle_count)
  @full_charge_capacity = args[:full_charge_capacity] if args.key?(:full_charge_capacity)
  @report_time = args[:report_time] if args.key?(:report_time)
  @sample = args[:sample] if args.key?(:sample)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
end