Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BootPerformanceReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Boot performance report of a device. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDeviceBootMode * Data Collection Frequency: On every boot up event * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_OS_REPORT

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1BootPerformanceReport

Returns a new instance of GoogleChromeManagementV1BootPerformanceReport.



567
568
569
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boot_up_durationString

Total time to boot up. Corresponds to the JSON property bootUpDuration

Returns:

  • (String)


540
541
542
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 540

def boot_up_duration
  @boot_up_duration
end

#boot_up_timeString

The timestamp when power came on. Corresponds to the JSON property bootUpTime

Returns:

  • (String)


545
546
547
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 545

def boot_up_time
  @boot_up_time
end

#report_timeString

Timestamp when the report was collected. Corresponds to the JSON property reportTime

Returns:

  • (String)


550
551
552
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 550

def report_time
  @report_time
end

#shutdown_durationString

Total time since shutdown start to power off. Corresponds to the JSON property shutdownDuration

Returns:

  • (String)


555
556
557
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 555

def shutdown_duration
  @shutdown_duration
end

#shutdown_reasonString

The shutdown reason. Corresponds to the JSON property shutdownReason

Returns:

  • (String)


560
561
562
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 560

def shutdown_reason
  @shutdown_reason
end

#shutdown_timeString

The timestamp when shutdown. Corresponds to the JSON property shutdownTime

Returns:

  • (String)


565
566
567
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 565

def shutdown_time
  @shutdown_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



572
573
574
575
576
577
578
579
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 572

def update!(**args)
  @boot_up_duration = args[:boot_up_duration] if args.key?(:boot_up_duration)
  @boot_up_time = args[:boot_up_time] if args.key?(:boot_up_time)
  @report_time = args[:report_time] if args.key?(:report_time)
  @shutdown_duration = args[:shutdown_duration] if args.key?(:shutdown_duration)
  @shutdown_reason = args[:shutdown_reason] if args.key?(:shutdown_reason)
  @shutdown_time = args[:shutdown_time] if args.key?(:shutdown_time)
end