Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ChromeAppInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Chrome Web Store app information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1ChromeAppInfo

Returns a new instance of GoogleChromeManagementV1ChromeAppInfo.



704
705
706
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_ownedBoolean Also known as: google_owned?

Output only. Whether the app or extension is built and maintained by Google. Version-specific field that will only be set when the requested app version is found. Corresponds to the JSON property googleOwned

Returns:

  • (Boolean)


634
635
636
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 634

def google_owned
  @google_owned
end

#is_cws_hostedBoolean Also known as: is_cws_hosted?

Output only. Whether the app or extension is in a published state in the Chrome Web Store. Corresponds to the JSON property isCwsHosted

Returns:

  • (Boolean)


641
642
643
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 641

def is_cws_hosted
  @is_cws_hosted
end

#is_extension_policy_supportedBoolean Also known as: is_extension_policy_supported?

Output only. Whether an app supports policy for extensions. Corresponds to the JSON property isExtensionPolicySupported

Returns:

  • (Boolean)


647
648
649
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 647

def is_extension_policy_supported
  @is_extension_policy_supported
end

#is_kiosk_onlyBoolean Also known as: is_kiosk_only?

Output only. Whether the app is only for Kiosk mode on ChromeOS devices Corresponds to the JSON property isKioskOnly

Returns:

  • (Boolean)


653
654
655
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 653

def is_kiosk_only
  @is_kiosk_only
end

#is_themeBoolean Also known as: is_theme?

Output only. Whether the app or extension is a theme. Corresponds to the JSON property isTheme

Returns:

  • (Boolean)


659
660
661
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 659

def is_theme
  @is_theme
end

#kiosk_enabledBoolean Also known as: kiosk_enabled?

Output only. Whether this app is enabled for Kiosk mode on ChromeOS devices Corresponds to the JSON property kioskEnabled

Returns:

  • (Boolean)


665
666
667
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 665

def kiosk_enabled
  @kiosk_enabled
end

#manifest_versionFixnum

Output only. The version of this extension's manifest. Corresponds to the JSON property manifestVersion

Returns:

  • (Fixnum)


671
672
673
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 671

def manifest_version
  @manifest_version
end

#min_user_countFixnum

Output only. The minimum number of users using this app. Corresponds to the JSON property minUserCount

Returns:

  • (Fixnum)


676
677
678
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 676

def min_user_count
  @min_user_count
end

#permissionsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ChromeAppPermission>

Output only. Every custom permission requested by the app. Version-specific field that will only be set when the requested app version is found. Corresponds to the JSON property permissions



682
683
684
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 682

def permissions
  @permissions
end

#site_accessArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ChromeAppSiteAccess>

Output only. Every permission giving access to domains or broad host patterns. ( e.g. www.google.com). This includes the matches from content scripts as well as hosts in the permissions node of the manifest. Version-specific field that will only be set when the requested app version is found. Corresponds to the JSON property siteAccess



690
691
692
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 690

def site_access
  @site_access
end

#support_enabledBoolean Also known as: support_enabled?

Output only. The app developer has enabled support for their app. Version- specific field that will only be set when the requested app version is found. Corresponds to the JSON property supportEnabled

Returns:

  • (Boolean)


696
697
698
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 696

def support_enabled
  @support_enabled
end

#typeString

Output only. Types of an item in the Chrome Web Store Corresponds to the JSON property type

Returns:

  • (String)


702
703
704
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 702

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



709
710
711
712
713
714
715
716
717
718
719
720
721
722
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 709

def update!(**args)
  @google_owned = args[:google_owned] if args.key?(:google_owned)
  @is_cws_hosted = args[:is_cws_hosted] if args.key?(:is_cws_hosted)
  @is_extension_policy_supported = args[:is_extension_policy_supported] if args.key?(:is_extension_policy_supported)
  @is_kiosk_only = args[:is_kiosk_only] if args.key?(:is_kiosk_only)
  @is_theme = args[:is_theme] if args.key?(:is_theme)
  @kiosk_enabled = args[:kiosk_enabled] if args.key?(:kiosk_enabled)
  @manifest_version = args[:manifest_version] if args.key?(:manifest_version)
  @min_user_count = args[:min_user_count] if args.key?(:min_user_count)
  @permissions = args[:permissions] if args.key?(:permissions)
  @site_access = args[:site_access] if args.key?(:site_access)
  @support_enabled = args[:support_enabled] if args.key?(:support_enabled)
  @type = args[:type] if args.key?(:type)
end