Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ChromeAppRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Details of an app installation request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1ChromeAppRequest

Returns a new instance of GoogleChromeManagementV1ChromeAppRequest.



800
801
802
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_detailsString

Output only. Format: app_details=customers/customer_id/apps/chrome/app_id Corresponds to the JSON property appDetails

Returns:

  • (String)


766
767
768
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 766

def app_details
  @app_details
end

#app_idString

Output only. Unique store identifier for the app. Example: " gmbmikajjgmnabiglmofipeabaddhgne" for the Save to Google Drive Chrome extension. Corresponds to the JSON property appId

Returns:

  • (String)


773
774
775
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 773

def app_id
  @app_id
end

#detail_uriString

Output only. The uri for the detail page of the item. Corresponds to the JSON property detailUri

Returns:

  • (String)


778
779
780
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 778

def detail_uri
  @detail_uri
end

#display_nameString

Output only. App's display name. Corresponds to the JSON property displayName

Returns:

  • (String)


783
784
785
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 783

def display_name
  @display_name
end

#icon_uriString

Output only. A link to an image that can be used as an icon for the product. Corresponds to the JSON property iconUri

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 788

def icon_uri
  @icon_uri
end

#latest_request_timeString

Output only. The timestamp of the most recently made request for this app. Corresponds to the JSON property latestRequestTime

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 793

def latest_request_time
  @latest_request_time
end

#request_countFixnum

Output only. Total count of requests for this app. Corresponds to the JSON property requestCount

Returns:

  • (Fixnum)


798
799
800
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 798

def request_count
  @request_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



805
806
807
808
809
810
811
812
813
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 805

def update!(**args)
  @app_details = args[:app_details] if args.key?(:app_details)
  @app_id = args[:app_id] if args.key?(:app_id)
  @detail_uri = args[:detail_uri] if args.key?(:detail_uri)
  @display_name = args[:display_name] if args.key?(:display_name)
  @icon_uri = args[:icon_uri] if args.key?(:icon_uri)
  @latest_request_time = args[:latest_request_time] if args.key?(:latest_request_time)
  @request_count = args[:request_count] if args.key?(:request_count)
end