Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountActiveDevicesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing the number of active devices.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1CountActiveDevicesResponse

Returns a new instance of GoogleChromeManagementV1CountActiveDevicesResponse.



852
853
854
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#seven_days_countFixnum

Number of active devices in the 7 days leading up to the date specified in the request. Corresponds to the JSON property sevenDaysCount

Returns:

  • (Fixnum)


844
845
846
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 844

def seven_days_count
  @seven_days_count
end

#thirty_days_countFixnum

Number of active devices in the 30 days leading up to the date specified in the request. Corresponds to the JSON property thirtyDaysCount

Returns:

  • (Fixnum)


850
851
852
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 850

def thirty_days_count
  @thirty_days_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



857
858
859
860
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 857

def update!(**args)
  @seven_days_count = args[:seven_days_count] if args.key?(:seven_days_count)
  @thirty_days_count = args[:thirty_days_count] if args.key?(:thirty_days_count)
end