Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeBrowsersNeedingAttentionResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing counts for browsers that need attention.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeBrowsersNeedingAttentionResponse

Returns a new instance of GoogleChromeManagementV1CountChromeBrowsersNeedingAttentionResponse.



913
914
915
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#no_recent_activity_countFixnum

Number of browsers that haven’t had any recent activity Corresponds to the JSON property noRecentActivityCount

Returns:

  • (Fixnum)


901
902
903
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 901

def no_recent_activity_count
  @no_recent_activity_count
end

#pending_browser_update_countFixnum

Number of browsers that are pending an OS update Corresponds to the JSON property pendingBrowserUpdateCount

Returns:

  • (Fixnum)


906
907
908
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 906

def pending_browser_update_count
  @pending_browser_update_count
end

#recently_enrolled_countFixnum

Number of browsers that have been recently enrolled Corresponds to the JSON property recentlyEnrolledCount

Returns:

  • (Fixnum)


911
912
913
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 911

def recently_enrolled_count
  @recently_enrolled_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



918
919
920
921
922
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 918

def update!(**args)
  @no_recent_activity_count = args[:no_recent_activity_count] if args.key?(:no_recent_activity_count)
  @pending_browser_update_count = args[:pending_browser_update_count] if args.key?(:pending_browser_update_count)
  @recently_enrolled_count = args[:recently_enrolled_count] if args.key?(:recently_enrolled_count)
end