Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeProfileVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeProfileVersionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing requested managed profile versions details and counts.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to specify the next page of the request.
-
#profile_browser_versions ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BrowserVersion>
List of all browser versions reported for profiles and their install counts.
-
#total_size ⇒ Fixnum
Total number browser versions matching request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeProfileVersionsResponse
constructor
A new instance of GoogleChromeManagementV1CountChromeProfileVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeProfileVersionsResponse
Returns a new instance of GoogleChromeManagementV1CountChromeProfileVersionsResponse.
1109 1110 1111 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1109 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to specify the next page of the request.
Corresponds to the JSON property nextPageToken
1097 1098 1099 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1097 def next_page_token @next_page_token end |
#profile_browser_versions ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BrowserVersion>
List of all browser versions reported for profiles and their install counts.
Corresponds to the JSON property profileBrowserVersions
1102 1103 1104 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1102 def profile_browser_versions @profile_browser_versions end |
#total_size ⇒ Fixnum
Total number browser versions matching request.
Corresponds to the JSON property totalSize
1107 1108 1109 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1107 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1114 1115 1116 1117 1118 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1114 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @profile_browser_versions = args[:profile_browser_versions] if args.key?(:profile_browser_versions) @total_size = args[:total_size] if args.key?(:total_size) end |