Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeVersionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeVersionsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing requested browser versions details and counts.
Instance Attribute Summary collapse
-
#browser_versions ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BrowserVersion>
List of all browser versions and their install counts.
-
#next_page_token ⇒ String
Token to specify the next page of the request.
-
#total_size ⇒ Fixnum
Total number browser versions matching request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeVersionsResponse
constructor
A new instance of GoogleChromeManagementV1CountChromeVersionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeVersionsResponse
Returns a new instance of GoogleChromeManagementV1CountChromeVersionsResponse.
1140 1141 1142 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#browser_versions ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BrowserVersion>
List of all browser versions and their install counts.
Corresponds to the JSON property browserVersions
1128 1129 1130 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1128 def browser_versions @browser_versions end |
#next_page_token ⇒ String
Token to specify the next page of the request.
Corresponds to the JSON property nextPageToken
1133 1134 1135 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1133 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
Total number browser versions matching request.
Corresponds to the JSON property totalSize
1138 1139 1140 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1138 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1145 1146 1147 1148 1149 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1145 def update!(**args) @browser_versions = args[:browser_versions] if args.key?(:browser_versions) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) end |