Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountPrintJobsByPrinterResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing a summary printing report for each printer from the specified organizational unit for the requested time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1CountPrintJobsByPrinterResponse

Returns a new instance of GoogleChromeManagementV1CountPrintJobsByPrinterResponse.



1295
1296
1297
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Pagination token for requesting the next page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1283

def next_page_token
  @next_page_token
end

#printer_reportsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport>

List of PrinterReports matching request. Corresponds to the JSON property printerReports



1288
1289
1290
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1288

def printer_reports
  @printer_reports
end

#total_sizeFixnum

Total number of printers matching request. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


1293
1294
1295
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1293

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1300
1301
1302
1303
1304
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1300

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @printer_reports = args[:printer_reports] if args.key?(:printer_reports)
  @total_size = args[:total_size] if args.key?(:total_size)
end