Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountPrintJobsByUserResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing a summary printing report for each user that has initiated a print job with a printer from the specified organizational unit during the requested time interval.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1CountPrintJobsByUserResponse

Returns a new instance of GoogleChromeManagementV1CountPrintJobsByUserResponse.



1328
1329
1330
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Pagination token for requesting the next page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1316
1317
1318
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1316

def next_page_token
  @next_page_token
end

#total_sizeFixnum

Total number of users matching request. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


1321
1322
1323
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1321

def total_size
  @total_size
end

#user_print_reportsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserPrintReport>

List of UserPrintReports matching request. Corresponds to the JSON property userPrintReports



1326
1327
1328
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1326

def user_print_reports
  @user_print_reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1333
1334
1335
1336
1337
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1333

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
  @user_print_reports = args[:user_print_reports] if args.key?(:user_print_reports)
end