Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuInfo
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
CPU specifications for the device * This field provides device information, which is static and will not change over time. * Data for this field is controlled via policy: ReportDeviceCpuInfo * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_CPU_INFO
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#keylocker_configured ⇒ Boolean
(also: #keylocker_configured?)
Output only.
-
#keylocker_supported ⇒ Boolean
(also: #keylocker_supported?)
Output only.
-
#max_clock_speed ⇒ Fixnum
Output only.
-
#model ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CpuInfo
constructor
A new instance of GoogleChromeManagementV1CpuInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CpuInfo
Returns a new instance of GoogleChromeManagementV1CpuInfo.
1387 1388 1389 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. Architecture type for the CPU. * This field provides device
information, which is static and will not change over time. * Data for this
field is controlled via policy: ReportDeviceCpuInfo * Data Collection Frequency: Only at
Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes *
Cache: If the device is offline, the collected data is stored locally, and
will be reported when the device is next online: No * Reported for affiliated
users only: N/A
Corresponds to the JSON property architecture
1361 1362 1363 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1361 def architecture @architecture end |
#keylocker_configured ⇒ Boolean Also known as: keylocker_configured?
Output only. Whether keylocker is configured.TRUE = Enabled; FALSE =
disabled. Only reported if keylockerSupported = TRUE.
Corresponds to the JSON property keylockerConfigured
1367 1368 1369 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1367 def keylocker_configured @keylocker_configured end |
#keylocker_supported ⇒ Boolean Also known as: keylocker_supported?
Output only. Whether keylocker is supported.
Corresponds to the JSON property keylockerSupported
1373 1374 1375 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1373 def keylocker_supported @keylocker_supported end |
#max_clock_speed ⇒ Fixnum
Output only. The max CPU clock speed in kHz.
Corresponds to the JSON property maxClockSpeed
1379 1380 1381 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1379 def max_clock_speed @max_clock_speed end |
#model ⇒ String
Output only. The CPU model name. Example: Intel(R) Core(TM) i5-8250U CPU @ 1.
60GHz
Corresponds to the JSON property model
1385 1386 1387 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1385 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1392 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @keylocker_configured = args[:keylocker_configured] if args.key?(:keylocker_configured) @keylocker_supported = args[:keylocker_supported] if args.key?(:keylocker_supported) @max_clock_speed = args[:max_clock_speed] if args.key?(:max_clock_speed) @model = args[:model] if args.key?(:model) end |