Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuStatusReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuStatusReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Provides information about the status of the CPU. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDeviceCpuInfo * Data Collection Frequency: Every 10 minutes * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_CPU_REPORT
Instance Attribute Summary collapse
-
#cpu_temperature_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuTemperatureInfo>
Output only.
-
#cpu_utilization_pct ⇒ Fixnum
Output only.
-
#report_time ⇒ String
Output only.
-
#sample_frequency ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CpuStatusReport
constructor
A new instance of GoogleChromeManagementV1CpuStatusReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CpuStatusReport
Returns a new instance of GoogleChromeManagementV1CpuStatusReport.
1434 1435 1436 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_temperature_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuTemperatureInfo>
Output only. CPU temperature sample info per CPU core in Celsius
Corresponds to the JSON property cpuTemperatureInfo
1416 1417 1418 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1416 def cpu_temperature_info @cpu_temperature_info end |
#cpu_utilization_pct ⇒ Fixnum
Output only. Sample of CPU utilization (0-100 percent).
Corresponds to the JSON property cpuUtilizationPct
1421 1422 1423 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1421 def cpu_utilization_pct @cpu_utilization_pct end |
#report_time ⇒ String
Output only. The timestamp in milliseconds representing time at which this
report was sampled.
Corresponds to the JSON property reportTime
1427 1428 1429 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1427 def report_time @report_time end |
#sample_frequency ⇒ String
Output only. Frequency the report is sampled.
Corresponds to the JSON property sampleFrequency
1432 1433 1434 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1432 def sample_frequency @sample_frequency end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1439 1440 1441 1442 1443 1444 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1439 def update!(**args) @cpu_temperature_info = args[:cpu_temperature_info] if args.key?(:cpu_temperature_info) @cpu_utilization_pct = args[:cpu_utilization_pct] if args.key?(:cpu_utilization_pct) @report_time = args[:report_time] if args.key?(:report_time) @sample_frequency = args[:sample_frequency] if args.key?(:sample_frequency) end |