Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuTemperatureInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

CPU temperature of a device. Sampled per CPU core in Celsius. * This field is telemetry information and this will change over time as the device is utilized.

  • Data for this field is controlled via policy: ReportDeviceCpuInfo * Data Collection Frequency: Every 10 minutes * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1CpuTemperatureInfo

Returns a new instance of GoogleChromeManagementV1CpuTemperatureInfo.



1437
1438
1439
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelString

Output only. CPU label. Example: Core 0 Corresponds to the JSON property label

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1430

def label
  @label
end

#temperature_celsiusFixnum

Output only. CPU temperature in Celsius. Corresponds to the JSON property temperatureCelsius

Returns:

  • (Fixnum)


1435
1436
1437
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1435

def temperature_celsius
  @temperature_celsius
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1442
1443
1444
1445
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1442

def update!(**args)
  @label = args[:label] if args.key?(:label)
  @temperature_celsius = args[:temperature_celsius] if args.key?(:temperature_celsius)
end