Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceRequestingExtensionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Details of a device requesting an extension, including the name of the device and the justification of the request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1DeviceRequestingExtensionDetails

Returns a new instance of GoogleChromeManagementV1DeviceRequestingExtensionDetails.



1619
1620
1621
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_nameString

The name of a device that has requested the extension. Corresponds to the JSON property deviceName

Returns:

  • (String)


1612
1613
1614
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1612

def device_name
  @device_name
end

#justificationString

Request justification as entered by the user. Corresponds to the JSON property justification

Returns:

  • (String)


1617
1618
1619
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1617

def justification
  @justification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1624
1625
1626
1627
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1624

def update!(**args)
  @device_name = args[:device_name] if args.key?(:device_name)
  @justification = args[:justification] if args.key?(:justification)
end