Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DiskInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Status of the single storage device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1DiskInfo

Returns a new instance of GoogleChromeManagementV1DiskInfo.



1701
1702
1703
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_read_this_sessionFixnum

Output only. Number of bytes read since last boot. Corresponds to the JSON property bytesReadThisSession

Returns:

  • (Fixnum)


1637
1638
1639
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1637

def bytes_read_this_session
  @bytes_read_this_session
end

#bytes_written_this_sessionFixnum

Output only. Number of bytes written since last boot. Corresponds to the JSON property bytesWrittenThisSession

Returns:

  • (Fixnum)


1642
1643
1644
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1642

def bytes_written_this_session
  @bytes_written_this_session
end

#discard_time_this_sessionString

Output only. Time spent discarding since last boot. Discarding is writing to clear blocks which are no longer in use. Supported on kernels 4.18+. Corresponds to the JSON property discardTimeThisSession

Returns:

  • (String)


1648
1649
1650
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1648

def discard_time_this_session
  @discard_time_this_session
end

#healthString

Output only. Disk health. Corresponds to the JSON property health

Returns:

  • (String)


1653
1654
1655
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1653

def health
  @health
end

#io_time_this_sessionString

Output only. Counts the time the disk and queue were busy, so unlike the fields above, parallel requests are not counted multiple times. Corresponds to the JSON property ioTimeThisSession

Returns:

  • (String)


1659
1660
1661
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1659

def io_time_this_session
  @io_time_this_session
end

#manufacturerString

Output only. Disk manufacturer. Corresponds to the JSON property manufacturer

Returns:

  • (String)


1664
1665
1666
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1664

def manufacturer
  @manufacturer
end

#modelString

Output only. Disk model. Corresponds to the JSON property model

Returns:

  • (String)


1669
1670
1671
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1669

def model
  @model
end

#read_time_this_sessionString

Output only. Time spent reading from disk since last boot. Corresponds to the JSON property readTimeThisSession

Returns:

  • (String)


1674
1675
1676
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1674

def read_time_this_session
  @read_time_this_session
end

#serial_numberString

Output only. Disk serial number. Corresponds to the JSON property serialNumber

Returns:

  • (String)


1679
1680
1681
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1679

def serial_number
  @serial_number
end

#size_bytesFixnum

Output only. Disk size. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


1684
1685
1686
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1684

def size_bytes
  @size_bytes
end

#typeString

Output only. Disk type: eMMC / NVMe / ATA / SCSI. Corresponds to the JSON property type

Returns:

  • (String)


1689
1690
1691
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1689

def type
  @type
end

#volume_idsArray<String>

Output only. Disk volumes. Corresponds to the JSON property volumeIds

Returns:

  • (Array<String>)


1694
1695
1696
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1694

def volume_ids
  @volume_ids
end

#write_time_this_sessionString

Output only. Time spent writing to disk since last boot. Corresponds to the JSON property writeTimeThisSession

Returns:

  • (String)


1699
1700
1701
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1699

def write_time_this_session
  @write_time_this_session
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1706

def update!(**args)
  @bytes_read_this_session = args[:bytes_read_this_session] if args.key?(:bytes_read_this_session)
  @bytes_written_this_session = args[:bytes_written_this_session] if args.key?(:bytes_written_this_session)
  @discard_time_this_session = args[:discard_time_this_session] if args.key?(:discard_time_this_session)
  @health = args[:health] if args.key?(:health)
  @io_time_this_session = args[:io_time_this_session] if args.key?(:io_time_this_session)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @model = args[:model] if args.key?(:model)
  @read_time_this_session = args[:read_time_this_session] if args.key?(:read_time_this_session)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @type = args[:type] if args.key?(:type)
  @volume_ids = args[:volume_ids] if args.key?(:volume_ids)
  @write_time_this_session = args[:write_time_this_session] if args.key?(:write_time_this_session)
end