Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1EnumeratePrintJobsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing a list of print jobs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1EnumeratePrintJobsResponse

Returns a new instance of GoogleChromeManagementV1EnumeratePrintJobsResponse.



1873
1874
1875
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be used in a subsequent request to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1861
1862
1863
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1861

def next_page_token
  @next_page_token
end

List of requested print jobs. Corresponds to the JSON property printJobs



1866
1867
1868
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1866

def print_jobs
  @print_jobs
end

#total_sizeFixnum

Total number of print jobs matching request. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


1871
1872
1873
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1871

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1878
1879
1880
1881
1882
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1878

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @print_jobs = args[:print_jobs] if args.key?(:print_jobs)
  @total_size = args[:total_size] if args.key?(:total_size)
end