Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing a list of devices that have requested the queried extension.
Instance Attribute Summary collapse
-
#device_details ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceRequestingExtensionDetails>
Details of devices that have requested the queried extension.
-
#next_page_token ⇒ String
Optional.
-
#total_size ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse
constructor
A new instance of GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse
Returns a new instance of GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse.
1906 1907 1908 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_details ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceRequestingExtensionDetails>
Details of devices that have requested the queried extension.
Corresponds to the JSON property deviceDetails
1893 1894 1895 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1893 def device_details @device_details end |
#next_page_token ⇒ String
Optional. Token to specify the next page in the list. Token expires after 1
day.
Corresponds to the JSON property nextPageToken
1899 1900 1901 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1899 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
Optional. Total number of devices in response.
Corresponds to the JSON property totalSize
1904 1905 1906 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1904 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1911 1912 1913 1914 1915 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1911 def update!(**args) @device_details = args[:device_details] if args.key?(:device_details) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) end |