Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FetchUsersRequestingExtensionResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing a list of users that have requested the queried extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1FetchUsersRequestingExtensionResponse

Returns a new instance of GoogleChromeManagementV1FetchUsersRequestingExtensionResponse.



1937
1938
1939
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to specify the next page in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1925

def next_page_token
  @next_page_token
end

#total_sizeFixnum

Total number of users in response. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


1930
1931
1932
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1930

def total_size
  @total_size
end

#user_detailsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserRequestingExtensionDetails>

Details of users that have requested the queried extension. Corresponds to the JSON property userDetails



1935
1936
1937
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1935

def user_details
  @user_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1942
1943
1944
1945
1946
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1942

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
  @user_details = args[:user_details] if args.key?(:user_details)
end