Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FindInstalledAppDevicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FindInstalledAppDevicesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing a list of devices with queried app installed.
Instance Attribute Summary collapse
-
#devices ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1Device>
A list of devices which have the app installed.
-
#next_page_token ⇒ String
Token to specify the next page of the request.
-
#total_size ⇒ Fixnum
Total number of devices matching request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1FindInstalledAppDevicesResponse
constructor
A new instance of GoogleChromeManagementV1FindInstalledAppDevicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1FindInstalledAppDevicesResponse
Returns a new instance of GoogleChromeManagementV1FindInstalledAppDevicesResponse.
1969 1970 1971 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1969 def initialize(**args) update!(**args) end |
Instance Attribute Details
#devices ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1Device>
A list of devices which have the app installed. Sorted in ascending
alphabetical order on the Device.machine field.
Corresponds to the JSON property devices
1957 1958 1959 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1957 def devices @devices end |
#next_page_token ⇒ String
Token to specify the next page of the request.
Corresponds to the JSON property nextPageToken
1962 1963 1964 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1962 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
Total number of devices matching request.
Corresponds to the JSON property totalSize
1967 1968 1969 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1967 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1974 1975 1976 1977 1978 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1974 def update!(**args) @devices = args[:devices] if args.key?(:devices) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) end |