Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FindInstalledAppProfilesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response containing a list of profiles with queried app installed.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1FindInstalledAppProfilesResponse

Returns a new instance of GoogleChromeManagementV1FindInstalledAppProfilesResponse.



2001
2002
2003
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Token to specify the next page of the request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1988
1989
1990
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1988

def next_page_token
  @next_page_token
end

#profilesArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ProfileAppInstallInstance>

A list of profiles which have the app installed. Sorted in ascending alphabetical order on the profile.Email field. Corresponds to the JSON property profiles



1994
1995
1996
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1994

def profiles
  @profiles
end

#total_sizeFixnum

Total number of profiles matching request. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


1999
2000
2001
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1999

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2006
2007
2008
2009
2010
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2006

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @profiles = args[:profiles] if args.key?(:profiles)
  @total_size = args[:total_size] if args.key?(:total_size)
end