Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsStatusReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsStatusReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Information of the graphics subsystem. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDeviceGraphicsInfo * Data Collection Frequency: 3 hours. * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_GRAPHICS_REPORT
Instance Attribute Summary collapse
-
#displays ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DisplayInfo>
Output only.
-
#report_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1GraphicsStatusReport
constructor
A new instance of GoogleChromeManagementV1GraphicsStatusReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1GraphicsStatusReport
Returns a new instance of GoogleChromeManagementV1GraphicsStatusReport.
2082 2083 2084 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#displays ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DisplayInfo>
Output only. Information about the displays for the device.
Corresponds to the JSON property displays
2075 2076 2077 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2075 def displays @displays end |
#report_time ⇒ String
Output only. Time at which the graphics data was reported.
Corresponds to the JSON property reportTime
2080 2081 2082 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2080 def report_time @report_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2087 2088 2089 2090 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2087 def update!(**args) @displays = args[:displays] if args.key?(:displays) @report_time = args[:report_time] if args.key?(:report_time) end |