Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1KioskAppStatusReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Kiosk app status report of a device. * Available for Kiosks * This field provides the app id and version number running on a kiosk device and the timestamp of when the report was last updated * Data for this field is controlled via policy: ReportDeviceSessionStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes

  • Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_APPS_REPORT

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1KioskAppStatusReport

Returns a new instance of GoogleChromeManagementV1KioskAppStatusReport.



2307
2308
2309
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

App id of kiosk app for example "mdmkkicfmmkgmpkmkdikhlbggogpicma" Corresponds to the JSON property appId

Returns:

  • (String)


2295
2296
2297
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2295

def app_id
  @app_id
end

#app_versionString

App version number of kiosk app for example "1.10.118" Corresponds to the JSON property appVersion

Returns:

  • (String)


2300
2301
2302
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2300

def app_version
  @app_version
end

#report_timeString

Timestamp of when report was collected Corresponds to the JSON property reportTime

Returns:

  • (String)


2305
2306
2307
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2305

def report_time
  @report_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2312
2313
2314
2315
2316
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2312

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @app_version = args[:app_version] if args.key?(:app_version)
  @report_time = args[:report_time] if args.key?(:report_time)
end