Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Contains information regarding the current OS update status. * This field is telemetry information and this will change over time as the device is utilized.
- Data for this field is controlled via policy: ReportDeviceOsUpdateStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_OS_REPORT
Instance Attribute Summary collapse
-
#last_reboot_time ⇒ String
Output only.
-
#last_update_check_time ⇒ String
Output only.
-
#last_update_time ⇒ String
Output only.
-
#new_platform_version ⇒ String
Output only.
-
#new_requested_platform_version ⇒ String
Output only.
-
#update_state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1OsUpdateStatus
constructor
A new instance of GoogleChromeManagementV1OsUpdateStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1OsUpdateStatus
Returns a new instance of GoogleChromeManagementV1OsUpdateStatus.
2835 2836 2837 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_reboot_time ⇒ String
Output only. Timestamp of the last reboot.
Corresponds to the JSON property lastRebootTime
2804 2805 2806 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2804 def last_reboot_time @last_reboot_time end |
#last_update_check_time ⇒ String
Output only. Timestamp of the last update check.
Corresponds to the JSON property lastUpdateCheckTime
2809 2810 2811 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2809 def last_update_check_time @last_update_check_time end |
#last_update_time ⇒ String
Output only. Timestamp of the last successful update.
Corresponds to the JSON property lastUpdateTime
2814 2815 2816 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2814 def last_update_time @last_update_time end |
#new_platform_version ⇒ String
Output only. New platform version of the os image being downloaded and applied.
It is only set when update status is OS_IMAGE_DOWNLOAD_IN_PROGRESS or
OS_UPDATE_NEED_REBOOT. Note this could be a dummy "0.0.0.0" for
OS_UPDATE_NEED_REBOOT status for some edge cases, e.g. update engine is
restarted without a reboot.
Corresponds to the JSON property newPlatformVersion
2823 2824 2825 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2823 def new_platform_version @new_platform_version end |
#new_requested_platform_version ⇒ String
Output only. New requested platform version from the pending updated kiosk app.
Corresponds to the JSON property newRequestedPlatformVersion
2828 2829 2830 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2828 def new_requested_platform_version @new_requested_platform_version end |
#update_state ⇒ String
Output only. Current state of the os update.
Corresponds to the JSON property updateState
2833 2834 2835 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2833 def update_state @update_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2840 2841 2842 2843 2844 2845 2846 2847 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2840 def update!(**args) @last_reboot_time = args[:last_reboot_time] if args.key?(:last_reboot_time) @last_update_check_time = args[:last_update_check_time] if args.key?(:last_update_check_time) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @new_platform_version = args[:new_platform_version] if args.key?(:new_platform_version) @new_requested_platform_version = args[:new_requested_platform_version] if args.key?(:new_requested_platform_version) @update_state = args[:update_state] if args.key?(:update_state) end |