Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrintJob

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Represents a request to print a document that has been submitted to a printer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1PrintJob

Returns a new instance of GoogleChromeManagementV1PrintJob.



2908
2909
2910
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#color_modeString

Color mode. Corresponds to the JSON property colorMode

Returns:

  • (String)


2846
2847
2848
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2846

def color_mode
  @color_mode
end

#complete_timeString

Print job completion timestamp. Corresponds to the JSON property completeTime

Returns:

  • (String)


2851
2852
2853
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2851

def complete_time
  @complete_time
end

#copy_countFixnum

Number of copies. Corresponds to the JSON property copyCount

Returns:

  • (Fixnum)


2856
2857
2858
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2856

def copy_count
  @copy_count
end

#create_timeString

Print job creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


2861
2862
2863
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2861

def create_time
  @create_time
end

#document_page_countFixnum

Number of pages in the document. Corresponds to the JSON property documentPageCount

Returns:

  • (Fixnum)


2866
2867
2868
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2866

def document_page_count
  @document_page_count
end

#duplex_modeString

Duplex mode. Corresponds to the JSON property duplexMode

Returns:

  • (String)


2871
2872
2873
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2871

def duplex_mode
  @duplex_mode
end

#idString

Unique ID of the print job. Corresponds to the JSON property id

Returns:

  • (String)


2876
2877
2878
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2876

def id
  @id
end

#printerString

Name of the printer used for printing. Corresponds to the JSON property printer

Returns:

  • (String)


2881
2882
2883
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2881

def printer
  @printer
end

#printer_idString

API ID of the printer used for printing. Corresponds to the JSON property printerId

Returns:

  • (String)


2886
2887
2888
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2886

def printer_id
  @printer_id
end

#stateString

The final state of the job. Corresponds to the JSON property state

Returns:

  • (String)


2891
2892
2893
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2891

def state
  @state
end

#titleString

The title of the document. Corresponds to the JSON property title

Returns:

  • (String)


2896
2897
2898
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2896

def title
  @title
end

#user_emailString

The primary e-mail address of the user who submitted the print job. Corresponds to the JSON property userEmail

Returns:

  • (String)


2901
2902
2903
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2901

def user_email
  @user_email
end

#user_idString

The unique Directory API ID of the user who submitted the print job. Corresponds to the JSON property userId

Returns:

  • (String)


2906
2907
2908
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2906

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2913

def update!(**args)
  @color_mode = args[:color_mode] if args.key?(:color_mode)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @copy_count = args[:copy_count] if args.key?(:copy_count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @document_page_count = args[:document_page_count] if args.key?(:document_page_count)
  @duplex_mode = args[:duplex_mode] if args.key?(:duplex_mode)
  @id = args[:id] if args.key?(:id)
  @printer = args[:printer] if args.key?(:printer)
  @printer_id = args[:printer_id] if args.key?(:printer_id)
  @state = args[:state] if args.key?(:state)
  @title = args[:title] if args.key?(:title)
  @user_email = args[:user_email] if args.key?(:user_email)
  @user_id = args[:user_id] if args.key?(:user_id)
end