Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Report for CountPrintJobsByPrinter, contains statistics on printer usage. Contains the total number of print jobs initiated with this printer, the number of users and the number of devices that have initiated at least one print job with this printer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1PrinterReport

Returns a new instance of GoogleChromeManagementV1PrinterReport.



3005
3006
3007
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_countFixnum

Number of chrome devices that have been used to send print jobs to the specified printer. Corresponds to the JSON property deviceCount

Returns:

  • (Fixnum)


2978
2979
2980
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2978

def device_count
  @device_count
end

#job_countFixnum

Number of print jobs sent to the printer. Corresponds to the JSON property jobCount

Returns:

  • (Fixnum)


2983
2984
2985
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2983

def job_count
  @job_count
end

#printerString

Printer name. Corresponds to the JSON property printer

Returns:

  • (String)


2988
2989
2990
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2988

def printer
  @printer
end

#printer_idString

Printer API ID. Corresponds to the JSON property printerId

Returns:

  • (String)


2993
2994
2995
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2993

def printer_id
  @printer_id
end

#printer_modelString

Printer model. Corresponds to the JSON property printerModel

Returns:

  • (String)


2998
2999
3000
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2998

def printer_model
  @printer_model
end

#user_countFixnum

Number of users that have sent print jobs to the printer. Corresponds to the JSON property userCount

Returns:

  • (Fixnum)


3003
3004
3005
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3003

def user_count
  @user_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3010

def update!(**args)
  @device_count = args[:device_count] if args.key?(:device_count)
  @job_count = args[:job_count] if args.key?(:job_count)
  @printer = args[:printer] if args.key?(:printer)
  @printer_id = args[:printer_id] if args.key?(:printer_id)
  @printer_model = args[:printer_model] if args.key?(:printer_model)
  @user_count = args[:user_count] if args.key?(:user_count)
end