Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RiskAssessment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Risk assessment for a Chrome extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1RiskAssessment

Returns a new instance of GoogleChromeManagementV1RiskAssessment.



3079
3080
3081
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessmentString

Risk assessment for the extension. Currently, this is a numerical value, and its interpretation is specific to each risk assessment provider. Corresponds to the JSON property assessment

Returns:

  • (String)


3066
3067
3068
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3066

def assessment
  @assessment
end

#details_urlString

A URL that a user can navigate to for more information about the risk assessment. Corresponds to the JSON property detailsUrl

Returns:

  • (String)


3072
3073
3074
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3072

def details_url
  @details_url
end

#versionString

The version of the extension that this assessment applies to. Corresponds to the JSON property version

Returns:

  • (String)


3077
3078
3079
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3077

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3084
3085
3086
3087
3088
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3084

def update!(**args)
  @assessment = args[:assessment] if args.key?(:assessment)
  @details_url = args[:details_url] if args.key?(:details_url)
  @version = args[:version] if args.key?(:version)
end