Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RuntimeCountersReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RuntimeCountersReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Runtime counters retrieved from CPU. Currently the runtime counters telemetry is only supported by Intel vPro PSR on Gen 14+.
Instance Attribute Summary collapse
-
#enter_hibernation_count ⇒ Fixnum
Number of times that the device has entered into the hibernation state.
-
#enter_poweroff_count ⇒ Fixnum
Number of times that the device has entered into the power-off state.
-
#enter_sleep_count ⇒ Fixnum
Number of times that the device has entered into the sleep state.
-
#report_time ⇒ String
Timestamp when the report was collected.
-
#uptime_runtime_duration ⇒ String
Total lifetime runtime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1RuntimeCountersReport
constructor
A new instance of GoogleChromeManagementV1RuntimeCountersReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1RuntimeCountersReport
Returns a new instance of GoogleChromeManagementV1RuntimeCountersReport.
3181 3182 3183 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enter_hibernation_count ⇒ Fixnum
Number of times that the device has entered into the hibernation state.
Currently obtained via the PSR, count from S0->S4.
Corresponds to the JSON property enterHibernationCount
3157 3158 3159 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3157 def enter_hibernation_count @enter_hibernation_count end |
#enter_poweroff_count ⇒ Fixnum
Number of times that the device has entered into the power-off state.
Currently obtained via the PSR, count from S0->S5.
Corresponds to the JSON property enterPoweroffCount
3163 3164 3165 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3163 def enter_poweroff_count @enter_poweroff_count end |
#enter_sleep_count ⇒ Fixnum
Number of times that the device has entered into the sleep state. Currently
obtained via the PSR, count from S0->S3.
Corresponds to the JSON property enterSleepCount
3169 3170 3171 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3169 def enter_sleep_count @enter_sleep_count end |
#report_time ⇒ String
Timestamp when the report was collected.
Corresponds to the JSON property reportTime
3174 3175 3176 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3174 def report_time @report_time end |
#uptime_runtime_duration ⇒ String
Total lifetime runtime. Currently always S0 runtime from Intel vPro PSR.
Corresponds to the JSON property uptimeRuntimeDuration
3179 3180 3181 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3179 def uptime_runtime_duration @uptime_runtime_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3186 3187 3188 3189 3190 3191 3192 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3186 def update!(**args) @enter_hibernation_count = args[:enter_hibernation_count] if args.key?(:enter_hibernation_count) @enter_poweroff_count = args[:enter_poweroff_count] if args.key?(:enter_poweroff_count) @enter_sleep_count = args[:enter_sleep_count] if args.key?(:enter_sleep_count) @report_time = args[:report_time] if args.key?(:report_time) @uptime_runtime_duration = args[:uptime_runtime_duration] if args.key?(:uptime_runtime_duration) end |