Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryNotificationFilter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Configures how the telemetry data should be filtered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryNotificationFilter

Returns a new instance of GoogleChromeManagementV1TelemetryNotificationFilter.



4034
4035
4036
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_idString

If set, only sends notifications for telemetry data coming from this device. Corresponds to the JSON property deviceId

Returns:

  • (String)


4009
4010
4011
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4009

def device_id
  @device_id
end

#device_org_unit_idString

If set, only sends notifications for telemetry data coming from devices in this org unit. Corresponds to the JSON property deviceOrgUnitId

Returns:

  • (String)


4015
4016
4017
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4015

def device_org_unit_id
  @device_org_unit_id
end

#telemetry_event_notification_filterGoogle::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryEventNotificationFilter

Configures how the telemetry events should be filtered. Corresponds to the JSON property telemetryEventNotificationFilter



4020
4021
4022
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4020

def telemetry_event_notification_filter
  @telemetry_event_notification_filter
end

#user_emailString

If set, only sends notifications for telemetry data coming from devices owned by this user. Corresponds to the JSON property userEmail

Returns:

  • (String)


4026
4027
4028
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4026

def user_email
  @user_email
end

#user_org_unit_idString

If set, only sends notifications for telemetry data coming from devices owned by users in this org unit. Corresponds to the JSON property userOrgUnitId

Returns:

  • (String)


4032
4033
4034
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4032

def user_org_unit_id
  @user_org_unit_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4039
4040
4041
4042
4043
4044
4045
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4039

def update!(**args)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_org_unit_id = args[:device_org_unit_id] if args.key?(:device_org_unit_id)
  @telemetry_event_notification_filter = args[:telemetry_event_notification_filter] if args.key?(:telemetry_event_notification_filter)
  @user_email = args[:user_email] if args.key?(:user_email)
  @user_org_unit_id = args[:user_org_unit_id] if args.key?(:user_org_unit_id)
end