Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryUser
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryUser
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Telemetry data collected from a managed user. * Granular permission needed: TELEMETRY_API_USER
Instance Attribute Summary collapse
-
#customer ⇒ String
G Suite Customer whose enterprise enrolled the device.
-
#name ⇒ String
Resource name of the user.
-
#org_unit_id ⇒ String
Organization unit of the user.
-
#user_device ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryUserDevice>
Telemetry data collected from a managed user and device.
-
#user_email ⇒ String
Email address of the user.
-
#user_id ⇒ String
Directory ID of the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryUser
constructor
A new instance of GoogleChromeManagementV1TelemetryUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryUser
Returns a new instance of GoogleChromeManagementV1TelemetryUser.
4097 4098 4099 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer ⇒ String
G Suite Customer whose enterprise enrolled the device.
Corresponds to the JSON property customer
4070 4071 4072 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4070 def customer @customer end |
#name ⇒ String
Resource name of the user.
Corresponds to the JSON property name
4075 4076 4077 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4075 def name @name end |
#org_unit_id ⇒ String
Organization unit of the user.
Corresponds to the JSON property orgUnitId
4080 4081 4082 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4080 def org_unit_id @org_unit_id end |
#user_device ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryUserDevice>
Telemetry data collected from a managed user and device.
Corresponds to the JSON property userDevice
4085 4086 4087 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4085 def user_device @user_device end |
#user_email ⇒ String
Email address of the user.
Corresponds to the JSON property userEmail
4090 4091 4092 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4090 def user_email @user_email end |
#user_id ⇒ String
Directory ID of the user.
Corresponds to the JSON property userId
4095 4096 4097 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4095 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4102 4103 4104 4105 4106 4107 4108 4109 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4102 def update!(**args) @customer = args[:customer] if args.key?(:customer) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @user_device = args[:user_device] if args.key?(:user_device) @user_email = args[:user_email] if args.key?(:user_email) @user_id = args[:user_id] if args.key?(:user_id) end |