Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TotalMemoryEncryptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Memory encryption information of a device. * This field provides device information, which is static and will not change over time. * Data for this field is controlled via policy: ReportDeviceMemoryInfo * Data Collection Frequency: At device startup * Default Data Reporting Frequency: At device startup - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: N/A

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1TotalMemoryEncryptionInfo

Returns a new instance of GoogleChromeManagementV1TotalMemoryEncryptionInfo.



4288
4289
4290
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4288

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryption_algorithmString

Memory encryption algorithm. Corresponds to the JSON property encryptionAlgorithm

Returns:

  • (String)


4271
4272
4273
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4271

def encryption_algorithm
  @encryption_algorithm
end

#encryption_stateString

The state of memory encryption on the device. Corresponds to the JSON property encryptionState

Returns:

  • (String)


4276
4277
4278
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4276

def encryption_state
  @encryption_state
end

#key_lengthFixnum

The length of the encryption keys. Corresponds to the JSON property keyLength

Returns:

  • (Fixnum)


4281
4282
4283
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4281

def key_length
  @key_length
end

#max_keysFixnum

The maximum number of keys that can be used for encryption. Corresponds to the JSON property maxKeys

Returns:

  • (Fixnum)


4286
4287
4288
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4286

def max_keys
  @max_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4293
4294
4295
4296
4297
4298
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4293

def update!(**args)
  @encryption_algorithm = args[:encryption_algorithm] if args.key?(:encryption_algorithm)
  @encryption_state = args[:encryption_state] if args.key?(:encryption_state)
  @key_length = args[:key_length] if args.key?(:key_length)
  @max_keys = args[:max_keys] if args.key?(:max_keys)
end