Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserPrintReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Report for CountPrintJobsByUser, contains printing statistics for a user. Contains the number of printers, the number of devices used to initiate print jobs, and the number of print jobs initiated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1UserPrintReport

Returns a new instance of GoogleChromeManagementV1UserPrintReport.



4452
4453
4454
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_countFixnum

Number of chrome devices that have been used to initiate print jobs by the user. Corresponds to the JSON property deviceCount

Returns:

  • (Fixnum)


4430
4431
4432
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4430

def device_count
  @device_count
end

#job_countFixnum

Number of print jobs initiated by the user. Corresponds to the JSON property jobCount

Returns:

  • (Fixnum)


4435
4436
4437
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4435

def job_count
  @job_count
end

#printer_countFixnum

Number of printers used by the user. Corresponds to the JSON property printerCount

Returns:

  • (Fixnum)


4440
4441
4442
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4440

def printer_count
  @printer_count
end

#user_emailString

The primary e-mail address of the user. Corresponds to the JSON property userEmail

Returns:

  • (String)


4445
4446
4447
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4445

def user_email
  @user_email
end

#user_idString

The unique Directory API ID of the user. Corresponds to the JSON property userId

Returns:

  • (String)


4450
4451
4452
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4450

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4457
4458
4459
4460
4461
4462
4463
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4457

def update!(**args)
  @device_count = args[:device_count] if args.key?(:device_count)
  @job_count = args[:job_count] if args.key?(:job_count)
  @printer_count = args[:printer_count] if args.key?(:printer_count)
  @user_email = args[:user_email] if args.key?(:user_email)
  @user_id = args[:user_id] if args.key?(:user_id)
end