Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserRequestingExtensionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserRequestingExtensionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Details of a user requesting an extension, including the email and the justification.
Instance Attribute Summary collapse
-
#email ⇒ String
The e-mail address of a user that has requested the extension.
-
#justification ⇒ String
Request justification as entered by the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1UserRequestingExtensionDetails
constructor
A new instance of GoogleChromeManagementV1UserRequestingExtensionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1UserRequestingExtensionDetails
Returns a new instance of GoogleChromeManagementV1UserRequestingExtensionDetails.
4481 4482 4483 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4481 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
The e-mail address of a user that has requested the extension.
Corresponds to the JSON property email
4474 4475 4476 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4474 def email @email end |
#justification ⇒ String
Request justification as entered by the user.
Corresponds to the JSON property justification
4479 4480 4481 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4479 def justification @justification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4486 4487 4488 4489 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4486 def update!(**args) @email = args[:email] if args.key?(:email) @justification = args[:justification] if args.key?(:justification) end |