Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Result of the execution of a command.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult

Returns a new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult.



4931
4932
4933
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_execution_timeString

Output only. Timestamp of the client execution of the remote command. Corresponds to the JSON property clientExecutionTime

Returns:

  • (String)


4918
4919
4920
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4918

def client_execution_time
  @client_execution_time
end

#result_codeString

Output only. Result code that indicates the type of error or success of the command. Corresponds to the JSON property resultCode

Returns:

  • (String)


4924
4925
4926
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4924

def result_code
  @result_code
end

#result_typeString

Output only. Result type of the remote command. Corresponds to the JSON property resultType

Returns:

  • (String)


4929
4930
4931
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4929

def result_type
  @result_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4936
4937
4938
4939
4940
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4936

def update!(**args)
  @client_execution_time = args[:client_execution_time] if args.key?(:client_execution_time)
  @result_code = args[:result_code] if args.key?(:result_code)
  @result_type = args[:result_type] if args.key?(:result_type)
end