Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListChromeBrowserProfileCommandsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response to ListChromeBrowserProfileCommands method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListChromeBrowserProfileCommandsResponse

Returns a new instance of GoogleChromeManagementVersionsV1ListChromeBrowserProfileCommandsResponse.



5404
5405
5406
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5404

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chrome_browser_profile_commandsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfileCommand>

The list of commands returned. Corresponds to the JSON property chromeBrowserProfileCommands



5392
5393
5394
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5392

def chrome_browser_profile_commands
  @chrome_browser_profile_commands
end

#next_page_tokenString

The pagination token that can be used to list the next page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5397
5398
5399
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5397

def next_page_token
  @next_page_token
end

#total_sizeFixnum

Total size represents an estimated number of resources returned. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


5402
5403
5404
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5402

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5409
5410
5411
5412
5413
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5409

def update!(**args)
  @chrome_browser_profile_commands = args[:chrome_browser_profile_commands] if args.key?(:chrome_browser_profile_commands)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
end