Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListChromeBrowserProfilesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListChromeBrowserProfilesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response to ListChromeBrowserProfiles method.
Instance Attribute Summary collapse
-
#chrome_browser_profiles ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile>
The list of profiles returned.
-
#next_page_token ⇒ String
The pagination token that can be used to list the next page.
-
#total_size ⇒ Fixnum
Total size represents an estimated number of resources returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListChromeBrowserProfilesResponse
constructor
A new instance of GoogleChromeManagementVersionsV1ListChromeBrowserProfilesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListChromeBrowserProfilesResponse
Returns a new instance of GoogleChromeManagementVersionsV1ListChromeBrowserProfilesResponse.
5627 5628 5629 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chrome_browser_profiles ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile>
The list of profiles returned.
Corresponds to the JSON property chromeBrowserProfiles
5614 5615 5616 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5614 def chrome_browser_profiles @chrome_browser_profiles end |
#next_page_token ⇒ String
The pagination token that can be used to list the next page.
Corresponds to the JSON property nextPageToken
5619 5620 5621 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5619 def next_page_token @next_page_token end |
#total_size ⇒ Fixnum
Total size represents an estimated number of resources returned. Not
guaranteed to be accurate above 10k profiles.
Corresponds to the JSON property totalSize
5625 5626 5627 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5625 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5632 5633 5634 5635 5636 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5632 def update!(**args) @chrome_browser_profiles = args[:chrome_browser_profiles] if args.key?(:chrome_browser_profiles) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @total_size = args[:total_size] if args.key?(:total_size) end |