Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Reporting settings for connector configs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ReportingSettings

Returns a new instance of GoogleChromeManagementVersionsV1ReportingSettings.



6154
6155
6156
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabled_default_eventsArray<String>

Optional. The list of user and browser events that are enabled for this connector. An empty list disables all default events, and using ALL_DEFAULT_EVENTS will enable all default events. Corresponds to the JSON property enabledDefaultEvents

Returns:

  • (Array<String>)


6138
6139
6140
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6138

def enabled_default_events
  @enabled_default_events
end

#enabled_device_eventsArray<String>

Optional. The list of device events that are enabled for this config. An empty list disables all device events, and using ALL_DEVICE_EVENTS will enable all device events. Corresponds to the JSON property enabledDeviceEvents

Returns:

  • (Array<String>)


6145
6146
6147
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6145

def enabled_device_events
  @enabled_device_events
end

#enabled_opt_in_eventsArray<String>

Optional. The list of opt-in events that are enabled for this config. An empty list disables all opt-in events, and using ALL_OPT_IN_EVENTS will enable all opt-in events. Corresponds to the JSON property enabledOptInEvents

Returns:

  • (Array<String>)


6152
6153
6154
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6152

def enabled_opt_in_events
  @enabled_opt_in_events
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6159
6160
6161
6162
6163
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6159

def update!(**args)
  @enabled_default_events = args[:enabled_default_events] if args.key?(:enabled_default_events)
  @enabled_device_events = args[:enabled_device_events] if args.key?(:enabled_device_events)
  @enabled_opt_in_events = args[:enabled_opt_in_events] if args.key?(:enabled_opt_in_events)
end