Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Describes a SCEP certificate provisioning profile.
Instance Attribute Summary collapse
-
#certificate_template_name ⇒ String
Output only.
-
#country ⇒ String
Output only.
-
#key_usages ⇒ Array<String>
Output only.
-
#locality ⇒ String
Output only.
-
#organization ⇒ String
Output only.
-
#organizational_units ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#subject_alt_names ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SubjectAltName>
Output only.
-
#subject_common_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ScepProfile
constructor
A new instance of GoogleChromeManagementVersionsV1ScepProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ScepProfile
Returns a new instance of GoogleChromeManagementVersionsV1ScepProfile.
6237 6238 6239 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_template_name ⇒ String
Output only. The certificate template name as defined by the admin on their on-
prem infrastructure. The Certificate Authority uses this name to identify the
certificate template.
Corresponds to the JSON property certificateTemplateName
6195 6196 6197 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6195 def certificate_template_name @certificate_template_name end |
#country ⇒ String
Output only. The country of the subject.
Corresponds to the JSON property country
6200 6201 6202 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6200 def country @country end |
#key_usages ⇒ Array<String>
Output only. The allowed key usages for certificate's key.
Corresponds to the JSON property keyUsages
6205 6206 6207 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6205 def key_usages @key_usages end |
#locality ⇒ String
Output only. The locality of the subject.
Corresponds to the JSON property locality
6210 6211 6212 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6210 def locality @locality end |
#organization ⇒ String
Output only. The name of the organization the subject belongs to.
Corresponds to the JSON property organization
6215 6216 6217 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6215 def organization @organization end |
#organizational_units ⇒ Array<String>
Output only. The organizational units of the subject.
Corresponds to the JSON property organizationalUnits
6220 6221 6222 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6220 def organizational_units @organizational_units end |
#state ⇒ String
Output only. The state of the subject.
Corresponds to the JSON property state
6225 6226 6227 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6225 def state @state end |
#subject_alt_names ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SubjectAltName>
Output only. The subject alternative names.
Corresponds to the JSON property subjectAltNames
6230 6231 6232 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6230 def subject_alt_names @subject_alt_names end |
#subject_common_name ⇒ String
Output only. The common name of the subject.
Corresponds to the JSON property subjectCommonName
6235 6236 6237 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6235 def subject_common_name @subject_common_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6242 def update!(**args) @certificate_template_name = args[:certificate_template_name] if args.key?(:certificate_template_name) @country = args[:country] if args.key?(:country) @key_usages = args[:key_usages] if args.key?(:key_usages) @locality = args[:locality] if args.key?(:locality) @organization = args[:organization] if args.key?(:organization) @organizational_units = args[:organizational_units] if args.key?(:organizational_units) @state = args[:state] if args.key?(:state) @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names) @subject_common_name = args[:subject_common_name] if args.key?(:subject_common_name) end |