Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SignDataRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Request message for requesting a signature from the client that initated a certificate provisioning process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SignDataRequest

Returns a new instance of GoogleChromeManagementVersionsV1SignDataRequest.



6325
6326
6327
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sign_dataString

Required. The data that the client was asked to sign. Corresponds to the JSON property signData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


6317
6318
6319
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6317

def sign_data
  @sign_data
end

#signature_algorithmString

Required. The signature algorithm that the adapter expects the client and backend components to use when processing sign_data. Corresponds to the JSON property signatureAlgorithm

Returns:

  • (String)


6323
6324
6325
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6323

def signature_algorithm
  @signature_algorithm
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6330
6331
6332
6333
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6330

def update!(**args)
  @sign_data = args[:sign_data] if args.key?(:sign_data)
  @signature_algorithm = args[:signature_algorithm] if args.key?(:signature_algorithm)
end