Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ThirdPartyProfileUser
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ThirdPartyProfileUser
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A representation of non-Google (third party) user that is associated with a managed Chrome profile.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#org_unit_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ThirdPartyProfileUser
constructor
A new instance of GoogleChromeManagementVersionsV1ThirdPartyProfileUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ThirdPartyProfileUser
Returns a new instance of GoogleChromeManagementVersionsV1ThirdPartyProfileUser.
6261 6262 6263 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6261 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. Format: customers/customer_id/thirdPartyProfileUsers/
third_party_profile_user_id
Corresponds to the JSON property name
6254 6255 6256 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6254 def name @name end |
#org_unit_id ⇒ String
Output only. The ID of the organizational unit assigned to the user.
Corresponds to the JSON property orgUnitId
6259 6260 6261 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6259 def org_unit_id @org_unit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6266 6267 6268 6269 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6266 def update!(**args) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) end |