Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppDetails
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Resource representing app details.
Instance Attribute Summary collapse
-
#android_app_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AndroidAppInfo
Android app information.
-
#app_id ⇒ String
Output only.
-
#category_ids ⇒ Array<String>
Output only.
-
#chrome_app_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ChromeAppInfo
Chrome Web Store app information.
-
#description ⇒ String
Output only.
-
#detail_uri ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#first_publish_time ⇒ String
Output only.
-
#homepage_uri ⇒ String
Output only.
-
#icon_uri ⇒ String
Output only.
-
#is_paid_app ⇒ Boolean
(also: #is_paid_app?)
Output only.
-
#latest_publish_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#privacy_policy_uri ⇒ String
Output only.
-
#publisher ⇒ String
Output only.
-
#review_number ⇒ Fixnum
Output only.
-
#review_rating ⇒ Float
Output only.
-
#revision_id ⇒ String
Output only.
-
#service_error ⇒ Google::Apis::ChromemanagementV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1AppDetails
constructor
A new instance of GoogleChromeManagementV1AppDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1AppDetails
Returns a new instance of GoogleChromeManagementV1AppDetails.
182 183 184 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#android_app_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AndroidAppInfo
Android app information.
Corresponds to the JSON property androidAppInfo
70 71 72 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 70 def android_app_info @android_app_info end |
#app_id ⇒ String
Output only. Unique store identifier for the item. Examples: "
gmbmikajjgmnabiglmofipeabaddhgne" for the Save to Google Drive Chrome
extension, "com.google.android.apps.docs" for the Google Drive Android app.
Corresponds to the JSON property appId
77 78 79 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 77 def app_id @app_id end |
#category_ids ⇒ Array<String>
Output only. The category IDs of the app, which are the same as stored in the
Web Store item. It's expected that there is only one category ID.
Corresponds to the JSON property categoryIds
83 84 85 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 83 def category_ids @category_ids end |
#chrome_app_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ChromeAppInfo
Chrome Web Store app information.
Corresponds to the JSON property chromeAppInfo
88 89 90 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 88 def chrome_app_info @chrome_app_info end |
#description ⇒ String
Output only. App's description.
Corresponds to the JSON property description
93 94 95 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 93 def description @description end |
#detail_uri ⇒ String
Output only. The uri for the detail page of the item.
Corresponds to the JSON property detailUri
98 99 100 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 98 def detail_uri @detail_uri end |
#display_name ⇒ String
Output only. App's display name.
Corresponds to the JSON property displayName
103 104 105 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 103 def display_name @display_name end |
#first_publish_time ⇒ String
Output only. First published time.
Corresponds to the JSON property firstPublishTime
108 109 110 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 108 def first_publish_time @first_publish_time end |
#homepage_uri ⇒ String
Output only. Home page or Website uri.
Corresponds to the JSON property homepageUri
113 114 115 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 113 def homepage_uri @homepage_uri end |
#icon_uri ⇒ String
Output only. A link to an image that can be used as an icon for the product.
Corresponds to the JSON property iconUri
118 119 120 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 118 def icon_uri @icon_uri end |
#is_paid_app ⇒ Boolean Also known as: is_paid_app?
Output only. Indicates if the app has to be paid for OR has paid content.
Corresponds to the JSON property isPaidApp
123 124 125 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 123 def is_paid_app @is_paid_app end |
#latest_publish_time ⇒ String
Output only. Latest published time.
Corresponds to the JSON property latestPublishTime
129 130 131 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 129 def latest_publish_time @latest_publish_time end |
#name ⇒ String
Output only. Format: name=customers/customer_id/apps/chrome|android|web/
app_id@version
Corresponds to the JSON property name
135 136 137 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 135 def name @name end |
#privacy_policy_uri ⇒ String
Output only. The URI pointing to the privacy policy of the app, if it was
provided by the developer. Version-specific field that will only be set when
the requested app version is found.
Corresponds to the JSON property privacyPolicyUri
142 143 144 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 142 def privacy_policy_uri @privacy_policy_uri end |
#publisher ⇒ String
Output only. The publisher of the item.
Corresponds to the JSON property publisher
147 148 149 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 147 def publisher @publisher end |
#review_number ⇒ Fixnum
Output only. Number of reviews received. Chrome Web Store review information
will always be for the latest version of an app.
Corresponds to the JSON property reviewNumber
153 154 155 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 153 def review_number @review_number end |
#review_rating ⇒ Float
Output only. The rating of the app (on 5 stars). Chrome Web Store review
information will always be for the latest version of an app.
Corresponds to the JSON property reviewRating
159 160 161 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 159 def @review_rating end |
#revision_id ⇒ String
Output only. App version. A new revision is committed whenever a new version
of the app is published.
Corresponds to the JSON property revisionId
165 166 167 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 165 def revision_id @revision_id end |
#service_error ⇒ Google::Apis::ChromemanagementV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property serviceError
175 176 177 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 175 def service_error @service_error end |
#type ⇒ String
Output only. App type.
Corresponds to the JSON property type
180 181 182 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 180 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 187 def update!(**args) @android_app_info = args[:android_app_info] if args.key?(:android_app_info) @app_id = args[:app_id] if args.key?(:app_id) @category_ids = args[:category_ids] if args.key?(:category_ids) @chrome_app_info = args[:chrome_app_info] if args.key?(:chrome_app_info) @description = args[:description] if args.key?(:description) @detail_uri = args[:detail_uri] if args.key?(:detail_uri) @display_name = args[:display_name] if args.key?(:display_name) @first_publish_time = args[:first_publish_time] if args.key?(:first_publish_time) @homepage_uri = args[:homepage_uri] if args.key?(:homepage_uri) @icon_uri = args[:icon_uri] if args.key?(:icon_uri) @is_paid_app = args[:is_paid_app] if args.key?(:is_paid_app) @latest_publish_time = args[:latest_publish_time] if args.key?(:latest_publish_time) @name = args[:name] if args.key?(:name) @privacy_policy_uri = args[:privacy_policy_uri] if args.key?(:privacy_policy_uri) @publisher = args[:publisher] if args.key?(:publisher) @review_number = args[:review_number] if args.key?(:review_number) @review_rating = args[:review_rating] if args.key?(:review_rating) @revision_id = args[:revision_id] if args.key?(:revision_id) @service_error = args[:service_error] if args.key?(:service_error) @type = args[:type] if args.key?(:type) end |