Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatterySampleReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatterySampleReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Sampling data for battery. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDevicePowerStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A
Instance Attribute Summary collapse
-
#charge_rate ⇒ Fixnum
Output only.
-
#current ⇒ Fixnum
Output only.
-
#discharge_rate ⇒ Fixnum
Output only.
-
#remaining_capacity ⇒ Fixnum
Output only.
-
#report_time ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#temperature ⇒ Fixnum
Output only.
-
#voltage ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1BatterySampleReport
constructor
A new instance of GoogleChromeManagementV1BatterySampleReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1BatterySampleReport
Returns a new instance of GoogleChromeManagementV1BatterySampleReport.
452 453 454 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#charge_rate ⇒ Fixnum
Output only. Battery charge percentage.
Corresponds to the JSON property chargeRate
414 415 416 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 414 def charge_rate @charge_rate end |
#current ⇒ Fixnum
Output only. Battery current (mA).
Corresponds to the JSON property current
419 420 421 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 419 def current @current end |
#discharge_rate ⇒ Fixnum
Output only. The battery discharge rate measured in mW. Positive if the
battery is being discharged, negative if it's being charged.
Corresponds to the JSON property dischargeRate
425 426 427 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 425 def discharge_rate @discharge_rate end |
#remaining_capacity ⇒ Fixnum
Output only. Battery remaining capacity (mAmpere-hours).
Corresponds to the JSON property remainingCapacity
430 431 432 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 430 def remaining_capacity @remaining_capacity end |
#report_time ⇒ String
Output only. Timestamp of when the sample was collected on device
Corresponds to the JSON property reportTime
435 436 437 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 435 def report_time @report_time end |
#status ⇒ String
Output only. Battery status read from sysfs. Example: Discharging
Corresponds to the JSON property status
440 441 442 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 440 def status @status end |
#temperature ⇒ Fixnum
Output only. Temperature in Celsius degrees.
Corresponds to the JSON property temperature
445 446 447 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 445 def temperature @temperature end |
#voltage ⇒ Fixnum
Output only. Battery voltage (millivolt).
Corresponds to the JSON property voltage
450 451 452 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 450 def voltage @voltage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
457 458 459 460 461 462 463 464 465 466 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 457 def update!(**args) @charge_rate = args[:charge_rate] if args.key?(:charge_rate) @current = args[:current] if args.key?(:current) @discharge_rate = args[:discharge_rate] if args.key?(:discharge_rate) @remaining_capacity = args[:remaining_capacity] if args.key?(:remaining_capacity) @report_time = args[:report_time] if args.key?(:report_time) @status = args[:status] if args.key?(:status) @temperature = args[:temperature] if args.key?(:temperature) @voltage = args[:voltage] if args.key?(:voltage) end |