Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing counts for devices that need attention.
Instance Attribute Summary collapse
-
#no_recent_policy_sync_count ⇒ Fixnum
Number of ChromeOS devices have not synced policies in the past 28 days.
-
#no_recent_user_activity_count ⇒ Fixnum
Number of ChromeOS devices that have not seen any user activity in the past 28 days.
-
#os_version_not_compliant_count ⇒ Fixnum
Number of devices whose OS version is not compliant.
-
#pending_update ⇒ Fixnum
Number of devices that are pending an OS update.
-
#unsupported_policy_count ⇒ Fixnum
Number of devices that are unable to apply a policy due to an OS version mismatch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse
constructor
A new instance of GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse
Returns a new instance of GoogleChromeManagementV1CountChromeDevicesThatNeedAttentionResponse.
1034 1035 1036 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#no_recent_policy_sync_count ⇒ Fixnum
Number of ChromeOS devices have not synced policies in the past 28 days.
Corresponds to the JSON property noRecentPolicySyncCount
1010 1011 1012 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1010 def no_recent_policy_sync_count @no_recent_policy_sync_count end |
#no_recent_user_activity_count ⇒ Fixnum
Number of ChromeOS devices that have not seen any user activity in the past 28
days.
Corresponds to the JSON property noRecentUserActivityCount
1016 1017 1018 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1016 def no_recent_user_activity_count @no_recent_user_activity_count end |
#os_version_not_compliant_count ⇒ Fixnum
Number of devices whose OS version is not compliant.
Corresponds to the JSON property osVersionNotCompliantCount
1021 1022 1023 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1021 def os_version_not_compliant_count @os_version_not_compliant_count end |
#pending_update ⇒ Fixnum
Number of devices that are pending an OS update.
Corresponds to the JSON property pendingUpdate
1026 1027 1028 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1026 def pending_update @pending_update end |
#unsupported_policy_count ⇒ Fixnum
Number of devices that are unable to apply a policy due to an OS version
mismatch.
Corresponds to the JSON property unsupportedPolicyCount
1032 1033 1034 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1032 def unsupported_policy_count @unsupported_policy_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1039 1040 1041 1042 1043 1044 1045 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1039 def update!(**args) @no_recent_policy_sync_count = args[:no_recent_policy_sync_count] if args.key?(:no_recent_policy_sync_count) @no_recent_user_activity_count = args[:no_recent_user_activity_count] if args.key?(:no_recent_user_activity_count) @os_version_not_compliant_count = args[:os_version_not_compliant_count] if args.key?(:os_version_not_compliant_count) @pending_update = args[:pending_update] if args.key?(:pending_update) @unsupported_policy_count = args[:unsupported_policy_count] if args.key?(:unsupported_policy_count) end |