Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing a list of devices with a specific type of hardware specification from the requested hardware type.
Instance Attribute Summary collapse
-
#cpu_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device cpu type (for example Intel(R) Core( TM) i7-10610U CPU @ 1.80GHz).
-
#memory_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device memory amount in gigabytes (for example 16).
-
#model_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device model type (for example Acer C7 Chromebook).
-
#storage_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device storage amount in gigabytes (for example 128).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse
constructor
A new instance of GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse
Returns a new instance of GoogleChromeManagementV1CountChromeHardwareFleetDevicesResponse.
1077 1078 1079 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device cpu type (for example Intel(R) Core(
TM) i7-10610U CPU @ 1.80GHz).
Corresponds to the JSON property cpuReports
1057 1058 1059 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1057 def cpu_reports @cpu_reports end |
#memory_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device memory amount in gigabytes (for
example 16).
Corresponds to the JSON property memoryReports
1063 1064 1065 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1063 def memory_reports @memory_reports end |
#model_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device model type (for example Acer C7
Chromebook).
Corresponds to the JSON property modelReports
1069 1070 1071 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1069 def model_reports @model_reports end |
#storage_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceHardwareCountReport>
The DeviceHardwareCountReport for device storage amount in gigabytes (for
example 128).
Corresponds to the JSON property storageReports
1075 1076 1077 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1075 def storage_reports @storage_reports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1082 1083 1084 1085 1086 1087 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1082 def update!(**args) @cpu_reports = args[:cpu_reports] if args.key?(:cpu_reports) @memory_reports = args[:memory_reports] if args.key?(:memory_reports) @model_reports = args[:model_reports] if args.key?(:model_reports) @storage_reports = args[:storage_reports] if args.key?(:storage_reports) end |