Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountPrintJobsByPrinterResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CountPrintJobsByPrinterResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing a summary printing report for each printer from the specified organizational unit for the requested time interval.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Pagination token for requesting the next page.
-
#printer_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport>
List of PrinterReports matching request.
-
#total_size ⇒ Fixnum
Total number of printers matching request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1CountPrintJobsByPrinterResponse
constructor
A new instance of GoogleChromeManagementV1CountPrintJobsByPrinterResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1CountPrintJobsByPrinterResponse
Returns a new instance of GoogleChromeManagementV1CountPrintJobsByPrinterResponse.
1264 1265 1266 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1264 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Pagination token for requesting the next page.
Corresponds to the JSON property nextPageToken
1252 1253 1254 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1252 def next_page_token @next_page_token end |
#printer_reports ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport>
List of PrinterReports matching request.
Corresponds to the JSON property printerReports
1257 1258 1259 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1257 def printer_reports @printer_reports end |
#total_size ⇒ Fixnum
Total number of printers matching request.
Corresponds to the JSON property totalSize
1262 1263 1264 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1262 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1269 1270 1271 1272 1273 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1269 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @printer_reports = args[:printer_reports] if args.key?(:printer_reports) @total_size = args[:total_size] if args.key?(:total_size) end |