Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceAueCountReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceAueCountReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Report for CountChromeDevicesPerAueDateResponse, contains the count of devices of a specific model and auto update expiration range.
Instance Attribute Summary collapse
-
#aue_month ⇒ String
Enum value of month corresponding to the auto update expiration date in UTC time zone.
-
#aue_year ⇒ Fixnum
Int value of year corresponding to the Auto Update Expiration date in UTC time zone.
-
#count ⇒ Fixnum
Count of devices of this model.
-
#expired ⇒ Boolean
(also: #expired?)
Boolean value for whether or not the device has already expired.
-
#model ⇒ String
Public model name of the devices.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1DeviceAueCountReport
constructor
A new instance of GoogleChromeManagementV1DeviceAueCountReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1DeviceAueCountReport
Returns a new instance of GoogleChromeManagementV1DeviceAueCountReport.
1533 1534 1535 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aue_month ⇒ String
Enum value of month corresponding to the auto update expiration date in UTC
time zone. If the device is already expired, this field is empty.
Corresponds to the JSON property aueMonth
1509 1510 1511 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1509 def aue_month @aue_month end |
#aue_year ⇒ Fixnum
Int value of year corresponding to the Auto Update Expiration date in UTC time
zone. If the device is already expired, this field is empty.
Corresponds to the JSON property aueYear
1515 1516 1517 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1515 def aue_year @aue_year end |
#count ⇒ Fixnum
Count of devices of this model.
Corresponds to the JSON property count
1520 1521 1522 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1520 def count @count end |
#expired ⇒ Boolean Also known as: expired?
Boolean value for whether or not the device has already expired.
Corresponds to the JSON property expired
1525 1526 1527 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1525 def expired @expired end |
#model ⇒ String
Public model name of the devices.
Corresponds to the JSON property model
1531 1532 1533 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1531 def model @model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1538 1539 1540 1541 1542 1543 1544 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1538 def update!(**args) @aue_month = args[:aue_month] if args.key?(:aue_month) @aue_year = args[:aue_year] if args.key?(:aue_year) @count = args[:count] if args.key?(:count) @expired = args[:expired] if args.key?(:expired) @model = args[:model] if args.key?(:model) end |