Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DiskInfo
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DiskInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Status of the single storage device.
Instance Attribute Summary collapse
-
#bytes_read_this_session ⇒ Fixnum
Output only.
-
#bytes_written_this_session ⇒ Fixnum
Output only.
-
#discard_time_this_session ⇒ String
Output only.
-
#health ⇒ String
Output only.
-
#io_time_this_session ⇒ String
Output only.
-
#manufacturer ⇒ String
Output only.
-
#model ⇒ String
Output only.
-
#read_time_this_session ⇒ String
Output only.
-
#serial_number ⇒ String
Output only.
-
#size_bytes ⇒ Fixnum
Output only.
-
#type ⇒ String
Output only.
-
#volume_ids ⇒ Array<String>
Output only.
-
#write_time_this_session ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1DiskInfo
constructor
A new instance of GoogleChromeManagementV1DiskInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1DiskInfo
Returns a new instance of GoogleChromeManagementV1DiskInfo.
1701 1702 1703 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1701 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bytes_read_this_session ⇒ Fixnum
Output only. Number of bytes read since last boot.
Corresponds to the JSON property bytesReadThisSession
1637 1638 1639 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1637 def bytes_read_this_session @bytes_read_this_session end |
#bytes_written_this_session ⇒ Fixnum
Output only. Number of bytes written since last boot.
Corresponds to the JSON property bytesWrittenThisSession
1642 1643 1644 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1642 def bytes_written_this_session @bytes_written_this_session end |
#discard_time_this_session ⇒ String
Output only. Time spent discarding since last boot. Discarding is writing to
clear blocks which are no longer in use. Supported on kernels 4.18+.
Corresponds to the JSON property discardTimeThisSession
1648 1649 1650 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1648 def discard_time_this_session @discard_time_this_session end |
#health ⇒ String
Output only. Disk health.
Corresponds to the JSON property health
1653 1654 1655 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1653 def health @health end |
#io_time_this_session ⇒ String
Output only. Counts the time the disk and queue were busy, so unlike the
fields above, parallel requests are not counted multiple times.
Corresponds to the JSON property ioTimeThisSession
1659 1660 1661 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1659 def io_time_this_session @io_time_this_session end |
#manufacturer ⇒ String
Output only. Disk manufacturer.
Corresponds to the JSON property manufacturer
1664 1665 1666 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1664 def manufacturer @manufacturer end |
#model ⇒ String
Output only. Disk model.
Corresponds to the JSON property model
1669 1670 1671 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1669 def model @model end |
#read_time_this_session ⇒ String
Output only. Time spent reading from disk since last boot.
Corresponds to the JSON property readTimeThisSession
1674 1675 1676 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1674 def read_time_this_session @read_time_this_session end |
#serial_number ⇒ String
Output only. Disk serial number.
Corresponds to the JSON property serialNumber
1679 1680 1681 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1679 def serial_number @serial_number end |
#size_bytes ⇒ Fixnum
Output only. Disk size.
Corresponds to the JSON property sizeBytes
1684 1685 1686 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1684 def size_bytes @size_bytes end |
#type ⇒ String
Output only. Disk type: eMMC / NVMe / ATA / SCSI.
Corresponds to the JSON property type
1689 1690 1691 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1689 def type @type end |
#volume_ids ⇒ Array<String>
Output only. Disk volumes.
Corresponds to the JSON property volumeIds
1694 1695 1696 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1694 def volume_ids @volume_ids end |
#write_time_this_session ⇒ String
Output only. Time spent writing to disk since last boot.
Corresponds to the JSON property writeTimeThisSession
1699 1700 1701 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1699 def write_time_this_session @write_time_this_session end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1706 def update!(**args) @bytes_read_this_session = args[:bytes_read_this_session] if args.key?(:bytes_read_this_session) @bytes_written_this_session = args[:bytes_written_this_session] if args.key?(:bytes_written_this_session) @discard_time_this_session = args[:discard_time_this_session] if args.key?(:discard_time_this_session) @health = args[:health] if args.key?(:health) @io_time_this_session = args[:io_time_this_session] if args.key?(:io_time_this_session) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @model = args[:model] if args.key?(:model) @read_time_this_session = args[:read_time_this_session] if args.key?(:read_time_this_session) @serial_number = args[:serial_number] if args.key?(:serial_number) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @type = args[:type] if args.key?(:type) @volume_ids = args[:volume_ids] if args.key?(:volume_ids) @write_time_this_session = args[:write_time_this_session] if args.key?(:write_time_this_session) end |