Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DiskInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Status of the single storage device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1DiskInfo

Returns a new instance of GoogleChromeManagementV1DiskInfo.



1670
1671
1672
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_read_this_sessionFixnum

Output only. Number of bytes read since last boot. Corresponds to the JSON property bytesReadThisSession

Returns:

  • (Fixnum)


1606
1607
1608
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1606

def bytes_read_this_session
  @bytes_read_this_session
end

#bytes_written_this_sessionFixnum

Output only. Number of bytes written since last boot. Corresponds to the JSON property bytesWrittenThisSession

Returns:

  • (Fixnum)


1611
1612
1613
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1611

def bytes_written_this_session
  @bytes_written_this_session
end

#discard_time_this_sessionString

Output only. Time spent discarding since last boot. Discarding is writing to clear blocks which are no longer in use. Supported on kernels 4.18+. Corresponds to the JSON property discardTimeThisSession

Returns:

  • (String)


1617
1618
1619
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1617

def discard_time_this_session
  @discard_time_this_session
end

#healthString

Output only. Disk health. Corresponds to the JSON property health

Returns:

  • (String)


1622
1623
1624
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1622

def health
  @health
end

#io_time_this_sessionString

Output only. Counts the time the disk and queue were busy, so unlike the fields above, parallel requests are not counted multiple times. Corresponds to the JSON property ioTimeThisSession

Returns:

  • (String)


1628
1629
1630
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1628

def io_time_this_session
  @io_time_this_session
end

#manufacturerString

Output only. Disk manufacturer. Corresponds to the JSON property manufacturer

Returns:

  • (String)


1633
1634
1635
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1633

def manufacturer
  @manufacturer
end

#modelString

Output only. Disk model. Corresponds to the JSON property model

Returns:

  • (String)


1638
1639
1640
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1638

def model
  @model
end

#read_time_this_sessionString

Output only. Time spent reading from disk since last boot. Corresponds to the JSON property readTimeThisSession

Returns:

  • (String)


1643
1644
1645
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1643

def read_time_this_session
  @read_time_this_session
end

#serial_numberString

Output only. Disk serial number. Corresponds to the JSON property serialNumber

Returns:

  • (String)


1648
1649
1650
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1648

def serial_number
  @serial_number
end

#size_bytesFixnum

Output only. Disk size. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


1653
1654
1655
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1653

def size_bytes
  @size_bytes
end

#typeString

Output only. Disk type: eMMC / NVMe / ATA / SCSI. Corresponds to the JSON property type

Returns:

  • (String)


1658
1659
1660
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1658

def type
  @type
end

#volume_idsArray<String>

Output only. Disk volumes. Corresponds to the JSON property volumeIds

Returns:

  • (Array<String>)


1663
1664
1665
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1663

def volume_ids
  @volume_ids
end

#write_time_this_sessionString

Output only. Time spent writing to disk since last boot. Corresponds to the JSON property writeTimeThisSession

Returns:

  • (String)


1668
1669
1670
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1668

def write_time_this_session
  @write_time_this_session
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1675

def update!(**args)
  @bytes_read_this_session = args[:bytes_read_this_session] if args.key?(:bytes_read_this_session)
  @bytes_written_this_session = args[:bytes_written_this_session] if args.key?(:bytes_written_this_session)
  @discard_time_this_session = args[:discard_time_this_session] if args.key?(:discard_time_this_session)
  @health = args[:health] if args.key?(:health)
  @io_time_this_session = args[:io_time_this_session] if args.key?(:io_time_this_session)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @model = args[:model] if args.key?(:model)
  @read_time_this_session = args[:read_time_this_session] if args.key?(:read_time_this_session)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @type = args[:type] if args.key?(:type)
  @volume_ids = args[:volume_ids] if args.key?(:volume_ids)
  @write_time_this_session = args[:write_time_this_session] if args.key?(:write_time_this_session)
end