Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FindInstalledAppProfilesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1FindInstalledAppProfilesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response containing a list of profiles with queried app installed.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to specify the next page of the request.
-
#profiles ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ProfileAppInstallInstance>
A list of profiles which have the app installed.
-
#total_size ⇒ Fixnum
Total number of profiles matching request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1FindInstalledAppProfilesResponse
constructor
A new instance of GoogleChromeManagementV1FindInstalledAppProfilesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1FindInstalledAppProfilesResponse
Returns a new instance of GoogleChromeManagementV1FindInstalledAppProfilesResponse.
1970 1971 1972 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to specify the next page of the request.
Corresponds to the JSON property nextPageToken
1957 1958 1959 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1957 def next_page_token @next_page_token end |
#profiles ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ProfileAppInstallInstance>
A list of profiles which have the app installed. Sorted in ascending
alphabetical order on the profile.Email field.
Corresponds to the JSON property profiles
1963 1964 1965 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1963 def profiles @profiles end |
#total_size ⇒ Fixnum
Total number of profiles matching request.
Corresponds to the JSON property totalSize
1968 1969 1970 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1968 def total_size @total_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1975 1976 1977 1978 1979 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 1975 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @profiles = args[:profiles] if args.key?(:profiles) @total_size = args[:total_size] if args.key?(:total_size) end |