Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Details about the network device. * This field provides device information, which is static and will not change over time. * Data for this field is controlled via policy: ReportNetworkDeviceConfiguration * Data Collection Frequency: At device startup * Default Data Reporting Frequency: At device startup - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: N/A

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1NetworkDevice

Returns a new instance of GoogleChromeManagementV1NetworkDevice.



2516
2517
2518
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2516

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#iccidString

Output only. The integrated circuit card ID associated with the device's sim card. Corresponds to the JSON property iccid

Returns:

  • (String)


2489
2490
2491
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2489

def iccid
  @iccid
end

#imeiString

Output only. IMEI (if applicable) of the corresponding network device. Corresponds to the JSON property imei

Returns:

  • (String)


2494
2495
2496
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2494

def imei
  @imei
end

#mac_addressString

Output only. MAC address (if applicable) of the corresponding network device. Corresponds to the JSON property macAddress

Returns:

  • (String)


2499
2500
2501
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2499

def mac_address
  @mac_address
end

#mdnString

Output only. The mobile directory number associated with the device's sim card. Corresponds to the JSON property mdn

Returns:

  • (String)


2504
2505
2506
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2504

def mdn
  @mdn
end

#meidString

Output only. MEID (if applicable) of the corresponding network device. Corresponds to the JSON property meid

Returns:

  • (String)


2509
2510
2511
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2509

def meid
  @meid
end

#typeString

Output only. Network device type. Corresponds to the JSON property type

Returns:

  • (String)


2514
2515
2516
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2514

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2521
2522
2523
2524
2525
2526
2527
2528
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2521

def update!(**args)
  @iccid = args[:iccid] if args.key?(:iccid)
  @imei = args[:imei] if args.key?(:imei)
  @mac_address = args[:mac_address] if args.key?(:mac_address)
  @mdn = args[:mdn] if args.key?(:mdn)
  @meid = args[:meid] if args.key?(:meid)
  @type = args[:type] if args.key?(:type)
end