Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkStatusReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkStatusReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
State of visible/configured networks. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportNetworkStatus * Data Collection Frequency: 60 minutes * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: Yes * Granular permission needed: TELEMETRY_API_NETWORK_REPORT
Instance Attribute Summary collapse
-
#connection_state ⇒ String
Output only.
-
#connection_type ⇒ String
Output only.
-
#encryption_on ⇒ Boolean
(also: #encryption_on?)
Output only.
-
#gateway_ip_address ⇒ String
Output only.
-
#gateway_ipv6_address ⇒ String
Output only.
-
#guid ⇒ String
Output only.
-
#ipv6_address ⇒ Array<String>
Output only.
-
#lan_ip_address ⇒ String
Output only.
-
#link_down_speed_kbps ⇒ Fixnum
Output only.
-
#metered ⇒ Boolean
(also: #metered?)
Output only.
-
#receiving_bit_rate_mbps ⇒ Fixnum
Output only.
-
#report_time ⇒ String
Output only.
-
#sample_frequency ⇒ String
Output only.
-
#signal_strength_dbm ⇒ Fixnum
Output only.
-
#transmission_bit_rate_mbps ⇒ Fixnum
Output only.
-
#transmission_power_dbm ⇒ Fixnum
Output only.
-
#wifi_link_quality ⇒ Fixnum
Output only.
-
#wifi_power_management_enabled ⇒ Boolean
(also: #wifi_power_management_enabled?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1NetworkStatusReport
constructor
A new instance of GoogleChromeManagementV1NetworkStatusReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1NetworkStatusReport
Returns a new instance of GoogleChromeManagementV1NetworkStatusReport.
2693 2694 2695 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2693 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_state ⇒ String
Output only. Current connection state of the network.
Corresponds to the JSON property connectionState
2600 2601 2602 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2600 def connection_state @connection_state end |
#connection_type ⇒ String
Output only. Network connection type.
Corresponds to the JSON property connectionType
2605 2606 2607 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2605 def connection_type @connection_type end |
#encryption_on ⇒ Boolean Also known as: encryption_on?
Output only. Whether the wifi encryption key is turned off.
Corresponds to the JSON property encryptionOn
2610 2611 2612 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2610 def encryption_on @encryption_on end |
#gateway_ip_address ⇒ String
Output only. Gateway IP address.
Corresponds to the JSON property gatewayIpAddress
2616 2617 2618 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2616 def gateway_ip_address @gateway_ip_address end |
#gateway_ipv6_address ⇒ String
Output only. The gateway IPv6 for this interface, if detected
Corresponds to the JSON property gatewayIpv6Address
2621 2622 2623 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2621 def gateway_ipv6_address @gateway_ipv6_address end |
#guid ⇒ String
Output only. Network connection guid.
Corresponds to the JSON property guid
2626 2627 2628 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2626 def guid @guid end |
#ipv6_address ⇒ Array<String>
Output only. IPv6 addresses assigned to this network, if any. Each address is
a string in standard IPv6 text representation (e.g., "2001:db8::1").
Corresponds to the JSON property ipv6Address
2632 2633 2634 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2632 def ipv6_address @ipv6_address end |
#lan_ip_address ⇒ String
Output only. LAN IP address.
Corresponds to the JSON property lanIpAddress
2637 2638 2639 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2637 def lan_ip_address @lan_ip_address end |
#link_down_speed_kbps ⇒ Fixnum
Output only. The maximum downstream bandwidth in Kilobits per second (Kbps),
if reported by the network interface or connection.
Corresponds to the JSON property linkDownSpeedKbps
2643 2644 2645 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2643 def link_down_speed_kbps @link_down_speed_kbps end |
#metered ⇒ Boolean Also known as: metered?
Output only. Whether the network was detected as metered.
Corresponds to the JSON property metered
2648 2649 2650 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2648 def metered @metered end |
#receiving_bit_rate_mbps ⇒ Fixnum
Output only. Receiving bit rate measured in Megabits per second.
Corresponds to the JSON property receivingBitRateMbps
2654 2655 2656 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2654 def receiving_bit_rate_mbps @receiving_bit_rate_mbps end |
#report_time ⇒ String
Output only. Time at which the network state was reported.
Corresponds to the JSON property reportTime
2659 2660 2661 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2659 def report_time @report_time end |
#sample_frequency ⇒ String
Output only. Frequency the report is sampled.
Corresponds to the JSON property sampleFrequency
2664 2665 2666 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2664 def sample_frequency @sample_frequency end |
#signal_strength_dbm ⇒ Fixnum
Output only. Signal strength for wireless networks measured in decibels.
Corresponds to the JSON property signalStrengthDbm
2669 2670 2671 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2669 def signal_strength_dbm @signal_strength_dbm end |
#transmission_bit_rate_mbps ⇒ Fixnum
Output only. Transmission bit rate measured in Megabits per second.
Corresponds to the JSON property transmissionBitRateMbps
2674 2675 2676 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2674 def transmission_bit_rate_mbps @transmission_bit_rate_mbps end |
#transmission_power_dbm ⇒ Fixnum
Output only. Transmission power measured in decibels.
Corresponds to the JSON property transmissionPowerDbm
2679 2680 2681 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2679 def transmission_power_dbm @transmission_power_dbm end |
#wifi_link_quality ⇒ Fixnum
Output only. Wifi link quality. Value ranges from [0, 70]. 0 indicates no
signal and 70 indicates a strong signal.
Corresponds to the JSON property wifiLinkQuality
2685 2686 2687 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2685 def wifi_link_quality @wifi_link_quality end |
#wifi_power_management_enabled ⇒ Boolean Also known as: wifi_power_management_enabled?
Output only. Wifi power management enabled
Corresponds to the JSON property wifiPowerManagementEnabled
2690 2691 2692 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2690 def wifi_power_management_enabled @wifi_power_management_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2698 def update!(**args) @connection_state = args[:connection_state] if args.key?(:connection_state) @connection_type = args[:connection_type] if args.key?(:connection_type) @encryption_on = args[:encryption_on] if args.key?(:encryption_on) @gateway_ip_address = args[:gateway_ip_address] if args.key?(:gateway_ip_address) @gateway_ipv6_address = args[:gateway_ipv6_address] if args.key?(:gateway_ipv6_address) @guid = args[:guid] if args.key?(:guid) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @lan_ip_address = args[:lan_ip_address] if args.key?(:lan_ip_address) @link_down_speed_kbps = args[:link_down_speed_kbps] if args.key?(:link_down_speed_kbps) @metered = args[:metered] if args.key?(:metered) @receiving_bit_rate_mbps = args[:receiving_bit_rate_mbps] if args.key?(:receiving_bit_rate_mbps) @report_time = args[:report_time] if args.key?(:report_time) @sample_frequency = args[:sample_frequency] if args.key?(:sample_frequency) @signal_strength_dbm = args[:signal_strength_dbm] if args.key?(:signal_strength_dbm) @transmission_bit_rate_mbps = args[:transmission_bit_rate_mbps] if args.key?(:transmission_bit_rate_mbps) @transmission_power_dbm = args[:transmission_power_dbm] if args.key?(:transmission_power_dbm) @wifi_link_quality = args[:wifi_link_quality] if args.key?(:wifi_link_quality) @wifi_power_management_enabled = args[:wifi_power_management_enabled] if args.key?(:wifi_power_management_enabled) end |