Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Contains information regarding the current OS update status. * This field is telemetry information and this will change over time as the device is utilized.

  • Data for this field is controlled via policy: ReportDeviceOsUpdateStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: No * Reported for affiliated users only: N/A * Granular permission needed: TELEMETRY_API_OS_REPORT

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1OsUpdateStatus

Returns a new instance of GoogleChromeManagementV1OsUpdateStatus.



2798
2799
2800
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_reboot_timeString

Output only. Timestamp of the last reboot. Corresponds to the JSON property lastRebootTime

Returns:

  • (String)


2767
2768
2769
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2767

def last_reboot_time
  @last_reboot_time
end

#last_update_check_timeString

Output only. Timestamp of the last update check. Corresponds to the JSON property lastUpdateCheckTime

Returns:

  • (String)


2772
2773
2774
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2772

def last_update_check_time
  @last_update_check_time
end

#last_update_timeString

Output only. Timestamp of the last successful update. Corresponds to the JSON property lastUpdateTime

Returns:

  • (String)


2777
2778
2779
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2777

def last_update_time
  @last_update_time
end

#new_platform_versionString

Output only. New platform version of the os image being downloaded and applied. It is only set when update status is OS_IMAGE_DOWNLOAD_IN_PROGRESS or OS_UPDATE_NEED_REBOOT. Note this could be a dummy "0.0.0.0" for OS_UPDATE_NEED_REBOOT status for some edge cases, e.g. update engine is restarted without a reboot. Corresponds to the JSON property newPlatformVersion

Returns:

  • (String)


2786
2787
2788
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2786

def new_platform_version
  @new_platform_version
end

#new_requested_platform_versionString

Output only. New requested platform version from the pending updated kiosk app. Corresponds to the JSON property newRequestedPlatformVersion

Returns:

  • (String)


2791
2792
2793
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2791

def new_requested_platform_version
  @new_requested_platform_version
end

#update_stateString

Output only. Current state of the os update. Corresponds to the JSON property updateState

Returns:

  • (String)


2796
2797
2798
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2796

def update_state
  @update_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2803
2804
2805
2806
2807
2808
2809
2810
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2803

def update!(**args)
  @last_reboot_time = args[:last_reboot_time] if args.key?(:last_reboot_time)
  @last_update_check_time = args[:last_update_check_time] if args.key?(:last_update_check_time)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @new_platform_version = args[:new_platform_version] if args.key?(:new_platform_version)
  @new_requested_platform_version = args[:new_requested_platform_version] if args.key?(:new_requested_platform_version)
  @update_state = args[:update_state] if args.key?(:update_state)
end