Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Report for CountPrintJobsByPrinter, contains statistics on printer usage. Contains the total number of print jobs initiated with this printer, the number of users and the number of devices that have initiated at least one print job with this printer.
Instance Attribute Summary collapse
-
#device_count ⇒ Fixnum
Number of chrome devices that have been used to send print jobs to the specified printer.
-
#job_count ⇒ Fixnum
Number of print jobs sent to the printer.
-
#printer ⇒ String
Printer name.
-
#printer_id ⇒ String
Printer API ID.
-
#printer_model ⇒ String
Printer model.
-
#user_count ⇒ Fixnum
Number of users that have sent print jobs to the printer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1PrinterReport
constructor
A new instance of GoogleChromeManagementV1PrinterReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1PrinterReport
Returns a new instance of GoogleChromeManagementV1PrinterReport.
2968 2969 2970 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_count ⇒ Fixnum
Number of chrome devices that have been used to send print jobs to the
specified printer.
Corresponds to the JSON property deviceCount
2941 2942 2943 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2941 def device_count @device_count end |
#job_count ⇒ Fixnum
Number of print jobs sent to the printer.
Corresponds to the JSON property jobCount
2946 2947 2948 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2946 def job_count @job_count end |
#printer ⇒ String
Printer name.
Corresponds to the JSON property printer
2951 2952 2953 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2951 def printer @printer end |
#printer_id ⇒ String
Printer API ID.
Corresponds to the JSON property printerId
2956 2957 2958 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2956 def printer_id @printer_id end |
#printer_model ⇒ String
Printer model.
Corresponds to the JSON property printerModel
2961 2962 2963 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2961 def printer_model @printer_model end |
#user_count ⇒ Fixnum
Number of users that have sent print jobs to the printer.
Corresponds to the JSON property userCount
2966 2967 2968 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2966 def user_count @user_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2973 2974 2975 2976 2977 2978 2979 2980 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2973 def update!(**args) @device_count = args[:device_count] if args.key?(:device_count) @job_count = args[:job_count] if args.key?(:job_count) @printer = args[:printer] if args.key?(:printer) @printer_id = args[:printer_id] if args.key?(:printer_id) @printer_model = args[:printer_model] if args.key?(:printer_model) @user_count = args[:user_count] if args.key?(:user_count) end |