Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PrinterReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Report for CountPrintJobsByPrinter, contains statistics on printer usage. Contains the total number of print jobs initiated with this printer, the number of users and the number of devices that have initiated at least one print job with this printer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1PrinterReport

Returns a new instance of GoogleChromeManagementV1PrinterReport.



2936
2937
2938
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2936

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_countFixnum

Number of chrome devices that have been used to send print jobs to the specified printer. Corresponds to the JSON property deviceCount

Returns:

  • (Fixnum)


2909
2910
2911
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2909

def device_count
  @device_count
end

#job_countFixnum

Number of print jobs sent to the printer. Corresponds to the JSON property jobCount

Returns:

  • (Fixnum)


2914
2915
2916
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2914

def job_count
  @job_count
end

#printerString

Printer name. Corresponds to the JSON property printer

Returns:

  • (String)


2919
2920
2921
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2919

def printer
  @printer
end

#printer_idString

Printer API ID. Corresponds to the JSON property printerId

Returns:

  • (String)


2924
2925
2926
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2924

def printer_id
  @printer_id
end

#printer_modelString

Printer model. Corresponds to the JSON property printerModel

Returns:

  • (String)


2929
2930
2931
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2929

def printer_model
  @printer_model
end

#user_countFixnum

Number of users that have sent print jobs to the printer. Corresponds to the JSON property userCount

Returns:

  • (Fixnum)


2934
2935
2936
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2934

def user_count
  @user_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2941
2942
2943
2944
2945
2946
2947
2948
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 2941

def update!(**args)
  @device_count = args[:device_count] if args.key?(:device_count)
  @job_count = args[:job_count] if args.key?(:job_count)
  @printer = args[:printer] if args.key?(:printer)
  @printer_id = args[:printer_id] if args.key?(:printer_id)
  @printer_model = args[:printer_model] if args.key?(:printer_model)
  @user_count = args[:user_count] if args.key?(:user_count)
end