Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RiskAssessment
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RiskAssessment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Risk assessment for a Chrome extension.
Instance Attribute Summary collapse
-
#assessment ⇒ String
Risk assessment for the extension.
-
#details_url ⇒ String
A URL that a user can navigate to for more information about the risk assessment.
-
#version ⇒ String
The version of the extension that this assessment applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1RiskAssessment
constructor
A new instance of GoogleChromeManagementV1RiskAssessment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1RiskAssessment
Returns a new instance of GoogleChromeManagementV1RiskAssessment.
3042 3043 3044 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assessment ⇒ String
Risk assessment for the extension. Currently, this is a numerical value, and
its interpretation is specific to each risk assessment provider.
Corresponds to the JSON property assessment
3029 3030 3031 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3029 def assessment @assessment end |
#details_url ⇒ String
A URL that a user can navigate to for more information about the risk
assessment.
Corresponds to the JSON property detailsUrl
3035 3036 3037 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3035 def details_url @details_url end |
#version ⇒ String
The version of the extension that this assessment applies to.
Corresponds to the JSON property version
3040 3041 3042 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3040 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3047 3048 3049 3050 3051 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3047 def update!(**args) @assessment = args[:assessment] if args.key?(:assessment) @details_url = args[:details_url] if args.key?(:details_url) @version = args[:version] if args.key?(:version) end |