Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryDevice
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryDevice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Telemetry data collected from a managed device. * Granular permission needed: TELEMETRY_API_DEVICE
Instance Attribute Summary collapse
-
#app_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppReport>
Output only.
-
#audio_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AudioStatusReport>
Output only.
-
#battery_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryInfo>
Output only.
-
#battery_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryStatusReport>
Output only.
-
#boot_performance_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BootPerformanceReport>
Output only.
-
#cpu_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuInfo>
Output only.
-
#cpu_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuStatusReport>
Output only.
-
#customer ⇒ String
Output only.
-
#device_id ⇒ String
Output only.
-
#graphics_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsInfo
Information of the graphics subsystem.
-
#graphics_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsStatusReport>
Output only.
-
#heartbeat_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1HeartbeatStatusReport>
Output only.
-
#kiosk_app_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1KioskAppStatusReport>
Output only.
-
#memory_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryInfo
Memory information of a device.
-
#memory_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryStatusReport>
Output only.
-
#name ⇒ String
Output only.
-
#network_bandwidth_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkBandwidthReport>
Output only.
-
#network_diagnostics_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkDiagnosticsReport>
Output only.
-
#network_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkInfo
Network device information.
-
#network_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkStatusReport>
Output only.
-
#org_unit_id ⇒ String
Output only.
-
#os_update_status ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus>
Output only.
-
#peripherals_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PeripheralsReport>
Output only.
-
#runtime_counters_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RuntimeCountersReport>
Output only.
-
#serial_number ⇒ String
Output only.
-
#storage_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageInfo
Status data for storage.
-
#storage_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageStatusReport>
Output only.
-
#thunderbolt_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ThunderboltInfo>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryDevice
constructor
A new instance of GoogleChromeManagementV1TelemetryDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryDevice
Returns a new instance of GoogleChromeManagementV1TelemetryDevice.
3610 3611 3612 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppReport>
Output only. App reports collected periodically sorted in a decreasing order
of report_time.
Corresponds to the JSON property appReport
3428 3429 3430 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3428 def app_report @app_report end |
#audio_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AudioStatusReport>
Output only. Audio reports collected periodically sorted in a decreasing order
of report_time.
Corresponds to the JSON property audioStatusReport
3434 3435 3436 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3434 def audio_status_report @audio_status_report end |
#battery_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryInfo>
Output only. Information on battery specs for the device.
Corresponds to the JSON property batteryInfo
3439 3440 3441 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3439 def battery_info @battery_info end |
#battery_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryStatusReport>
Output only. Battery reports collected periodically.
Corresponds to the JSON property batteryStatusReport
3444 3445 3446 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3444 def battery_status_report @battery_status_report end |
#boot_performance_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BootPerformanceReport>
Output only. Boot performance reports of the device.
Corresponds to the JSON property bootPerformanceReport
3449 3450 3451 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3449 def boot_performance_report @boot_performance_report end |
#cpu_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuInfo>
Output only. Information regarding CPU specs for the device.
Corresponds to the JSON property cpuInfo
3454 3455 3456 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3454 def cpu_info @cpu_info end |
#cpu_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuStatusReport>
Output only. CPU status reports collected periodically sorted in a decreasing
order of report_time.
Corresponds to the JSON property cpuStatusReport
3460 3461 3462 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3460 def cpu_status_report @cpu_status_report end |
#customer ⇒ String
Output only. Google Workspace Customer whose enterprise enrolled the device.
Corresponds to the JSON property customer
3465 3466 3467 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3465 def customer @customer end |
#device_id ⇒ String
Output only. The unique Directory API ID of the device. This value is the same
as the Admin Console's Directory API ID in the ChromeOS Devices tab
Corresponds to the JSON property deviceId
3471 3472 3473 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3471 def device_id @device_id end |
#graphics_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsInfo
Information of the graphics subsystem. * This field provides device
information, which is static and will not change over time. * Data for this
field is controlled via policy: ReportDeviceGraphicsStatus * Data
Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3
hours - Policy Controlled: Yes * Cache: If the device is offline, the
collected data is stored locally, and will be reported when the device is next
online: No * Reported for affiliated users only: N/A * Granular permission
needed: TELEMETRY_API_GRAPHICS_INFO
Corresponds to the JSON property graphicsInfo
3484 3485 3486 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3484 def graphics_info @graphics_info end |
#graphics_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsStatusReport>
Output only. Graphics reports collected periodically.
Corresponds to the JSON property graphicsStatusReport
3489 3490 3491 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3489 def graphics_status_report @graphics_status_report end |
#heartbeat_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1HeartbeatStatusReport>
Output only. Heartbeat status report containing timestamps periodically sorted
in decreasing order of report_time
Corresponds to the JSON property heartbeatStatusReport
3495 3496 3497 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3495 def heartbeat_status_report @heartbeat_status_report end |
#kiosk_app_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1KioskAppStatusReport>
Output only. Kiosk app status report for the kiosk device
Corresponds to the JSON property kioskAppStatusReport
3500 3501 3502 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3500 def kiosk_app_status_report @kiosk_app_status_report end |
#memory_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryInfo
Memory information of a device. * This field has both telemetry and device
information: - totalRamBytes - Device information - availableRamBytes -
Telemetry information - totalMemoryEncryption - Device information * Data
for this field is controlled via policy: ReportDeviceMemoryInfo * Data Collection
Frequency: - totalRamBytes - Only at upload - availableRamBytes - Every 10
minutes - totalMemoryEncryption - at device startup * Default Data Reporting
Frequency: - totalRamBytes - 3 hours - availableRamBytes - 3 hours -
totalMemoryEncryption - at device startup - Policy Controlled: Yes * Cache:
If the device is offline, the collected data is stored locally, and will be
reported when the device is next online: only for totalMemoryEncryption *
Reported for affiliated users only: N/A * Granular permission needed:
TELEMETRY_API_MEMORY_INFO
Corresponds to the JSON property memoryInfo
3517 3518 3519 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3517 def memory_info @memory_info end |
#memory_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryStatusReport>
Output only. Memory status reports collected periodically sorted decreasing by
report_time.
Corresponds to the JSON property memoryStatusReport
3523 3524 3525 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3523 def memory_status_report @memory_status_report end |
#name ⇒ String
Output only. Resource name of the device.
Corresponds to the JSON property name
3528 3529 3530 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3528 def name @name end |
#network_bandwidth_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkBandwidthReport>
Output only. Network bandwidth reports collected periodically sorted in a
decreasing order of report_time.
Corresponds to the JSON property networkBandwidthReport
3534 3535 3536 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3534 def network_bandwidth_report @network_bandwidth_report end |
#network_diagnostics_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkDiagnosticsReport>
Output only. Network diagnostics collected periodically.
Corresponds to the JSON property networkDiagnosticsReport
3539 3540 3541 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3539 def network_diagnostics_report @network_diagnostics_report end |
#network_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkInfo
Network device information. * This field provides device information, which is
static and will not change over time. * Data for this field is controlled via
policy: ReportNetworkDeviceConfiguration * Data Collection Frequency: At
device startup * Default Data Reporting Frequency: At device startup - Policy
Controlled: Yes * Cache: If the device is offline, the collected data is
stored locally, and will be reported when the device is next online: Yes *
Reported for affiliated users only: N/A * Granular permission needed:
TELEMETRY_API_NETWORK_INFO
Corresponds to the JSON property networkInfo
3552 3553 3554 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3552 def network_info @network_info end |
#network_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkStatusReport>
Output only. Network specs collected periodically.
Corresponds to the JSON property networkStatusReport
3557 3558 3559 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3557 def network_status_report @network_status_report end |
#org_unit_id ⇒ String
Output only. Organization unit ID of the device.
Corresponds to the JSON property orgUnitId
3562 3563 3564 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3562 def org_unit_id @org_unit_id end |
#os_update_status ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus>
Output only. Contains relevant information regarding ChromeOS update status.
Corresponds to the JSON property osUpdateStatus
3567 3568 3569 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3567 def os_update_status @os_update_status end |
#peripherals_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PeripheralsReport>
Output only. Peripherals reports collected periodically sorted in a decreasing
order of report_time.
Corresponds to the JSON property peripheralsReport
3573 3574 3575 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3573 def peripherals_report @peripherals_report end |
#runtime_counters_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RuntimeCountersReport>
Output only. Runtime counters reports collected device lifetime runtime, as
well as the counts of S0->S3, S0->S4, and S0->S5 transitions, meaning entering
into sleep, hibernation, and power-off states
Corresponds to the JSON property runtimeCountersReport
3580 3581 3582 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3580 def runtime_counters_report @runtime_counters_report end |
#serial_number ⇒ String
Output only. Device serial number. This value is the same as the Admin Console'
s Serial Number in the ChromeOS Devices tab.
Corresponds to the JSON property serialNumber
3586 3587 3588 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3586 def serial_number @serial_number end |
#storage_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageInfo
Status data for storage. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDeviceStorageStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes
- Cache: If the device is offline, the collected data is stored locally, and
will be reported when the device is next online: No * Reported for affiliated
users only: N/A * Granular permission needed: TELEMETRY_API_STORAGE_INFO
Corresponds to the JSON property
storageInfo
3598 3599 3600 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3598 def storage_info @storage_info end |
#storage_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageStatusReport>
Output only. Storage reports collected periodically.
Corresponds to the JSON property storageStatusReport
3603 3604 3605 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3603 def storage_status_report @storage_status_report end |
#thunderbolt_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ThunderboltInfo>
Output only. Information on Thunderbolt bus.
Corresponds to the JSON property thunderboltInfo
3608 3609 3610 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3608 def thunderbolt_info @thunderbolt_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3615 def update!(**args) @app_report = args[:app_report] if args.key?(:app_report) @audio_status_report = args[:audio_status_report] if args.key?(:audio_status_report) @battery_info = args[:battery_info] if args.key?(:battery_info) @battery_status_report = args[:battery_status_report] if args.key?(:battery_status_report) @boot_performance_report = args[:boot_performance_report] if args.key?(:boot_performance_report) @cpu_info = args[:cpu_info] if args.key?(:cpu_info) @cpu_status_report = args[:cpu_status_report] if args.key?(:cpu_status_report) @customer = args[:customer] if args.key?(:customer) @device_id = args[:device_id] if args.key?(:device_id) @graphics_info = args[:graphics_info] if args.key?(:graphics_info) @graphics_status_report = args[:graphics_status_report] if args.key?(:graphics_status_report) @heartbeat_status_report = args[:heartbeat_status_report] if args.key?(:heartbeat_status_report) @kiosk_app_status_report = args[:kiosk_app_status_report] if args.key?(:kiosk_app_status_report) @memory_info = args[:memory_info] if args.key?(:memory_info) @memory_status_report = args[:memory_status_report] if args.key?(:memory_status_report) @name = args[:name] if args.key?(:name) @network_bandwidth_report = args[:network_bandwidth_report] if args.key?(:network_bandwidth_report) @network_diagnostics_report = args[:network_diagnostics_report] if args.key?(:network_diagnostics_report) @network_info = args[:network_info] if args.key?(:network_info) @network_status_report = args[:network_status_report] if args.key?(:network_status_report) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @os_update_status = args[:os_update_status] if args.key?(:os_update_status) @peripherals_report = args[:peripherals_report] if args.key?(:peripherals_report) @runtime_counters_report = args[:runtime_counters_report] if args.key?(:runtime_counters_report) @serial_number = args[:serial_number] if args.key?(:serial_number) @storage_info = args[:storage_info] if args.key?(:storage_info) @storage_status_report = args[:storage_status_report] if args.key?(:storage_status_report) @thunderbolt_info = args[:thunderbolt_info] if args.key?(:thunderbolt_info) end |