Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryDevice
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryDevice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Telemetry data collected from a managed device. * Granular permission needed: TELEMETRY_API_DEVICE
Instance Attribute Summary collapse
-
#app_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppReport>
Output only.
-
#audio_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AudioStatusReport>
Output only.
-
#battery_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryInfo>
Output only.
-
#battery_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryStatusReport>
Output only.
-
#boot_performance_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BootPerformanceReport>
Output only.
-
#cpu_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuInfo>
Output only.
-
#cpu_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuStatusReport>
Output only.
-
#customer ⇒ String
Output only.
-
#device_id ⇒ String
Output only.
-
#graphics_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsInfo
Information of the graphics subsystem.
-
#graphics_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsStatusReport>
Output only.
-
#heartbeat_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1HeartbeatStatusReport>
Output only.
-
#kiosk_app_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1KioskAppStatusReport>
Output only.
-
#memory_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryInfo
Memory information of a device.
-
#memory_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryStatusReport>
Output only.
-
#name ⇒ String
Output only.
-
#network_bandwidth_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkBandwidthReport>
Output only.
-
#network_diagnostics_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkDiagnosticsReport>
Output only.
-
#network_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkInfo
Network device information.
-
#network_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkStatusReport>
Output only.
-
#org_unit_id ⇒ String
Output only.
-
#os_update_status ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus>
Output only.
-
#peripherals_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PeripheralsReport>
Output only.
-
#runtime_counters_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RuntimeCountersReport>
Output only.
-
#serial_number ⇒ String
Output only.
-
#storage_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageInfo
Status data for storage.
-
#storage_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageStatusReport>
Output only.
-
#thunderbolt_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ThunderboltInfo>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryDevice
constructor
A new instance of GoogleChromeManagementV1TelemetryDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryDevice
Returns a new instance of GoogleChromeManagementV1TelemetryDevice.
3573 3574 3575 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3573 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppReport>
Output only. App reports collected periodically sorted in a decreasing order
of report_time.
Corresponds to the JSON property appReport
3391 3392 3393 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3391 def app_report @app_report end |
#audio_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AudioStatusReport>
Output only. Audio reports collected periodically sorted in a decreasing order
of report_time.
Corresponds to the JSON property audioStatusReport
3397 3398 3399 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3397 def audio_status_report @audio_status_report end |
#battery_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryInfo>
Output only. Information on battery specs for the device.
Corresponds to the JSON property batteryInfo
3402 3403 3404 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3402 def battery_info @battery_info end |
#battery_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BatteryStatusReport>
Output only. Battery reports collected periodically.
Corresponds to the JSON property batteryStatusReport
3407 3408 3409 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3407 def battery_status_report @battery_status_report end |
#boot_performance_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1BootPerformanceReport>
Output only. Boot performance reports of the device.
Corresponds to the JSON property bootPerformanceReport
3412 3413 3414 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3412 def boot_performance_report @boot_performance_report end |
#cpu_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuInfo>
Output only. Information regarding CPU specs for the device.
Corresponds to the JSON property cpuInfo
3417 3418 3419 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3417 def cpu_info @cpu_info end |
#cpu_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1CpuStatusReport>
Output only. CPU status reports collected periodically sorted in a decreasing
order of report_time.
Corresponds to the JSON property cpuStatusReport
3423 3424 3425 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3423 def cpu_status_report @cpu_status_report end |
#customer ⇒ String
Output only. Google Workspace Customer whose enterprise enrolled the device.
Corresponds to the JSON property customer
3428 3429 3430 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3428 def customer @customer end |
#device_id ⇒ String
Output only. The unique Directory API ID of the device. This value is the same
as the Admin Console's Directory API ID in the ChromeOS Devices tab
Corresponds to the JSON property deviceId
3434 3435 3436 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3434 def device_id @device_id end |
#graphics_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsInfo
Information of the graphics subsystem. * This field provides device
information, which is static and will not change over time. * Data for this
field is controlled via policy: ReportDeviceGraphicsStatus * Data
Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3
hours - Policy Controlled: Yes * Cache: If the device is offline, the
collected data is stored locally, and will be reported when the device is next
online: No * Reported for affiliated users only: N/A * Granular permission
needed: TELEMETRY_API_GRAPHICS_INFO
Corresponds to the JSON property graphicsInfo
3447 3448 3449 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3447 def graphics_info @graphics_info end |
#graphics_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1GraphicsStatusReport>
Output only. Graphics reports collected periodically.
Corresponds to the JSON property graphicsStatusReport
3452 3453 3454 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3452 def graphics_status_report @graphics_status_report end |
#heartbeat_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1HeartbeatStatusReport>
Output only. Heartbeat status report containing timestamps periodically sorted
in decreasing order of report_time
Corresponds to the JSON property heartbeatStatusReport
3458 3459 3460 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3458 def heartbeat_status_report @heartbeat_status_report end |
#kiosk_app_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1KioskAppStatusReport>
Output only. Kiosk app status report for the kiosk device
Corresponds to the JSON property kioskAppStatusReport
3463 3464 3465 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3463 def kiosk_app_status_report @kiosk_app_status_report end |
#memory_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryInfo
Memory information of a device. * This field has both telemetry and device
information: - totalRamBytes - Device information - availableRamBytes -
Telemetry information - totalMemoryEncryption - Device information * Data
for this field is controlled via policy: ReportDeviceMemoryInfo * Data Collection
Frequency: - totalRamBytes - Only at upload - availableRamBytes - Every 10
minutes - totalMemoryEncryption - at device startup * Default Data Reporting
Frequency: - totalRamBytes - 3 hours - availableRamBytes - 3 hours -
totalMemoryEncryption - at device startup - Policy Controlled: Yes * Cache:
If the device is offline, the collected data is stored locally, and will be
reported when the device is next online: only for totalMemoryEncryption *
Reported for affiliated users only: N/A * Granular permission needed:
TELEMETRY_API_MEMORY_INFO
Corresponds to the JSON property memoryInfo
3480 3481 3482 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3480 def memory_info @memory_info end |
#memory_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1MemoryStatusReport>
Output only. Memory status reports collected periodically sorted decreasing by
report_time.
Corresponds to the JSON property memoryStatusReport
3486 3487 3488 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3486 def memory_status_report @memory_status_report end |
#name ⇒ String
Output only. Resource name of the device.
Corresponds to the JSON property name
3491 3492 3493 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3491 def name @name end |
#network_bandwidth_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkBandwidthReport>
Output only. Network bandwidth reports collected periodically sorted in a
decreasing order of report_time.
Corresponds to the JSON property networkBandwidthReport
3497 3498 3499 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3497 def network_bandwidth_report @network_bandwidth_report end |
#network_diagnostics_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkDiagnosticsReport>
Output only. Network diagnostics collected periodically.
Corresponds to the JSON property networkDiagnosticsReport
3502 3503 3504 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3502 def network_diagnostics_report @network_diagnostics_report end |
#network_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkInfo
Network device information. * This field provides device information, which is
static and will not change over time. * Data for this field is controlled via
policy: ReportNetworkDeviceConfiguration * Data Collection Frequency: At
device startup * Default Data Reporting Frequency: At device startup - Policy
Controlled: Yes * Cache: If the device is offline, the collected data is
stored locally, and will be reported when the device is next online: Yes *
Reported for affiliated users only: N/A * Granular permission needed:
TELEMETRY_API_NETWORK_INFO
Corresponds to the JSON property networkInfo
3515 3516 3517 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3515 def network_info @network_info end |
#network_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkStatusReport>
Output only. Network specs collected periodically.
Corresponds to the JSON property networkStatusReport
3520 3521 3522 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3520 def network_status_report @network_status_report end |
#org_unit_id ⇒ String
Output only. Organization unit ID of the device.
Corresponds to the JSON property orgUnitId
3525 3526 3527 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3525 def org_unit_id @org_unit_id end |
#os_update_status ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1OsUpdateStatus>
Output only. Contains relevant information regarding ChromeOS update status.
Corresponds to the JSON property osUpdateStatus
3530 3531 3532 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3530 def os_update_status @os_update_status end |
#peripherals_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PeripheralsReport>
Output only. Peripherals reports collected periodically sorted in a decreasing
order of report_time.
Corresponds to the JSON property peripheralsReport
3536 3537 3538 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3536 def peripherals_report @peripherals_report end |
#runtime_counters_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1RuntimeCountersReport>
Output only. Runtime counters reports collected device lifetime runtime, as
well as the counts of S0->S3, S0->S4, and S0->S5 transitions, meaning entering
into sleep, hibernation, and power-off states
Corresponds to the JSON property runtimeCountersReport
3543 3544 3545 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3543 def runtime_counters_report @runtime_counters_report end |
#serial_number ⇒ String
Output only. Device serial number. This value is the same as the Admin Console'
s Serial Number in the ChromeOS Devices tab.
Corresponds to the JSON property serialNumber
3549 3550 3551 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3549 def serial_number @serial_number end |
#storage_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageInfo
Status data for storage. * This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportDeviceStorageStatus * Data Collection Frequency: Only at Upload * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes
- Cache: If the device is offline, the collected data is stored locally, and
will be reported when the device is next online: No * Reported for affiliated
users only: N/A * Granular permission needed: TELEMETRY_API_STORAGE_INFO
Corresponds to the JSON property
storageInfo
3561 3562 3563 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3561 def storage_info @storage_info end |
#storage_status_report ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1StorageStatusReport>
Output only. Storage reports collected periodically.
Corresponds to the JSON property storageStatusReport
3566 3567 3568 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3566 def storage_status_report @storage_status_report end |
#thunderbolt_info ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1ThunderboltInfo>
Output only. Information on Thunderbolt bus.
Corresponds to the JSON property thunderboltInfo
3571 3572 3573 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3571 def thunderbolt_info @thunderbolt_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 3578 def update!(**args) @app_report = args[:app_report] if args.key?(:app_report) @audio_status_report = args[:audio_status_report] if args.key?(:audio_status_report) @battery_info = args[:battery_info] if args.key?(:battery_info) @battery_status_report = args[:battery_status_report] if args.key?(:battery_status_report) @boot_performance_report = args[:boot_performance_report] if args.key?(:boot_performance_report) @cpu_info = args[:cpu_info] if args.key?(:cpu_info) @cpu_status_report = args[:cpu_status_report] if args.key?(:cpu_status_report) @customer = args[:customer] if args.key?(:customer) @device_id = args[:device_id] if args.key?(:device_id) @graphics_info = args[:graphics_info] if args.key?(:graphics_info) @graphics_status_report = args[:graphics_status_report] if args.key?(:graphics_status_report) @heartbeat_status_report = args[:heartbeat_status_report] if args.key?(:heartbeat_status_report) @kiosk_app_status_report = args[:kiosk_app_status_report] if args.key?(:kiosk_app_status_report) @memory_info = args[:memory_info] if args.key?(:memory_info) @memory_status_report = args[:memory_status_report] if args.key?(:memory_status_report) @name = args[:name] if args.key?(:name) @network_bandwidth_report = args[:network_bandwidth_report] if args.key?(:network_bandwidth_report) @network_diagnostics_report = args[:network_diagnostics_report] if args.key?(:network_diagnostics_report) @network_info = args[:network_info] if args.key?(:network_info) @network_status_report = args[:network_status_report] if args.key?(:network_status_report) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @os_update_status = args[:os_update_status] if args.key?(:os_update_status) @peripherals_report = args[:peripherals_report] if args.key?(:peripherals_report) @runtime_counters_report = args[:runtime_counters_report] if args.key?(:runtime_counters_report) @serial_number = args[:serial_number] if args.key?(:serial_number) @storage_info = args[:storage_info] if args.key?(:storage_info) @storage_status_report = args[:storage_status_report] if args.key?(:storage_status_report) @thunderbolt_info = args[:thunderbolt_info] if args.key?(:thunderbolt_info) end |