Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryUserDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Telemetry data collected for a managed user and device. * Granular permission needed: TELEMETRY_API_DEVICE

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryUserDevice

Returns a new instance of GoogleChromeManagementV1TelemetryUserDevice.



4153
4154
4155
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4153

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppReport>

Output only. App reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property appReport



4121
4122
4123
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4121

def app_report
  @app_report
end

#audio_status_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AudioStatusReport>

Output only. Audio reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property audioStatusReport



4127
4128
4129
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4127

def audio_status_report
  @audio_status_report
end

#device_activity_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceActivityReport>

Output only. Device activity reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property deviceActivityReport



4133
4134
4135
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4133

def device_activity_report
  @device_activity_report
end

#device_idString

The unique Directory API ID of the device. This value is the same as the Admin Console's Directory API ID in the ChromeOS Devices tab. Corresponds to the JSON property deviceId

Returns:

  • (String)


4139
4140
4141
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4139

def device_id
  @device_id
end

#network_bandwidth_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkBandwidthReport>

Output only. Network bandwidth reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property networkBandwidthReport



4145
4146
4147
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4145

def network_bandwidth_report
  @network_bandwidth_report
end

#peripherals_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PeripheralsReport>

Output only. Peripherals reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property peripheralsReport



4151
4152
4153
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4151

def peripherals_report
  @peripherals_report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4158
4159
4160
4161
4162
4163
4164
4165
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4158

def update!(**args)
  @app_report = args[:app_report] if args.key?(:app_report)
  @audio_status_report = args[:audio_status_report] if args.key?(:audio_status_report)
  @device_activity_report = args[:device_activity_report] if args.key?(:device_activity_report)
  @device_id = args[:device_id] if args.key?(:device_id)
  @network_bandwidth_report = args[:network_bandwidth_report] if args.key?(:network_bandwidth_report)
  @peripherals_report = args[:peripherals_report] if args.key?(:peripherals_report)
end