Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1TelemetryUserDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Telemetry data collected for a managed user and device. * Granular permission needed: TELEMETRY_API_DEVICE

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1TelemetryUserDevice

Returns a new instance of GoogleChromeManagementV1TelemetryUserDevice.



4083
4084
4085
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AppReport>

Output only. App reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property appReport



4051
4052
4053
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4051

def app_report
  @app_report
end

#audio_status_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1AudioStatusReport>

Output only. Audio reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property audioStatusReport



4057
4058
4059
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4057

def audio_status_report
  @audio_status_report
end

#device_activity_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1DeviceActivityReport>

Output only. Device activity reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property deviceActivityReport



4063
4064
4065
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4063

def device_activity_report
  @device_activity_report
end

#device_idString

The unique Directory API ID of the device. This value is the same as the Admin Console's Directory API ID in the ChromeOS Devices tab. Corresponds to the JSON property deviceId

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4069

def device_id
  @device_id
end

#network_bandwidth_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1NetworkBandwidthReport>

Output only. Network bandwidth reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property networkBandwidthReport



4075
4076
4077
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4075

def network_bandwidth_report
  @network_bandwidth_report
end

#peripherals_reportArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementV1PeripheralsReport>

Output only. Peripherals reports collected periodically sorted in a decreasing order of report_time. Corresponds to the JSON property peripheralsReport



4081
4082
4083
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4081

def peripherals_report
  @peripherals_report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4088

def update!(**args)
  @app_report = args[:app_report] if args.key?(:app_report)
  @audio_status_report = args[:audio_status_report] if args.key?(:audio_status_report)
  @device_activity_report = args[:device_activity_report] if args.key?(:device_activity_report)
  @device_id = args[:device_id] if args.key?(:device_id)
  @network_bandwidth_report = args[:network_bandwidth_report] if args.key?(:network_bandwidth_report)
  @peripherals_report = args[:peripherals_report] if args.key?(:peripherals_report)
end