Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserPrintReport
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserPrintReport
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Report for CountPrintJobsByUser, contains printing statistics for a user. Contains the number of printers, the number of devices used to initiate print jobs, and the number of print jobs initiated.
Instance Attribute Summary collapse
-
#device_count ⇒ Fixnum
Number of chrome devices that have been used to initiate print jobs by the user.
-
#job_count ⇒ Fixnum
Number of print jobs initiated by the user.
-
#printer_count ⇒ Fixnum
Number of printers used by the user.
-
#user_email ⇒ String
The primary e-mail address of the user.
-
#user_id ⇒ String
The unique Directory API ID of the user.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementV1UserPrintReport
constructor
A new instance of GoogleChromeManagementV1UserPrintReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementV1UserPrintReport
Returns a new instance of GoogleChromeManagementV1UserPrintReport.
4415 4416 4417 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_count ⇒ Fixnum
Number of chrome devices that have been used to initiate print jobs by the
user.
Corresponds to the JSON property deviceCount
4393 4394 4395 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4393 def device_count @device_count end |
#job_count ⇒ Fixnum
Number of print jobs initiated by the user.
Corresponds to the JSON property jobCount
4398 4399 4400 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4398 def job_count @job_count end |
#printer_count ⇒ Fixnum
Number of printers used by the user.
Corresponds to the JSON property printerCount
4403 4404 4405 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4403 def printer_count @printer_count end |
#user_email ⇒ String
The primary e-mail address of the user.
Corresponds to the JSON property userEmail
4408 4409 4410 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4408 def user_email @user_email end |
#user_id ⇒ String
The unique Directory API ID of the user.
Corresponds to the JSON property userId
4413 4414 4415 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4413 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4420 4421 4422 4423 4424 4425 4426 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4420 def update!(**args) @device_count = args[:device_count] if args.key?(:device_count) @job_count = args[:job_count] if args.key?(:job_count) @printer_count = args[:printer_count] if args.key?(:printer_count) @user_email = args[:user_email] if args.key?(:user_email) @user_id = args[:user_id] if args.key?(:user_id) end |