Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserPrintReport

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Report for CountPrintJobsByUser, contains printing statistics for a user. Contains the number of printers, the number of devices used to initiate print jobs, and the number of print jobs initiated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1UserPrintReport

Returns a new instance of GoogleChromeManagementV1UserPrintReport.



4345
4346
4347
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_countFixnum

Number of chrome devices that have been used to initiate print jobs by the user. Corresponds to the JSON property deviceCount

Returns:

  • (Fixnum)


4323
4324
4325
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4323

def device_count
  @device_count
end

#job_countFixnum

Number of print jobs initiated by the user. Corresponds to the JSON property jobCount

Returns:

  • (Fixnum)


4328
4329
4330
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4328

def job_count
  @job_count
end

#printer_countFixnum

Number of printers used by the user. Corresponds to the JSON property printerCount

Returns:

  • (Fixnum)


4333
4334
4335
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4333

def printer_count
  @printer_count
end

#user_emailString

The primary e-mail address of the user. Corresponds to the JSON property userEmail

Returns:

  • (String)


4338
4339
4340
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4338

def user_email
  @user_email
end

#user_idString

The unique Directory API ID of the user. Corresponds to the JSON property userId

Returns:

  • (String)


4343
4344
4345
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4343

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4350
4351
4352
4353
4354
4355
4356
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4350

def update!(**args)
  @device_count = args[:device_count] if args.key?(:device_count)
  @job_count = args[:job_count] if args.key?(:job_count)
  @printer_count = args[:printer_count] if args.key?(:printer_count)
  @user_email = args[:user_email] if args.key?(:user_email)
  @user_id = args[:user_id] if args.key?(:user_id)
end