Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementV1UserRequestingExtensionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Details of a user requesting an extension, including the email and the justification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementV1UserRequestingExtensionDetails

Returns a new instance of GoogleChromeManagementV1UserRequestingExtensionDetails.



4444
4445
4446
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#emailString

The e-mail address of a user that has requested the extension. Corresponds to the JSON property email

Returns:

  • (String)


4437
4438
4439
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4437

def email
  @email
end

#justificationString

Request justification as entered by the user. Corresponds to the JSON property justification

Returns:

  • (String)


4442
4443
4444
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4442

def justification
  @justification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4449
4450
4451
4452
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4449

def update!(**args)
  @email = args[:email] if args.key?(:email)
  @justification = args[:justification] if args.key?(:justification)
end