Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1CertificateProvisioningProcess
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1CertificateProvisioningProcess
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A certificate provisioning process.
Instance Attribute Summary collapse
-
#chrome_os_device ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsDevice
Describes the ChromeOS device that a
CertificateProvisioningProcessbelongs to. -
#chrome_os_user_session ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsUserSession
Describes the ChromeOS user session that a
CertificateProvisioningProcessbelongs to. -
#failure_message ⇒ String
Output only.
-
#generic_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericCaConnection
Describes a generic Certificate Authority Connection.
-
#generic_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericProfile
Describes a generic certificate provisioning profile.
-
#issued_certificate ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#provisioning_profile_id ⇒ String
Output only.
-
#scep_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepCaConnection
Describes a SCEP Certificate Authority Connection.
-
#scep_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
Describes a SCEP certificate provisioning profile.
-
#sign_data ⇒ String
Output only.
-
#signature ⇒ String
Output only.
-
#signature_algorithm ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#subject_public_key_info ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1CertificateProvisioningProcess
constructor
A new instance of GoogleChromeManagementVersionsV1CertificateProvisioningProcess.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1CertificateProvisioningProcess
Returns a new instance of GoogleChromeManagementVersionsV1CertificateProvisioningProcess.
4629 4630 4631 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chrome_os_device ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsDevice
Describes the ChromeOS device that a CertificateProvisioningProcess belongs
to.
Corresponds to the JSON property chromeOsDevice
4538 4539 4540 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4538 def chrome_os_device @chrome_os_device end |
#chrome_os_user_session ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsUserSession
Describes the ChromeOS user session that a CertificateProvisioningProcess
belongs to.
Corresponds to the JSON property chromeOsUserSession
4544 4545 4546 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4544 def chrome_os_user_session @chrome_os_user_session end |
#failure_message ⇒ String
Output only. A message describing why this CertificateProvisioningProcess
has failed. Presence of this field indicates that the
CertificateProvisioningProcess has failed.
Corresponds to the JSON property failureMessage
4551 4552 4553 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4551 def @failure_message end |
#generic_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericCaConnection
Describes a generic Certificate Authority Connection.
Corresponds to the JSON property genericCaConnection
4556 4557 4558 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4556 def generic_ca_connection @generic_ca_connection end |
#generic_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericProfile
Describes a generic certificate provisioning profile.
Corresponds to the JSON property genericProfile
4561 4562 4563 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4561 def generic_profile @generic_profile end |
#issued_certificate ⇒ String
Output only. The issued certificate for this CertificateProvisioningProcess
in PEM format.
Corresponds to the JSON property issuedCertificate
4567 4568 4569 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4567 def issued_certificate @issued_certificate end |
#name ⇒ String
Identifier. Resource name of the CertificateProvisioningProcess. The name
pattern is given as customers/customer/certificateProvisioningProcesses/
certificate_provisioning_processwithcustomerbeing the obfuscated
customer id andcertificate_provisioning_process`being the certificate
provisioning process id.
Corresponds to the JSON propertyname`
4576 4577 4578 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4576 def name @name end |
#provisioning_profile_id ⇒ String
Output only. The ID of the certificate provisioning profile.
Corresponds to the JSON property provisioningProfileId
4581 4582 4583 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4581 def provisioning_profile_id @provisioning_profile_id end |
#scep_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepCaConnection
Describes a SCEP Certificate Authority Connection.
Corresponds to the JSON property scepCaConnection
4586 4587 4588 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4586 def scep_ca_connection @scep_ca_connection end |
#scep_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
Describes a SCEP certificate provisioning profile.
Corresponds to the JSON property scepProfile
4591 4592 4593 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4591 def scep_profile @scep_profile end |
#sign_data ⇒ String
Output only. The data that the client was asked to sign. This field is only
present after the SignData operation has been initiated.
Corresponds to the JSON property signData
NOTE: Values are automatically base64 encoded/decoded in the client library.
4598 4599 4600 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4598 def sign_data @sign_data end |
#signature ⇒ String
Output only. The signature of signature_algorithm, generated using the
client's private key using signature_algorithm. This field is only present
after the SignData operation has finished.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4606 4607 4608 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4606 def signature @signature end |
#signature_algorithm ⇒ String
Output only. The signature algorithm that the client and backend components
use when processing sign_data. If the profile_type is a GenericProfile,
this field will only be present after the SignData operation was initiated.
If the profile_type is a ScepProfile, the field will always be present.
Corresponds to the JSON property signatureAlgorithm
4614 4615 4616 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4614 def signature_algorithm @signature_algorithm end |
#start_time ⇒ String
Output only. Server-generated timestamp of when the certificate provisioning
process has been created.
Corresponds to the JSON property startTime
4620 4621 4622 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4620 def start_time @start_time end |
#subject_public_key_info ⇒ String
Output only. The public key for which a certificate should be provisioned.
Represented as a DER-encoded X.509 SubjectPublicKeyInfo.
Corresponds to the JSON property subjectPublicKeyInfo
NOTE: Values are automatically base64 encoded/decoded in the client library.
4627 4628 4629 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4627 def subject_public_key_info @subject_public_key_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4634 4635 4636 4637 4638 4639 4640 4641 4642 4643 4644 4645 4646 4647 4648 4649 4650 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4634 def update!(**args) @chrome_os_device = args[:chrome_os_device] if args.key?(:chrome_os_device) @chrome_os_user_session = args[:chrome_os_user_session] if args.key?(:chrome_os_user_session) @failure_message = args[:failure_message] if args.key?(:failure_message) @generic_ca_connection = args[:generic_ca_connection] if args.key?(:generic_ca_connection) @generic_profile = args[:generic_profile] if args.key?(:generic_profile) @issued_certificate = args[:issued_certificate] if args.key?(:issued_certificate) @name = args[:name] if args.key?(:name) @provisioning_profile_id = args[:provisioning_profile_id] if args.key?(:provisioning_profile_id) @scep_ca_connection = args[:scep_ca_connection] if args.key?(:scep_ca_connection) @scep_profile = args[:scep_profile] if args.key?(:scep_profile) @sign_data = args[:sign_data] if args.key?(:sign_data) @signature = args[:signature] if args.key?(:signature) @signature_algorithm = args[:signature_algorithm] if args.key?(:signature_algorithm) @start_time = args[:start_time] if args.key?(:start_time) @subject_public_key_info = args[:subject_public_key_info] if args.key?(:subject_public_key_info) end |