Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1CertificateProvisioningProcess
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1CertificateProvisioningProcess
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A certificate provisioning process.
Instance Attribute Summary collapse
-
#chrome_os_device ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsDevice
Describes the ChromeOS device that a
CertificateProvisioningProcessbelongs to. -
#chrome_os_user_session ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsUserSession
Describes the ChromeOS user session that a
CertificateProvisioningProcessbelongs to. -
#failure_message ⇒ String
Output only.
-
#generic_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericCaConnection
Describes a generic Certificate Authority Connection.
-
#generic_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericProfile
Describes a generic certificate provisioning profile.
-
#issued_certificate ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#provisioning_profile_id ⇒ String
Output only.
-
#scep_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepCaConnection
Describes a SCEP Certificate Authority Connection.
-
#scep_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
Describes a SCEP certificate provisioning profile.
-
#sign_data ⇒ String
Output only.
-
#signature ⇒ String
Output only.
-
#signature_algorithm ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#subject_public_key_info ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1CertificateProvisioningProcess
constructor
A new instance of GoogleChromeManagementVersionsV1CertificateProvisioningProcess.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1CertificateProvisioningProcess
Returns a new instance of GoogleChromeManagementVersionsV1CertificateProvisioningProcess.
4592 4593 4594 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chrome_os_device ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsDevice
Describes the ChromeOS device that a CertificateProvisioningProcess belongs
to.
Corresponds to the JSON property chromeOsDevice
4501 4502 4503 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4501 def chrome_os_device @chrome_os_device end |
#chrome_os_user_session ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsUserSession
Describes the ChromeOS user session that a CertificateProvisioningProcess
belongs to.
Corresponds to the JSON property chromeOsUserSession
4507 4508 4509 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4507 def chrome_os_user_session @chrome_os_user_session end |
#failure_message ⇒ String
Output only. A message describing why this CertificateProvisioningProcess
has failed. Presence of this field indicates that the
CertificateProvisioningProcess has failed.
Corresponds to the JSON property failureMessage
4514 4515 4516 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4514 def @failure_message end |
#generic_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericCaConnection
Describes a generic Certificate Authority Connection.
Corresponds to the JSON property genericCaConnection
4519 4520 4521 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4519 def generic_ca_connection @generic_ca_connection end |
#generic_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1GenericProfile
Describes a generic certificate provisioning profile.
Corresponds to the JSON property genericProfile
4524 4525 4526 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4524 def generic_profile @generic_profile end |
#issued_certificate ⇒ String
Output only. The issued certificate for this CertificateProvisioningProcess
in PEM format.
Corresponds to the JSON property issuedCertificate
4530 4531 4532 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4530 def issued_certificate @issued_certificate end |
#name ⇒ String
Identifier. Resource name of the CertificateProvisioningProcess. The name
pattern is given as customers/customer/certificateProvisioningProcesses/
certificate_provisioning_processwithcustomerbeing the obfuscated
customer id andcertificate_provisioning_process`being the certificate
provisioning process id.
Corresponds to the JSON propertyname`
4539 4540 4541 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4539 def name @name end |
#provisioning_profile_id ⇒ String
Output only. The ID of the certificate provisioning profile.
Corresponds to the JSON property provisioningProfileId
4544 4545 4546 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4544 def provisioning_profile_id @provisioning_profile_id end |
#scep_ca_connection ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepCaConnection
Describes a SCEP Certificate Authority Connection.
Corresponds to the JSON property scepCaConnection
4549 4550 4551 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4549 def scep_ca_connection @scep_ca_connection end |
#scep_profile ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
Describes a SCEP certificate provisioning profile.
Corresponds to the JSON property scepProfile
4554 4555 4556 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4554 def scep_profile @scep_profile end |
#sign_data ⇒ String
Output only. The data that the client was asked to sign. This field is only
present after the SignData operation has been initiated.
Corresponds to the JSON property signData
NOTE: Values are automatically base64 encoded/decoded in the client library.
4561 4562 4563 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4561 def sign_data @sign_data end |
#signature ⇒ String
Output only. The signature of signature_algorithm, generated using the
client's private key using signature_algorithm. This field is only present
after the SignData operation has finished.
Corresponds to the JSON property signature
NOTE: Values are automatically base64 encoded/decoded in the client library.
4569 4570 4571 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4569 def signature @signature end |
#signature_algorithm ⇒ String
Output only. The signature algorithm that the client and backend components
use when processing sign_data. If the profile_type is a GenericProfile,
this field will only be present after the SignData operation was initiated.
If the profile_type is a ScepProfile, the field will always be present.
Corresponds to the JSON property signatureAlgorithm
4577 4578 4579 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4577 def signature_algorithm @signature_algorithm end |
#start_time ⇒ String
Output only. Server-generated timestamp of when the certificate provisioning
process has been created.
Corresponds to the JSON property startTime
4583 4584 4585 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4583 def start_time @start_time end |
#subject_public_key_info ⇒ String
Output only. The public key for which a certificate should be provisioned.
Represented as a DER-encoded X.509 SubjectPublicKeyInfo.
Corresponds to the JSON property subjectPublicKeyInfo
NOTE: Values are automatically base64 encoded/decoded in the client library.
4590 4591 4592 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4590 def subject_public_key_info @subject_public_key_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4597 4598 4599 4600 4601 4602 4603 4604 4605 4606 4607 4608 4609 4610 4611 4612 4613 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4597 def update!(**args) @chrome_os_device = args[:chrome_os_device] if args.key?(:chrome_os_device) @chrome_os_user_session = args[:chrome_os_user_session] if args.key?(:chrome_os_user_session) @failure_message = args[:failure_message] if args.key?(:failure_message) @generic_ca_connection = args[:generic_ca_connection] if args.key?(:generic_ca_connection) @generic_profile = args[:generic_profile] if args.key?(:generic_profile) @issued_certificate = args[:issued_certificate] if args.key?(:issued_certificate) @name = args[:name] if args.key?(:name) @provisioning_profile_id = args[:provisioning_profile_id] if args.key?(:provisioning_profile_id) @scep_ca_connection = args[:scep_ca_connection] if args.key?(:scep_ca_connection) @scep_profile = args[:scep_profile] if args.key?(:scep_profile) @sign_data = args[:sign_data] if args.key?(:sign_data) @signature = args[:signature] if args.key?(:signature) @signature_algorithm = args[:signature_algorithm] if args.key?(:signature_algorithm) @start_time = args[:start_time] if args.key?(:start_time) @subject_public_key_info = args[:subject_public_key_info] if args.key?(:subject_public_key_info) end |