Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

A representation of a Chrome browser profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile

Returns a new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.



4779
4780
4781
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliation_stateString

Output only. The specific affiliation state of the profile. Corresponds to the JSON property affiliationState

Returns:

  • (String)


4642
4643
4644
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4642

def affiliation_state
  @affiliation_state
end

#annotated_locationString

Optional. Location of the profile annotated by the admin. Corresponds to the JSON property annotatedLocation

Returns:

  • (String)


4647
4648
4649
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4647

def annotated_location
  @annotated_location
end

#annotated_userString

Optional. User of the profile annotated by the admin. Corresponds to the JSON property annotatedUser

Returns:

  • (String)


4652
4653
4654
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4652

def annotated_user
  @annotated_user
end

#attestation_credentialGoogle::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential

Information of public key associated with a Chrome browser profile. Corresponds to the JSON property attestationCredential



4657
4658
4659
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4657

def attestation_credential
  @attestation_credential
end

#browser_channelString

Output only. Channel of the browser on which the profile exists. Corresponds to the JSON property browserChannel

Returns:

  • (String)


4662
4663
4664
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4662

def browser_channel
  @browser_channel
end

#browser_versionString

Output only. Version of the browser on which the profile exists. Corresponds to the JSON property browserVersion

Returns:

  • (String)


4667
4668
4669
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4667

def browser_version
  @browser_version
end

#device_infoGoogle::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo

Information of a device that runs a Chrome browser profile. Corresponds to the JSON property deviceInfo



4672
4673
4674
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4672

def device_info
  @device_info
end

#display_nameString

Output only. Profile display name set by client. Corresponds to the JSON property displayName

Returns:

  • (String)


4677
4678
4679
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4677

def display_name
  @display_name
end

#etagString

Output only. Etag of this ChromeBrowserProfile resource. This etag can be used with UPDATE operation to ensure consistency. Corresponds to the JSON property etag

Returns:

  • (String)


4683
4684
4685
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4683

def etag
  @etag
end

#extension_countFixnum

Output only. Number of extensions installed on the profile. Corresponds to the JSON property extensionCount

Returns:

  • (Fixnum)


4688
4689
4690
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4688

def extension_count
  @extension_count
end

#first_enrollment_timeString

Output only. Timestamp of the first enrollment of the profile. Corresponds to the JSON property firstEnrollmentTime

Returns:

  • (String)


4693
4694
4695
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4693

def first_enrollment_time
  @first_enrollment_time
end

#identity_providerString

Output only. Identify provider of the profile. Corresponds to the JSON property identityProvider

Returns:

  • (String)


4698
4699
4700
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4698

def identity_provider
  @identity_provider
end

#last_activity_timeString

Output only. Timestamp of the latest activity by the profile. Corresponds to the JSON property lastActivityTime

Returns:

  • (String)


4703
4704
4705
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4703

def last_activity_time
  @last_activity_time
end

#last_policy_fetch_timeString

Output only. Timestamp of the latest policy fetch by the profile. Corresponds to the JSON property lastPolicyFetchTime

Returns:

  • (String)


4708
4709
4710
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4708

def last_policy_fetch_time
  @last_policy_fetch_time
end

#last_policy_sync_timeString

Output only. Timestamp of the latest policy sync by the profile. Corresponds to the JSON property lastPolicySyncTime

Returns:

  • (String)


4713
4714
4715
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4713

def last_policy_sync_time
  @last_policy_sync_time
end

#last_status_report_timeString

Output only. Timestamp of the latest status report by the profile. Corresponds to the JSON property lastStatusReportTime

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4718

def last_status_report_time
  @last_status_report_time
end

#nameString

Identifier. Format: customers/customer_id/profiles/profile_permanent_id Corresponds to the JSON property name

Returns:

  • (String)


4723
4724
4725
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4723

def name
  @name
end

#os_platform_typeString

Output only. OS platform of the device on which the profile exists. Corresponds to the JSON property osPlatformType

Returns:

  • (String)


4728
4729
4730
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4728

def os_platform_type
  @os_platform_type
end

#os_platform_versionString

Output only. Major OS platform version of the device on which the profile exists, from profile reporting. Corresponds to the JSON property osPlatformVersion

Returns:

  • (String)


4734
4735
4736
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4734

def os_platform_version
  @os_platform_version
end

#os_versionString

Output only. OS version of the device on which the profile exists. Corresponds to the JSON property osVersion

Returns:

  • (String)


4739
4740
4741
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4739

def os_version
  @os_version
end

#policy_countFixnum

Output only. Number of policies applied on the profile. Corresponds to the JSON property policyCount

Returns:

  • (Fixnum)


4744
4745
4746
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4744

def policy_count
  @policy_count
end

#profile_idString

Output only. Chrome client side profile ID. Corresponds to the JSON property profileId

Returns:

  • (String)


4749
4750
4751
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4749

def profile_id
  @profile_id
end

#profile_permanent_idString

Output only. Profile permanent ID is the unique identifier of a profile within one customer. Corresponds to the JSON property profilePermanentId

Returns:

  • (String)


4755
4756
4757
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4755

def profile_permanent_id
  @profile_permanent_id
end

#reporting_dataGoogle::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData

Reporting data of a Chrome browser profile. Corresponds to the JSON property reportingData



4760
4761
4762
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4760

def reporting_data
  @reporting_data
end

#supports_fcm_notificationsBoolean Also known as: supports_fcm_notifications?

Output only. Whether the profile supports FCM notifications. Corresponds to the JSON property supportsFcmNotifications

Returns:

  • (Boolean)


4765
4766
4767
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4765

def supports_fcm_notifications
  @supports_fcm_notifications
end

#user_emailString

Output only. Email address of the user to which the profile belongs. Corresponds to the JSON property userEmail

Returns:

  • (String)


4771
4772
4773
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4771

def user_email
  @user_email
end

#user_idString

Output only. Unique Directory API ID of the user that can be used in Admin SDK Users API. Corresponds to the JSON property userId

Returns:

  • (String)


4777
4778
4779
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4777

def user_id
  @user_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4784
4785
4786
4787
4788
4789
4790
4791
4792
4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
4803
4804
4805
4806
4807
4808
4809
4810
4811
4812
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4784

def update!(**args)
  @affiliation_state = args[:affiliation_state] if args.key?(:affiliation_state)
  @annotated_location = args[:annotated_location] if args.key?(:annotated_location)
  @annotated_user = args[:annotated_user] if args.key?(:annotated_user)
  @attestation_credential = args[:attestation_credential] if args.key?(:attestation_credential)
  @browser_channel = args[:browser_channel] if args.key?(:browser_channel)
  @browser_version = args[:browser_version] if args.key?(:browser_version)
  @device_info = args[:device_info] if args.key?(:device_info)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @extension_count = args[:extension_count] if args.key?(:extension_count)
  @first_enrollment_time = args[:first_enrollment_time] if args.key?(:first_enrollment_time)
  @identity_provider = args[:identity_provider] if args.key?(:identity_provider)
  @last_activity_time = args[:last_activity_time] if args.key?(:last_activity_time)
  @last_policy_fetch_time = args[:last_policy_fetch_time] if args.key?(:last_policy_fetch_time)
  @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time)
  @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time)
  @name = args[:name] if args.key?(:name)
  @os_platform_type = args[:os_platform_type] if args.key?(:os_platform_type)
  @os_platform_version = args[:os_platform_version] if args.key?(:os_platform_version)
  @os_version = args[:os_version] if args.key?(:os_version)
  @policy_count = args[:policy_count] if args.key?(:policy_count)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
  @profile_permanent_id = args[:profile_permanent_id] if args.key?(:profile_permanent_id)
  @reporting_data = args[:reporting_data] if args.key?(:reporting_data)
  @supports_fcm_notifications = args[:supports_fcm_notifications] if args.key?(:supports_fcm_notifications)
  @user_email = args[:user_email] if args.key?(:user_email)
  @user_id = args[:user_id] if args.key?(:user_id)
end