Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A representation of a Chrome browser profile.
Instance Attribute Summary collapse
-
#affiliation_state ⇒ String
Output only.
-
#annotated_location ⇒ String
Optional.
-
#annotated_user ⇒ String
Optional.
-
#attestation_credential ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential
Information of public key associated with a Chrome browser profile.
-
#browser_channel ⇒ String
Output only.
-
#browser_version ⇒ String
Output only.
-
#device_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
Information of a device that runs a Chrome browser profile.
-
#display_name ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#extension_count ⇒ Fixnum
Output only.
-
#first_enrollment_time ⇒ String
Output only.
-
#identity_provider ⇒ String
Output only.
-
#last_activity_time ⇒ String
Output only.
-
#last_policy_fetch_time ⇒ String
Output only.
-
#last_policy_sync_time ⇒ String
Output only.
-
#last_status_report_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#os_platform_type ⇒ String
Output only.
-
#os_platform_version ⇒ String
Output only.
-
#os_version ⇒ String
Output only.
-
#policy_count ⇒ Fixnum
Output only.
-
#profile_id ⇒ String
Output only.
-
#profile_permanent_id ⇒ String
Output only.
-
#reporting_data ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData
Reporting data of a Chrome browser profile.
-
#supports_fcm_notifications ⇒ Boolean
(also: #supports_fcm_notifications?)
Output only.
-
#user_email ⇒ String
Output only.
-
#user_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile
constructor
A new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile
Returns a new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.
4779 4780 4781 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliation_state ⇒ String
Output only. The specific affiliation state of the profile.
Corresponds to the JSON property affiliationState
4642 4643 4644 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4642 def affiliation_state @affiliation_state end |
#annotated_location ⇒ String
Optional. Location of the profile annotated by the admin.
Corresponds to the JSON property annotatedLocation
4647 4648 4649 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4647 def annotated_location @annotated_location end |
#annotated_user ⇒ String
Optional. User of the profile annotated by the admin.
Corresponds to the JSON property annotatedUser
4652 4653 4654 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4652 def annotated_user @annotated_user end |
#attestation_credential ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential
Information of public key associated with a Chrome browser profile.
Corresponds to the JSON property attestationCredential
4657 4658 4659 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4657 def attestation_credential @attestation_credential end |
#browser_channel ⇒ String
Output only. Channel of the browser on which the profile exists.
Corresponds to the JSON property browserChannel
4662 4663 4664 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4662 def browser_channel @browser_channel end |
#browser_version ⇒ String
Output only. Version of the browser on which the profile exists.
Corresponds to the JSON property browserVersion
4667 4668 4669 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4667 def browser_version @browser_version end |
#device_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
Information of a device that runs a Chrome browser profile.
Corresponds to the JSON property deviceInfo
4672 4673 4674 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4672 def device_info @device_info end |
#display_name ⇒ String
Output only. Profile display name set by client.
Corresponds to the JSON property displayName
4677 4678 4679 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4677 def display_name @display_name end |
#etag ⇒ String
Output only. Etag of this ChromeBrowserProfile resource. This etag can be used
with UPDATE operation to ensure consistency.
Corresponds to the JSON property etag
4683 4684 4685 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4683 def etag @etag end |
#extension_count ⇒ Fixnum
Output only. Number of extensions installed on the profile.
Corresponds to the JSON property extensionCount
4688 4689 4690 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4688 def extension_count @extension_count end |
#first_enrollment_time ⇒ String
Output only. Timestamp of the first enrollment of the profile.
Corresponds to the JSON property firstEnrollmentTime
4693 4694 4695 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4693 def first_enrollment_time @first_enrollment_time end |
#identity_provider ⇒ String
Output only. Identify provider of the profile.
Corresponds to the JSON property identityProvider
4698 4699 4700 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4698 def identity_provider @identity_provider end |
#last_activity_time ⇒ String
Output only. Timestamp of the latest activity by the profile.
Corresponds to the JSON property lastActivityTime
4703 4704 4705 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4703 def last_activity_time @last_activity_time end |
#last_policy_fetch_time ⇒ String
Output only. Timestamp of the latest policy fetch by the profile.
Corresponds to the JSON property lastPolicyFetchTime
4708 4709 4710 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4708 def last_policy_fetch_time @last_policy_fetch_time end |
#last_policy_sync_time ⇒ String
Output only. Timestamp of the latest policy sync by the profile.
Corresponds to the JSON property lastPolicySyncTime
4713 4714 4715 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4713 def last_policy_sync_time @last_policy_sync_time end |
#last_status_report_time ⇒ String
Output only. Timestamp of the latest status report by the profile.
Corresponds to the JSON property lastStatusReportTime
4718 4719 4720 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4718 def last_status_report_time @last_status_report_time end |
#name ⇒ String
Identifier. Format: customers/customer_id/profiles/profile_permanent_id
Corresponds to the JSON property name
4723 4724 4725 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4723 def name @name end |
#os_platform_type ⇒ String
Output only. OS platform of the device on which the profile exists.
Corresponds to the JSON property osPlatformType
4728 4729 4730 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4728 def os_platform_type @os_platform_type end |
#os_platform_version ⇒ String
Output only. Major OS platform version of the device on which the profile
exists, from profile reporting.
Corresponds to the JSON property osPlatformVersion
4734 4735 4736 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4734 def os_platform_version @os_platform_version end |
#os_version ⇒ String
Output only. OS version of the device on which the profile exists.
Corresponds to the JSON property osVersion
4739 4740 4741 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4739 def os_version @os_version end |
#policy_count ⇒ Fixnum
Output only. Number of policies applied on the profile.
Corresponds to the JSON property policyCount
4744 4745 4746 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4744 def policy_count @policy_count end |
#profile_id ⇒ String
Output only. Chrome client side profile ID.
Corresponds to the JSON property profileId
4749 4750 4751 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4749 def profile_id @profile_id end |
#profile_permanent_id ⇒ String
Output only. Profile permanent ID is the unique identifier of a profile within
one customer.
Corresponds to the JSON property profilePermanentId
4755 4756 4757 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4755 def profile_permanent_id @profile_permanent_id end |
#reporting_data ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData
Reporting data of a Chrome browser profile.
Corresponds to the JSON property reportingData
4760 4761 4762 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4760 def reporting_data @reporting_data end |
#supports_fcm_notifications ⇒ Boolean Also known as: supports_fcm_notifications?
Output only. Whether the profile supports FCM notifications.
Corresponds to the JSON property supportsFcmNotifications
4765 4766 4767 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4765 def supports_fcm_notifications @supports_fcm_notifications end |
#user_email ⇒ String
Output only. Email address of the user to which the profile belongs.
Corresponds to the JSON property userEmail
4771 4772 4773 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4771 def user_email @user_email end |
#user_id ⇒ String
Output only. Unique Directory API ID of the user that can be used in Admin SDK
Users API.
Corresponds to the JSON property userId
4777 4778 4779 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4777 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4784 4785 4786 4787 4788 4789 4790 4791 4792 4793 4794 4795 4796 4797 4798 4799 4800 4801 4802 4803 4804 4805 4806 4807 4808 4809 4810 4811 4812 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4784 def update!(**args) @affiliation_state = args[:affiliation_state] if args.key?(:affiliation_state) @annotated_location = args[:annotated_location] if args.key?(:annotated_location) @annotated_user = args[:annotated_user] if args.key?(:annotated_user) @attestation_credential = args[:attestation_credential] if args.key?(:attestation_credential) @browser_channel = args[:browser_channel] if args.key?(:browser_channel) @browser_version = args[:browser_version] if args.key?(:browser_version) @device_info = args[:device_info] if args.key?(:device_info) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @extension_count = args[:extension_count] if args.key?(:extension_count) @first_enrollment_time = args[:first_enrollment_time] if args.key?(:first_enrollment_time) @identity_provider = args[:identity_provider] if args.key?(:identity_provider) @last_activity_time = args[:last_activity_time] if args.key?(:last_activity_time) @last_policy_fetch_time = args[:last_policy_fetch_time] if args.key?(:last_policy_fetch_time) @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time) @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time) @name = args[:name] if args.key?(:name) @os_platform_type = args[:os_platform_type] if args.key?(:os_platform_type) @os_platform_version = args[:os_platform_version] if args.key?(:os_platform_version) @os_version = args[:os_version] if args.key?(:os_version) @policy_count = args[:policy_count] if args.key?(:policy_count) @profile_id = args[:profile_id] if args.key?(:profile_id) @profile_permanent_id = args[:profile_permanent_id] if args.key?(:profile_permanent_id) @reporting_data = args[:reporting_data] if args.key?(:reporting_data) @supports_fcm_notifications = args[:supports_fcm_notifications] if args.key?(:supports_fcm_notifications) @user_email = args[:user_email] if args.key?(:user_email) @user_id = args[:user_id] if args.key?(:user_id) end |