Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A representation of a Chrome browser profile.
Instance Attribute Summary collapse
-
#affiliation_state ⇒ String
Output only.
-
#annotated_location ⇒ String
Optional.
-
#annotated_user ⇒ String
Optional.
-
#attestation_credential ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential
Information of public key associated with a Chrome browser profile.
-
#browser_channel ⇒ String
Output only.
-
#browser_version ⇒ String
Output only.
-
#device_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
Information of a device that runs a Chrome browser profile.
-
#display_name ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#extension_count ⇒ Fixnum
Output only.
-
#first_enrollment_time ⇒ String
Output only.
-
#identity_provider ⇒ String
Output only.
-
#last_activity_time ⇒ String
Output only.
-
#last_policy_fetch_time ⇒ String
Output only.
-
#last_policy_sync_time ⇒ String
Output only.
-
#last_status_report_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#os_platform_type ⇒ String
Output only.
-
#os_platform_version ⇒ String
Output only.
-
#os_version ⇒ String
Output only.
-
#policy_count ⇒ Fixnum
Output only.
-
#profile_id ⇒ String
Output only.
-
#profile_permanent_id ⇒ String
Output only.
-
#reporting_data ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData
Reporting data of a Chrome browser profile.
-
#supports_fcm_notifications ⇒ Boolean
(also: #supports_fcm_notifications?)
Output only.
-
#user_email ⇒ String
Output only.
-
#user_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile
constructor
A new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile
Returns a new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.
4760 4761 4762 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliation_state ⇒ String
Output only. The specific affiliation state of the profile.
Corresponds to the JSON property affiliationState
4623 4624 4625 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4623 def affiliation_state @affiliation_state end |
#annotated_location ⇒ String
Optional. Location of the profile annotated by the admin.
Corresponds to the JSON property annotatedLocation
4628 4629 4630 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4628 def annotated_location @annotated_location end |
#annotated_user ⇒ String
Optional. User of the profile annotated by the admin.
Corresponds to the JSON property annotatedUser
4633 4634 4635 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4633 def annotated_user @annotated_user end |
#attestation_credential ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential
Information of public key associated with a Chrome browser profile.
Corresponds to the JSON property attestationCredential
4638 4639 4640 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4638 def attestation_credential @attestation_credential end |
#browser_channel ⇒ String
Output only. Channel of the browser on which the profile exists.
Corresponds to the JSON property browserChannel
4643 4644 4645 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4643 def browser_channel @browser_channel end |
#browser_version ⇒ String
Output only. Version of the browser on which the profile exists.
Corresponds to the JSON property browserVersion
4648 4649 4650 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4648 def browser_version @browser_version end |
#device_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
Information of a device that runs a Chrome browser profile.
Corresponds to the JSON property deviceInfo
4653 4654 4655 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4653 def device_info @device_info end |
#display_name ⇒ String
Output only. Profile display name set by client.
Corresponds to the JSON property displayName
4658 4659 4660 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4658 def display_name @display_name end |
#etag ⇒ String
Output only. Etag of this ChromeBrowserProfile resource. This etag can be used
with UPDATE operation to ensure consistency.
Corresponds to the JSON property etag
4664 4665 4666 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4664 def etag @etag end |
#extension_count ⇒ Fixnum
Output only. Number of extensions installed on the profile.
Corresponds to the JSON property extensionCount
4669 4670 4671 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4669 def extension_count @extension_count end |
#first_enrollment_time ⇒ String
Output only. Timestamp of the first enrollment of the profile.
Corresponds to the JSON property firstEnrollmentTime
4674 4675 4676 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4674 def first_enrollment_time @first_enrollment_time end |
#identity_provider ⇒ String
Output only. Identify provider of the profile.
Corresponds to the JSON property identityProvider
4679 4680 4681 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4679 def identity_provider @identity_provider end |
#last_activity_time ⇒ String
Output only. Timestamp of the latest activity by the profile.
Corresponds to the JSON property lastActivityTime
4684 4685 4686 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4684 def last_activity_time @last_activity_time end |
#last_policy_fetch_time ⇒ String
Output only. Timestamp of the latest policy fetch by the profile.
Corresponds to the JSON property lastPolicyFetchTime
4689 4690 4691 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4689 def last_policy_fetch_time @last_policy_fetch_time end |
#last_policy_sync_time ⇒ String
Output only. Timestamp of the latest policy sync by the profile.
Corresponds to the JSON property lastPolicySyncTime
4694 4695 4696 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4694 def last_policy_sync_time @last_policy_sync_time end |
#last_status_report_time ⇒ String
Output only. Timestamp of the latest status report by the profile.
Corresponds to the JSON property lastStatusReportTime
4699 4700 4701 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4699 def last_status_report_time @last_status_report_time end |
#name ⇒ String
Identifier. Format: customers/customer_id/profiles/profile_permanent_id
Corresponds to the JSON property name
4704 4705 4706 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4704 def name @name end |
#os_platform_type ⇒ String
Output only. OS platform of the device on which the profile exists.
Corresponds to the JSON property osPlatformType
4709 4710 4711 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4709 def os_platform_type @os_platform_type end |
#os_platform_version ⇒ String
Output only. Major OS platform version of the device on which the profile
exists, from profile reporting.
Corresponds to the JSON property osPlatformVersion
4715 4716 4717 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4715 def os_platform_version @os_platform_version end |
#os_version ⇒ String
Output only. OS version of the device on which the profile exists.
Corresponds to the JSON property osVersion
4720 4721 4722 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4720 def os_version @os_version end |
#policy_count ⇒ Fixnum
Output only. Number of policies applied on the profile.
Corresponds to the JSON property policyCount
4725 4726 4727 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4725 def policy_count @policy_count end |
#profile_id ⇒ String
Output only. Chrome client side profile ID.
Corresponds to the JSON property profileId
4730 4731 4732 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4730 def profile_id @profile_id end |
#profile_permanent_id ⇒ String
Output only. Profile permanent ID is the unique identifier of a profile within
one customer.
Corresponds to the JSON property profilePermanentId
4736 4737 4738 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4736 def profile_permanent_id @profile_permanent_id end |
#reporting_data ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData
Reporting data of a Chrome browser profile.
Corresponds to the JSON property reportingData
4741 4742 4743 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4741 def reporting_data @reporting_data end |
#supports_fcm_notifications ⇒ Boolean Also known as: supports_fcm_notifications?
Output only. Whether the profile supports FCM notifications.
Corresponds to the JSON property supportsFcmNotifications
4746 4747 4748 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4746 def supports_fcm_notifications @supports_fcm_notifications end |
#user_email ⇒ String
Output only. Email address of the user to which the profile belongs.
Corresponds to the JSON property userEmail
4752 4753 4754 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4752 def user_email @user_email end |
#user_id ⇒ String
Output only. Unique Directory API ID of the user that can be used in Admin SDK
Users API.
Corresponds to the JSON property userId
4758 4759 4760 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4758 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4765 4766 4767 4768 4769 4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 4792 4793 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4765 def update!(**args) @affiliation_state = args[:affiliation_state] if args.key?(:affiliation_state) @annotated_location = args[:annotated_location] if args.key?(:annotated_location) @annotated_user = args[:annotated_user] if args.key?(:annotated_user) @attestation_credential = args[:attestation_credential] if args.key?(:attestation_credential) @browser_channel = args[:browser_channel] if args.key?(:browser_channel) @browser_version = args[:browser_version] if args.key?(:browser_version) @device_info = args[:device_info] if args.key?(:device_info) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @extension_count = args[:extension_count] if args.key?(:extension_count) @first_enrollment_time = args[:first_enrollment_time] if args.key?(:first_enrollment_time) @identity_provider = args[:identity_provider] if args.key?(:identity_provider) @last_activity_time = args[:last_activity_time] if args.key?(:last_activity_time) @last_policy_fetch_time = args[:last_policy_fetch_time] if args.key?(:last_policy_fetch_time) @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time) @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time) @name = args[:name] if args.key?(:name) @os_platform_type = args[:os_platform_type] if args.key?(:os_platform_type) @os_platform_version = args[:os_platform_version] if args.key?(:os_platform_version) @os_version = args[:os_version] if args.key?(:os_version) @policy_count = args[:policy_count] if args.key?(:policy_count) @profile_id = args[:profile_id] if args.key?(:profile_id) @profile_permanent_id = args[:profile_permanent_id] if args.key?(:profile_permanent_id) @reporting_data = args[:reporting_data] if args.key?(:reporting_data) @supports_fcm_notifications = args[:supports_fcm_notifications] if args.key?(:supports_fcm_notifications) @user_email = args[:user_email] if args.key?(:user_email) @user_id = args[:user_id] if args.key?(:user_id) end |