Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A representation of a Chrome browser profile.
Instance Attribute Summary collapse
-
#affiliation_state ⇒ String
Output only.
-
#annotated_location ⇒ String
Optional.
-
#annotated_user ⇒ String
Optional.
-
#attestation_credential ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential
Information of public key associated with a Chrome browser profile.
-
#browser_channel ⇒ String
Output only.
-
#browser_version ⇒ String
Output only.
-
#device_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
Information of a device that runs a Chrome browser profile.
-
#display_name ⇒ String
Output only.
-
#etag ⇒ String
Output only.
-
#extension_count ⇒ Fixnum
Output only.
-
#first_enrollment_time ⇒ String
Output only.
-
#identity_provider ⇒ String
Output only.
-
#last_activity_time ⇒ String
Output only.
-
#last_policy_fetch_time ⇒ String
Output only.
-
#last_policy_sync_time ⇒ String
Output only.
-
#last_status_report_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#os_platform_type ⇒ String
Output only.
-
#os_platform_version ⇒ String
Output only.
-
#os_version ⇒ String
Output only.
-
#policy_count ⇒ Fixnum
Output only.
-
#profile_id ⇒ String
Output only.
-
#profile_permanent_id ⇒ String
Output only.
-
#reporting_data ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData
Reporting data of a Chrome browser profile.
-
#supports_fcm_notifications ⇒ Boolean
(also: #supports_fcm_notifications?)
Output only.
-
#user_email ⇒ String
Output only.
-
#user_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile
constructor
A new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfile
Returns a new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfile.
4690 4691 4692 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliation_state ⇒ String
Output only. The specific affiliation state of the profile.
Corresponds to the JSON property affiliationState
4553 4554 4555 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4553 def affiliation_state @affiliation_state end |
#annotated_location ⇒ String
Optional. Location of the profile annotated by the admin.
Corresponds to the JSON property annotatedLocation
4558 4559 4560 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4558 def annotated_location @annotated_location end |
#annotated_user ⇒ String
Optional. User of the profile annotated by the admin.
Corresponds to the JSON property annotatedUser
4563 4564 4565 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4563 def annotated_user @annotated_user end |
#attestation_credential ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1AttestationCredential
Information of public key associated with a Chrome browser profile.
Corresponds to the JSON property attestationCredential
4568 4569 4570 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4568 def attestation_credential @attestation_credential end |
#browser_channel ⇒ String
Output only. Channel of the browser on which the profile exists.
Corresponds to the JSON property browserChannel
4573 4574 4575 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4573 def browser_channel @browser_channel end |
#browser_version ⇒ String
Output only. Version of the browser on which the profile exists.
Corresponds to the JSON property browserVersion
4578 4579 4580 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4578 def browser_version @browser_version end |
#device_info ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
Information of a device that runs a Chrome browser profile.
Corresponds to the JSON property deviceInfo
4583 4584 4585 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4583 def device_info @device_info end |
#display_name ⇒ String
Output only. Profile display name set by client.
Corresponds to the JSON property displayName
4588 4589 4590 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4588 def display_name @display_name end |
#etag ⇒ String
Output only. Etag of this ChromeBrowserProfile resource. This etag can be used
with UPDATE operation to ensure consistency.
Corresponds to the JSON property etag
4594 4595 4596 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4594 def etag @etag end |
#extension_count ⇒ Fixnum
Output only. Number of extensions installed on the profile.
Corresponds to the JSON property extensionCount
4599 4600 4601 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4599 def extension_count @extension_count end |
#first_enrollment_time ⇒ String
Output only. Timestamp of the first enrollment of the profile.
Corresponds to the JSON property firstEnrollmentTime
4604 4605 4606 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4604 def first_enrollment_time @first_enrollment_time end |
#identity_provider ⇒ String
Output only. Identify provider of the profile.
Corresponds to the JSON property identityProvider
4609 4610 4611 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4609 def identity_provider @identity_provider end |
#last_activity_time ⇒ String
Output only. Timestamp of the latest activity by the profile.
Corresponds to the JSON property lastActivityTime
4614 4615 4616 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4614 def last_activity_time @last_activity_time end |
#last_policy_fetch_time ⇒ String
Output only. Timestamp of the latest policy fetch by the profile.
Corresponds to the JSON property lastPolicyFetchTime
4619 4620 4621 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4619 def last_policy_fetch_time @last_policy_fetch_time end |
#last_policy_sync_time ⇒ String
Output only. Timestamp of the latest policy sync by the profile.
Corresponds to the JSON property lastPolicySyncTime
4624 4625 4626 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4624 def last_policy_sync_time @last_policy_sync_time end |
#last_status_report_time ⇒ String
Output only. Timestamp of the latest status report by the profile.
Corresponds to the JSON property lastStatusReportTime
4629 4630 4631 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4629 def last_status_report_time @last_status_report_time end |
#name ⇒ String
Identifier. Format: customers/customer_id/profiles/profile_permanent_id
Corresponds to the JSON property name
4634 4635 4636 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4634 def name @name end |
#os_platform_type ⇒ String
Output only. OS platform of the device on which the profile exists.
Corresponds to the JSON property osPlatformType
4639 4640 4641 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4639 def os_platform_type @os_platform_type end |
#os_platform_version ⇒ String
Output only. Major OS platform version of the device on which the profile
exists, from profile reporting.
Corresponds to the JSON property osPlatformVersion
4645 4646 4647 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4645 def os_platform_version @os_platform_version end |
#os_version ⇒ String
Output only. OS version of the device on which the profile exists.
Corresponds to the JSON property osVersion
4650 4651 4652 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4650 def os_version @os_version end |
#policy_count ⇒ Fixnum
Output only. Number of policies applied on the profile.
Corresponds to the JSON property policyCount
4655 4656 4657 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4655 def policy_count @policy_count end |
#profile_id ⇒ String
Output only. Chrome client side profile ID.
Corresponds to the JSON property profileId
4660 4661 4662 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4660 def profile_id @profile_id end |
#profile_permanent_id ⇒ String
Output only. Profile permanent ID is the unique identifier of a profile within
one customer.
Corresponds to the JSON property profilePermanentId
4666 4667 4668 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4666 def profile_permanent_id @profile_permanent_id end |
#reporting_data ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData
Reporting data of a Chrome browser profile.
Corresponds to the JSON property reportingData
4671 4672 4673 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4671 def reporting_data @reporting_data end |
#supports_fcm_notifications ⇒ Boolean Also known as: supports_fcm_notifications?
Output only. Whether the profile supports FCM notifications.
Corresponds to the JSON property supportsFcmNotifications
4676 4677 4678 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4676 def supports_fcm_notifications @supports_fcm_notifications end |
#user_email ⇒ String
Output only. Email address of the user to which the profile belongs.
Corresponds to the JSON property userEmail
4682 4683 4684 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4682 def user_email @user_email end |
#user_id ⇒ String
Output only. Unique Directory API ID of the user that can be used in Admin SDK
Users API.
Corresponds to the JSON property userId
4688 4689 4690 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4688 def user_id @user_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 4699 4700 4701 4702 4703 4704 4705 4706 4707 4708 4709 4710 4711 4712 4713 4714 4715 4716 4717 4718 4719 4720 4721 4722 4723 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4695 def update!(**args) @affiliation_state = args[:affiliation_state] if args.key?(:affiliation_state) @annotated_location = args[:annotated_location] if args.key?(:annotated_location) @annotated_user = args[:annotated_user] if args.key?(:annotated_user) @attestation_credential = args[:attestation_credential] if args.key?(:attestation_credential) @browser_channel = args[:browser_channel] if args.key?(:browser_channel) @browser_version = args[:browser_version] if args.key?(:browser_version) @device_info = args[:device_info] if args.key?(:device_info) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @extension_count = args[:extension_count] if args.key?(:extension_count) @first_enrollment_time = args[:first_enrollment_time] if args.key?(:first_enrollment_time) @identity_provider = args[:identity_provider] if args.key?(:identity_provider) @last_activity_time = args[:last_activity_time] if args.key?(:last_activity_time) @last_policy_fetch_time = args[:last_policy_fetch_time] if args.key?(:last_policy_fetch_time) @last_policy_sync_time = args[:last_policy_sync_time] if args.key?(:last_policy_sync_time) @last_status_report_time = args[:last_status_report_time] if args.key?(:last_status_report_time) @name = args[:name] if args.key?(:name) @os_platform_type = args[:os_platform_type] if args.key?(:os_platform_type) @os_platform_version = args[:os_platform_version] if args.key?(:os_platform_version) @os_version = args[:os_version] if args.key?(:os_version) @policy_count = args[:policy_count] if args.key?(:policy_count) @profile_id = args[:profile_id] if args.key?(:profile_id) @profile_permanent_id = args[:profile_permanent_id] if args.key?(:profile_permanent_id) @reporting_data = args[:reporting_data] if args.key?(:reporting_data) @supports_fcm_notifications = args[:supports_fcm_notifications] if args.key?(:supports_fcm_notifications) @user_email = args[:user_email] if args.key?(:user_email) @user_id = args[:user_id] if args.key?(:user_id) end |