Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Result of the execution of a command.
Instance Attribute Summary collapse
-
#client_execution_time ⇒ String
Output only.
-
#result_code ⇒ String
Output only.
-
#result_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult
constructor
A new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult
Returns a new instance of GoogleChromeManagementVersionsV1ChromeBrowserProfileCommandCommandResult.
4875 4876 4877 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_execution_time ⇒ String
Output only. Timestamp of the client execution of the remote command.
Corresponds to the JSON property clientExecutionTime
4862 4863 4864 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4862 def client_execution_time @client_execution_time end |
#result_code ⇒ String
Output only. Result code that indicates the type of error or success of the
command.
Corresponds to the JSON property resultCode
4868 4869 4870 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4868 def result_code @result_code end |
#result_type ⇒ String
Output only. Result type of the remote command.
Corresponds to the JSON property resultType
4873 4874 4875 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4873 def result_type @result_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4880 4881 4882 4883 4884 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4880 def update!(**args) @client_execution_time = args[:client_execution_time] if args.key?(:client_execution_time) @result_code = args[:result_code] if args.key?(:result_code) @result_type = args[:result_type] if args.key?(:result_type) end |