Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeOsDevice

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Describes the ChromeOS device that a CertificateProvisioningProcess belongs to.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ChromeOsDevice

Returns a new instance of GoogleChromeManagementVersionsV1ChromeOsDevice.



4834
4835
4836
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_directory_api_idString

Output only. The unique Directory API ID of the device. This value is the same as the Admin Console's Directory API ID in the ChromeOS Devices tab. Corresponds to the JSON property deviceDirectoryApiId

Returns:

  • (String)


4826
4827
4828
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4826

def device_directory_api_id
  @device_directory_api_id
end

#serial_numberString

Output only. Device serial number. This value is the same as the Admin Console' s Serial Number in the ChromeOS Devices tab. Corresponds to the JSON property serialNumber

Returns:

  • (String)


4832
4833
4834
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4832

def serial_number
  @serial_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4839
4840
4841
4842
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 4839

def update!(**args)
  @device_directory_api_id = args[:device_directory_api_id] if args.key?(:device_directory_api_id)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
end