Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfigStatus
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfigStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
The status of the connector config.
Instance Attribute Summary collapse
-
#failure_start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ConnectorConfigStatus
constructor
A new instance of GoogleChromeManagementVersionsV1ConnectorConfigStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ConnectorConfigStatus
Returns a new instance of GoogleChromeManagementVersionsV1ConnectorConfigStatus.
5140 5141 5142 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_start_time ⇒ String
Output only. Field recording time of the earliest failure since the last
success event. This field is only set when the state is DISABLED_BY_FAILURES.
Corresponds to the JSON property failureStartTime
5123 5124 5125 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5123 def failure_start_time @failure_start_time end |
#state ⇒ String
Output only. The state of the connector config. The connector state is
disabled if the connector has not successfully sent an event in the last 24
hours.
Corresponds to the JSON property state
5130 5131 5132 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5130 def state @state end |
#update_time ⇒ String
Output only. Field recording time of most recent modification of the status.
For ENABLED, this is the time the status was changed to ENABLED. For
DISABLED_BY_FAILURES, this is the time of the most recent failed attempt to
send an event to this config.
Corresponds to the JSON property updateTime
5138 5139 5140 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5138 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5145 5146 5147 5148 5149 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5145 def update!(**args) @failure_start_time = args[:failure_start_time] if args.key?(:failure_start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |