Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfigStatus
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfigStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
The status of the connector config.
Instance Attribute Summary collapse
-
#failure_start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ConnectorConfigStatus
constructor
A new instance of GoogleChromeManagementVersionsV1ConnectorConfigStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ConnectorConfigStatus
Returns a new instance of GoogleChromeManagementVersionsV1ConnectorConfigStatus.
5121 5122 5123 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_start_time ⇒ String
Output only. Field recording time of the earliest failure since the last
success event. This field is only set when the state is DISABLED_BY_FAILURES.
Corresponds to the JSON property failureStartTime
5104 5105 5106 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5104 def failure_start_time @failure_start_time end |
#state ⇒ String
Output only. The state of the connector config. The connector state is
disabled if the connector has not successfully sent an event in the last 24
hours.
Corresponds to the JSON property state
5111 5112 5113 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5111 def state @state end |
#update_time ⇒ String
Output only. Field recording time of most recent modification of the status.
For ENABLED, this is the time the status was changed to ENABLED. For
DISABLED_BY_FAILURES, this is the time of the most recent failed attempt to
send an event to this config.
Corresponds to the JSON property updateTime
5119 5120 5121 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5119 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5126 5127 5128 5129 5130 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5126 def update!(**args) @failure_start_time = args[:failure_start_time] if args.key?(:failure_start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |