Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfigStatus
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfigStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
The status of the connector config.
Instance Attribute Summary collapse
-
#failure_start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ConnectorConfigStatus
constructor
A new instance of GoogleChromeManagementVersionsV1ConnectorConfigStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ConnectorConfigStatus
Returns a new instance of GoogleChromeManagementVersionsV1ConnectorConfigStatus.
5045 5046 5047 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failure_start_time ⇒ String
Output only. Field recording time of the earliest failure since the last
success event. This field is only set when the state is DISABLED_BY_FAILURES.
Corresponds to the JSON property failureStartTime
5028 5029 5030 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5028 def failure_start_time @failure_start_time end |
#state ⇒ String
Output only. The state of the connector config. The connector state is
disabled if the connector has not successfully sent an event in the last 24
hours.
Corresponds to the JSON property state
5035 5036 5037 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5035 def state @state end |
#update_time ⇒ String
Output only. Field recording time of most recent modification of the status.
For ENABLED, this is the time the status was changed to ENABLED. For
DISABLED_BY_FAILURES, this is the time of the most recent failed attempt to
send an event to this config.
Corresponds to the JSON property updateTime
5043 5044 5045 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5043 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5050 5051 5052 5053 5054 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5050 def update!(**args) @failure_start_time = args[:failure_start_time] if args.key?(:failure_start_time) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |