Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Information of a device that runs a Chrome browser profile.
Instance Attribute Summary collapse
-
#affiliated_device_id ⇒ String
Output only.
-
#device_type ⇒ String
Output only.
-
#hostname ⇒ String
Output only.
-
#machine ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceInfo
constructor
A new instance of GoogleChromeManagementVersionsV1DeviceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceInfo
Returns a new instance of GoogleChromeManagementVersionsV1DeviceInfo.
5374 5375 5376 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5374 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affiliated_device_id ⇒ String
Output only. Device ID that identifies the affiliated device on which the
profile exists. If the device type is CHROME_BROWSER, then this represents a
unique Directory API ID of the device that can be used in Admin SDK Browsers
API.
Corresponds to the JSON property affiliatedDeviceId
5354 5355 5356 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5354 def affiliated_device_id @affiliated_device_id end |
#device_type ⇒ String
Output only. Type of the device on which the profile exists.
Corresponds to the JSON property deviceType
5359 5360 5361 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5359 def device_type @device_type end |
#hostname ⇒ String
Output only. Hostname of the device on which the profile exists.
Corresponds to the JSON property hostname
5364 5365 5366 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5364 def hostname @hostname end |
#machine ⇒ String
Output only. Machine name of the device on which the profile exists. On
platforms which do not report the machine name (currently iOS and Android)
this is instead set to the browser's device_id - but note that this is a
different device_id than the |affiliated_device_id|.
Corresponds to the JSON property machine
5372 5373 5374 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5372 def machine @machine end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5379 5380 5381 5382 5383 5384 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5379 def update!(**args) @affiliated_device_id = args[:affiliated_device_id] if args.key?(:affiliated_device_id) @device_type = args[:device_type] if args.key?(:device_type) @hostname = args[:hostname] if args.key?(:hostname) @machine = args[:machine] if args.key?(:machine) end |