Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Information of a device that runs a Chrome browser profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceInfo

Returns a new instance of GoogleChromeManagementVersionsV1DeviceInfo.



5275
5276
5277
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliated_device_idString

Output only. Device ID that identifies the affiliated device on which the profile exists. If the device type is CHROME_BROWSER, then this represents a unique Directory API ID of the device that can be used in Admin SDK Browsers API. Corresponds to the JSON property affiliatedDeviceId

Returns:

  • (String)


5255
5256
5257
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5255

def affiliated_device_id
  @affiliated_device_id
end

#device_typeString

Output only. Type of the device on which the profile exists. Corresponds to the JSON property deviceType

Returns:

  • (String)


5260
5261
5262
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5260

def device_type
  @device_type
end

#hostnameString

Output only. Hostname of the device on which the profile exists. Corresponds to the JSON property hostname

Returns:

  • (String)


5265
5266
5267
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5265

def hostname
  @hostname
end

#machineString

Output only. Machine name of the device on which the profile exists. On platforms which do not report the machine name (currently iOS and Android) this is instead set to the browser's device_id - but note that this is a different device_id than the |affiliated_device_id|. Corresponds to the JSON property machine

Returns:

  • (String)


5273
5274
5275
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5273

def machine
  @machine
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5280
5281
5282
5283
5284
5285
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5280

def update!(**args)
  @affiliated_device_id = args[:affiliated_device_id] if args.key?(:affiliated_device_id)
  @device_type = args[:device_type] if args.key?(:device_type)
  @hostname = args[:hostname] if args.key?(:hostname)
  @machine = args[:machine] if args.key?(:machine)
end