Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Information of a device that runs a Chrome browser profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceInfo

Returns a new instance of GoogleChromeManagementVersionsV1DeviceInfo.



5256
5257
5258
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliated_device_idString

Output only. Device ID that identifies the affiliated device on which the profile exists. If the device type is CHROME_BROWSER, then this represents a unique Directory API ID of the device that can be used in Admin SDK Browsers API. Corresponds to the JSON property affiliatedDeviceId

Returns:

  • (String)


5236
5237
5238
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5236

def affiliated_device_id
  @affiliated_device_id
end

#device_typeString

Output only. Type of the device on which the profile exists. Corresponds to the JSON property deviceType

Returns:

  • (String)


5241
5242
5243
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5241

def device_type
  @device_type
end

#hostnameString

Output only. Hostname of the device on which the profile exists. Corresponds to the JSON property hostname

Returns:

  • (String)


5246
5247
5248
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5246

def hostname
  @hostname
end

#machineString

Output only. Machine name of the device on which the profile exists. On platforms which do not report the machine name (currently iOS and Android) this is instead set to the browser's device_id - but note that this is a different device_id than the |affiliated_device_id|. Corresponds to the JSON property machine

Returns:

  • (String)


5254
5255
5256
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5254

def machine
  @machine
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5261
5262
5263
5264
5265
5266
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5261

def update!(**args)
  @affiliated_device_id = args[:affiliated_device_id] if args.key?(:affiliated_device_id)
  @device_type = args[:device_type] if args.key?(:device_type)
  @hostname = args[:hostname] if args.key?(:hostname)
  @machine = args[:machine] if args.key?(:machine)
end