Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Information of a device that runs a Chrome browser profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceInfo

Returns a new instance of GoogleChromeManagementVersionsV1DeviceInfo.



5180
5181
5182
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#affiliated_device_idString

Output only. Device ID that identifies the affiliated device on which the profile exists. If the device type is CHROME_BROWSER, then this represents a unique Directory API ID of the device that can be used in Admin SDK Browsers API. Corresponds to the JSON property affiliatedDeviceId

Returns:

  • (String)


5160
5161
5162
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5160

def affiliated_device_id
  @affiliated_device_id
end

#device_typeString

Output only. Type of the device on which the profile exists. Corresponds to the JSON property deviceType

Returns:

  • (String)


5165
5166
5167
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5165

def device_type
  @device_type
end

#hostnameString

Output only. Hostname of the device on which the profile exists. Corresponds to the JSON property hostname

Returns:

  • (String)


5170
5171
5172
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5170

def hostname
  @hostname
end

#machineString

Output only. Machine name of the device on which the profile exists. On platforms which do not report the machine name (currently iOS and Android) this is instead set to the browser's device_id - but note that this is a different device_id than the |affiliated_device_id|. Corresponds to the JSON property machine

Returns:

  • (String)


5178
5179
5180
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5178

def machine
  @machine
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5185
5186
5187
5188
5189
5190
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5185

def update!(**args)
  @affiliated_device_id = args[:affiliated_device_id] if args.key?(:affiliated_device_id)
  @device_type = args[:device_type] if args.key?(:device_type)
  @hostname = args[:hostname] if args.key?(:hostname)
  @machine = args[:machine] if args.key?(:machine)
end