Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceTrustConfig
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceTrustConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Device trust config for device trust connectors.
Instance Attribute Summary collapse
-
#scope ⇒ String
Required.
-
#service_accounts ⇒ Array<String>
Required.
-
#service_provider ⇒ String
Optional.
-
#url_matchers ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceTrustConfig
constructor
A new instance of GoogleChromeManagementVersionsV1DeviceTrustConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceTrustConfig
Returns a new instance of GoogleChromeManagementVersionsV1DeviceTrustConfig.
5318 5319 5320 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5318 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scope ⇒ String
Required. The scope at which this configuration will be applied. Note that
this only applies to Chrome browser, as in ChromeOS it's always applied.
Corresponds to the JSON property scope
5296 5297 5298 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5296 def scope @scope end |
#service_accounts ⇒ Array<String>
Required. A list of email addresses of the service accounts which are allowed
to call the Verified Access API with full access.
Corresponds to the JSON property serviceAccounts
5302 5303 5304 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5302 def service_accounts @service_accounts end |
#service_provider ⇒ String
Optional. The service provider for the device trust connector.
Corresponds to the JSON property serviceProvider
5307 5308 5309 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5307 def service_provider @service_provider end |
#url_matchers ⇒ Array<String>
Required. List of URLs allowed to be part of the attestation flow to get the
set of signals from the machine. URLs must have HTTPS scheme, e.g. "https://
example.com". Wildcards, *, are allowed. For detailed information on valid URL
patterns, please see https://cloud.google.com/docs/chrome-enterprise/policies/
url-patterns.
Corresponds to the JSON property urlMatchers
5316 5317 5318 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5316 def url_matchers @url_matchers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5323 5324 5325 5326 5327 5328 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5323 def update!(**args) @scope = args[:scope] if args.key?(:scope) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @service_provider = args[:service_provider] if args.key?(:service_provider) @url_matchers = args[:url_matchers] if args.key?(:url_matchers) end |