Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1DeviceTrustConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Device trust config for device trust connectors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1DeviceTrustConfig

Returns a new instance of GoogleChromeManagementVersionsV1DeviceTrustConfig.



5299
5300
5301
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scopeString

Required. The scope at which this configuration will be applied. Note that this only applies to Chrome browser, as in ChromeOS it's always applied. Corresponds to the JSON property scope

Returns:

  • (String)


5277
5278
5279
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5277

def scope
  @scope
end

#service_accountsArray<String>

Required. A list of email addresses of the service accounts which are allowed to call the Verified Access API with full access. Corresponds to the JSON property serviceAccounts

Returns:

  • (Array<String>)


5283
5284
5285
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5283

def service_accounts
  @service_accounts
end

#service_providerString

Optional. The service provider for the device trust connector. Corresponds to the JSON property serviceProvider

Returns:

  • (String)


5288
5289
5290
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5288

def service_provider
  @service_provider
end

#url_matchersArray<String>

Required. List of URLs allowed to be part of the attestation flow to get the set of signals from the machine. URLs must have HTTPS scheme, e.g. "https:// example.com". Wildcards, *, are allowed. For detailed information on valid URL patterns, please see https://cloud.google.com/docs/chrome-enterprise/policies/ url-patterns. Corresponds to the JSON property urlMatchers

Returns:

  • (Array<String>)


5297
5298
5299
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5297

def url_matchers
  @url_matchers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5304
5305
5306
5307
5308
5309
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5304

def update!(**args)
  @scope = args[:scope] if args.key?(:scope)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @service_provider = args[:service_provider] if args.key?(:service_provider)
  @url_matchers = args[:url_matchers] if args.key?(:url_matchers)
end