Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1EnableInsightsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Request to enable insights for the customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1EnableInsightsRequest

Returns a new instance of GoogleChromeManagementVersionsV1EnableInsightsRequest.



5375
5376
5377
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_ousArray<String>

Optional. The Organizational Units to set up required connectors for. Organizational Units are provided as paths relative to root. If this field is not set, connectors will be set up at root OU (as if it were set to ["/"]). Example: ["/corp/sales", "/eng"] Corresponds to the JSON property targetOus

Returns:

  • (Array<String>)


5373
5374
5375
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5373

def target_ous
  @target_ous
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5380
5381
5382
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5380

def update!(**args)
  @target_ous = args[:target_ous] if args.key?(:target_ous)
end