Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListChromeBrowserProfileCommandsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response to ListChromeBrowserProfileCommands method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListChromeBrowserProfileCommandsResponse

Returns a new instance of GoogleChromeManagementVersionsV1ListChromeBrowserProfileCommandsResponse.



5328
5329
5330
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chrome_browser_profile_commandsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ChromeBrowserProfileCommand>

The list of commands returned. Corresponds to the JSON property chromeBrowserProfileCommands



5316
5317
5318
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5316

def chrome_browser_profile_commands
  @chrome_browser_profile_commands
end

#next_page_tokenString

The pagination token that can be used to list the next page. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5321
5322
5323
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5321

def next_page_token
  @next_page_token
end

#total_sizeFixnum

Total size represents an estimated number of resources returned. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


5326
5327
5328
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5326

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5333
5334
5335
5336
5337
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5333

def update!(**args)
  @chrome_browser_profile_commands = args[:chrome_browser_profile_commands] if args.key?(:chrome_browser_profile_commands)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
end