Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListConnectorConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListConnectorConfigsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Response to ListConnectorConfigs method.
Instance Attribute Summary collapse
-
#connector_configs ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfig>
The list of connector configs returned.
-
#next_page_token ⇒ String
The page token used to retrieve the next page of the listing request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListConnectorConfigsResponse
constructor
A new instance of GoogleChromeManagementVersionsV1ListConnectorConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListConnectorConfigsResponse
Returns a new instance of GoogleChromeManagementVersionsV1ListConnectorConfigsResponse.
5463 5464 5465 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connector_configs ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfig>
The list of connector configs returned.
Corresponds to the JSON property connectorConfigs
5455 5456 5457 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5455 def connector_configs @connector_configs end |
#next_page_token ⇒ String
The page token used to retrieve the next page of the listing request. If the
token is empty, there are no more pages to retrieve.
Corresponds to the JSON property nextPageToken
5461 5462 5463 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5461 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5468 5469 5470 5471 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5468 def update!(**args) @connector_configs = args[:connector_configs] if args.key?(:connector_configs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |