Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ListConnectorConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Response to ListConnectorConfigs method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ListConnectorConfigsResponse

Returns a new instance of GoogleChromeManagementVersionsV1ListConnectorConfigsResponse.



5387
5388
5389
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_configsArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ConnectorConfig>

The list of connector configs returned. Corresponds to the JSON property connectorConfigs



5379
5380
5381
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5379

def connector_configs
  @connector_configs
end

#next_page_tokenString

The page token used to retrieve the next page of the listing request. If the token is empty, there are no more pages to retrieve. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5385
5386
5387
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5385

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5392
5393
5394
5395
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5392

def update!(**args)
  @connector_configs = args[:connector_configs] if args.key?(:connector_configs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end