Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Reporting data of a Chrome browser profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ReportingData

Returns a new instance of GoogleChromeManagementVersionsV1ReportingData.



5659
5660
5661
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#browser_executable_pathString

Output only. Executable path of the installed Chrome browser. A valid path is included only in affiliated profiles. Corresponds to the JSON property browserExecutablePath

Returns:

  • (String)


5630
5631
5632
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5630

def browser_executable_path
  @browser_executable_path
end

#extension_dataArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingDataExtensionData>

Output only. Information of the extensions installed on the profile. Corresponds to the JSON property extensionData



5635
5636
5637
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5635

def extension_data
  @extension_data
end

#extension_policy_dataArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingDataExtensionPolicyData>

Output only. Information of the policies applied on the extensions. Corresponds to the JSON property extensionPolicyData



5640
5641
5642
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5640

def extension_policy_data
  @extension_policy_data
end

#installed_browser_versionString

Output only. Updated version of a browser, if it is different from the active browser version. Corresponds to the JSON property installedBrowserVersion

Returns:

  • (String)


5646
5647
5648
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5646

def installed_browser_version
  @installed_browser_version
end

#policy_dataArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingDataPolicyData>

Output only. Information of the policies applied on the profile. Corresponds to the JSON property policyData



5651
5652
5653
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5651

def policy_data
  @policy_data
end

#profile_pathString

Output only. Path of the profile. A valid path is included only in affiliated profiles. Corresponds to the JSON property profilePath

Returns:

  • (String)


5657
5658
5659
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5657

def profile_path
  @profile_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5664
5665
5666
5667
5668
5669
5670
5671
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5664

def update!(**args)
  @browser_executable_path = args[:browser_executable_path] if args.key?(:browser_executable_path)
  @extension_data = args[:extension_data] if args.key?(:extension_data)
  @extension_policy_data = args[:extension_policy_data] if args.key?(:extension_policy_data)
  @installed_browser_version = args[:installed_browser_version] if args.key?(:installed_browser_version)
  @policy_data = args[:policy_data] if args.key?(:policy_data)
  @profile_path = args[:profile_path] if args.key?(:profile_path)
end