Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Reporting settings for connector configs.
Instance Attribute Summary collapse
-
#enabled_default_events ⇒ Array<String>
Optional.
-
#enabled_device_events ⇒ Array<String>
Optional.
-
#enabled_opt_in_events ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ReportingSettings
constructor
A new instance of GoogleChromeManagementVersionsV1ReportingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ReportingSettings
Returns a new instance of GoogleChromeManagementVersionsV1ReportingSettings.
5770 5771 5772 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5770 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled_default_events ⇒ Array<String>
Optional. The list of user and browser events that are enabled for this
connector. An empty list disables all default events, and using
ALL_DEFAULT_EVENTS will enable all default events.
Corresponds to the JSON property enabledDefaultEvents
5754 5755 5756 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5754 def enabled_default_events @enabled_default_events end |
#enabled_device_events ⇒ Array<String>
Optional. The list of device events that are enabled for this config. An empty
list disables all device events, and using ALL_DEVICE_EVENTS will enable all
device events.
Corresponds to the JSON property enabledDeviceEvents
5761 5762 5763 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5761 def enabled_device_events @enabled_device_events end |
#enabled_opt_in_events ⇒ Array<String>
Optional. The list of opt-in events that are enabled for this config. An empty
list disables all opt-in events, and using ALL_OPT_IN_EVENTS will enable all
opt-in events.
Corresponds to the JSON property enabledOptInEvents
5768 5769 5770 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5768 def enabled_opt_in_events @enabled_opt_in_events end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5775 5776 5777 5778 5779 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5775 def update!(**args) @enabled_default_events = args[:enabled_default_events] if args.key?(:enabled_default_events) @enabled_device_events = args[:enabled_device_events] if args.key?(:enabled_device_events) @enabled_opt_in_events = args[:enabled_opt_in_events] if args.key?(:enabled_opt_in_events) end |