Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Describes a SCEP certificate provisioning profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ScepProfile

Returns a new instance of GoogleChromeManagementVersionsV1ScepProfile.



5956
5957
5958
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_template_nameString

Output only. The certificate template name as defined by the admin on their on- prem infrastructure. The Certificate Authority uses this name to identify the certificate template. Corresponds to the JSON property certificateTemplateName

Returns:

  • (String)


5914
5915
5916
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5914

def certificate_template_name
  @certificate_template_name
end

#countryString

Output only. The country of the subject. Corresponds to the JSON property country

Returns:

  • (String)


5919
5920
5921
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5919

def country
  @country
end

#key_usagesArray<String>

Output only. The allowed key usages for certificate's key. Corresponds to the JSON property keyUsages

Returns:

  • (Array<String>)


5924
5925
5926
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5924

def key_usages
  @key_usages
end

#localityString

Output only. The locality of the subject. Corresponds to the JSON property locality

Returns:

  • (String)


5929
5930
5931
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5929

def locality
  @locality
end

#organizationString

Output only. The name of the organization the subject belongs to. Corresponds to the JSON property organization

Returns:

  • (String)


5934
5935
5936
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5934

def organization
  @organization
end

#organizational_unitsArray<String>

Output only. The organizational units of the subject. Corresponds to the JSON property organizationalUnits

Returns:

  • (Array<String>)


5939
5940
5941
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5939

def organizational_units
  @organizational_units
end

#stateString

Output only. The state of the subject. Corresponds to the JSON property state

Returns:

  • (String)


5944
5945
5946
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5944

def state
  @state
end

#subject_alt_namesArray<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SubjectAltName>

Output only. The subject alternative names. Corresponds to the JSON property subjectAltNames



5949
5950
5951
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5949

def subject_alt_names
  @subject_alt_names
end

#subject_common_nameString

Output only. The common name of the subject. Corresponds to the JSON property subjectCommonName

Returns:

  • (String)


5954
5955
5956
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5954

def subject_common_name
  @subject_common_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5961
5962
5963
5964
5965
5966
5967
5968
5969
5970
5971
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5961

def update!(**args)
  @certificate_template_name = args[:certificate_template_name] if args.key?(:certificate_template_name)
  @country = args[:country] if args.key?(:country)
  @key_usages = args[:key_usages] if args.key?(:key_usages)
  @locality = args[:locality] if args.key?(:locality)
  @organization = args[:organization] if args.key?(:organization)
  @organizational_units = args[:organizational_units] if args.key?(:organizational_units)
  @state = args[:state] if args.key?(:state)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
  @subject_common_name = args[:subject_common_name] if args.key?(:subject_common_name)
end