Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ScepProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Describes a SCEP certificate provisioning profile.
Instance Attribute Summary collapse
-
#certificate_template_name ⇒ String
Output only.
-
#country ⇒ String
Output only.
-
#key_usages ⇒ Array<String>
Output only.
-
#locality ⇒ String
Output only.
-
#organization ⇒ String
Output only.
-
#organizational_units ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#subject_alt_names ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SubjectAltName>
Output only.
-
#subject_common_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ScepProfile
constructor
A new instance of GoogleChromeManagementVersionsV1ScepProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ScepProfile
Returns a new instance of GoogleChromeManagementVersionsV1ScepProfile.
5853 5854 5855 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_template_name ⇒ String
Output only. The certificate template name as defined by the admin on their on-
prem infrastructure. The Certificate Authority uses this name to identify the
certificate template.
Corresponds to the JSON property certificateTemplateName
5811 5812 5813 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5811 def certificate_template_name @certificate_template_name end |
#country ⇒ String
Output only. The country of the subject.
Corresponds to the JSON property country
5816 5817 5818 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5816 def country @country end |
#key_usages ⇒ Array<String>
Output only. The allowed key usages for certificate's key.
Corresponds to the JSON property keyUsages
5821 5822 5823 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5821 def key_usages @key_usages end |
#locality ⇒ String
Output only. The locality of the subject.
Corresponds to the JSON property locality
5826 5827 5828 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5826 def locality @locality end |
#organization ⇒ String
Output only. The name of the organization the subject belongs to.
Corresponds to the JSON property organization
5831 5832 5833 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5831 def organization @organization end |
#organizational_units ⇒ Array<String>
Output only. The organizational units of the subject.
Corresponds to the JSON property organizationalUnits
5836 5837 5838 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5836 def organizational_units @organizational_units end |
#state ⇒ String
Output only. The state of the subject.
Corresponds to the JSON property state
5841 5842 5843 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5841 def state @state end |
#subject_alt_names ⇒ Array<Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SubjectAltName>
Output only. The subject alternative names.
Corresponds to the JSON property subjectAltNames
5846 5847 5848 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5846 def subject_alt_names @subject_alt_names end |
#subject_common_name ⇒ String
Output only. The common name of the subject.
Corresponds to the JSON property subjectCommonName
5851 5852 5853 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5851 def subject_common_name @subject_common_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5858 5859 5860 5861 5862 5863 5864 5865 5866 5867 5868 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 5858 def update!(**args) @certificate_template_name = args[:certificate_template_name] if args.key?(:certificate_template_name) @country = args[:country] if args.key?(:country) @key_usages = args[:key_usages] if args.key?(:key_usages) @locality = args[:locality] if args.key?(:locality) @organization = args[:organization] if args.key?(:organization) @organizational_units = args[:organizational_units] if args.key?(:organizational_units) @state = args[:state] if args.key?(:state) @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names) @subject_common_name = args[:subject_common_name] if args.key?(:subject_common_name) end |