Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SignDataRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Request message for requesting a signature from the client that initated a certificate provisioning process.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SignDataRequest

Returns a new instance of GoogleChromeManagementVersionsV1SignDataRequest.



6136
6137
6138
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sign_dataString

Required. The data that the client was asked to sign. Corresponds to the JSON property signData NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


6128
6129
6130
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6128

def sign_data
  @sign_data
end

#signature_algorithmString

Required. The signature algorithm that the adapter expects the client and backend components to use when processing sign_data. Corresponds to the JSON property signatureAlgorithm

Returns:

  • (String)


6134
6135
6136
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6134

def signature_algorithm
  @signature_algorithm
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6141
6142
6143
6144
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6141

def update!(**args)
  @sign_data = args[:sign_data] if args.key?(:sign_data)
  @signature_algorithm = args[:signature_algorithm] if args.key?(:signature_algorithm)
end