Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SplunkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SplunkConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Splunk connector config.
Instance Attribute Summary collapse
-
#hec_token ⇒ String
Required.
-
#host ⇒ String
Required.
-
#port_number ⇒ Fixnum
Optional.
-
#reporting_settings ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings
Reporting settings for connector configs.
-
#source ⇒ String
Optional.
-
#unsecure_scheme ⇒ Boolean
(also: #unsecure_scheme?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SplunkConfig
constructor
A new instance of GoogleChromeManagementVersionsV1SplunkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SplunkConfig
Returns a new instance of GoogleChromeManagementVersionsV1SplunkConfig.
6393 6394 6395 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hec_token ⇒ String
Required. Input only. The data input's HTTP Event Collector token to use as an
Authorization header.
Corresponds to the JSON property hecToken
6364 6365 6366 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6364 def hec_token @hec_token end |
#host ⇒ String
Required. Host to identify the customer specific server to receive the events.
Corresponds to the JSON property host
6369 6370 6371 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6369 def host @host end |
#port_number ⇒ Fixnum
Optional. The port number to use. If not set, the default Splunk port is used.
Corresponds to the JSON property portNumber
6374 6375 6376 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6374 def port_number @port_number end |
#reporting_settings ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings
Reporting settings for connector configs.
Corresponds to the JSON property reportingSettings
6379 6380 6381 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6379 def reporting_settings @reporting_settings end |
#source ⇒ String
Optional. Optional source name to override the default one set in the Splunk
admin console.
Corresponds to the JSON property source
6385 6386 6387 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6385 def source @source end |
#unsecure_scheme ⇒ Boolean Also known as: unsecure_scheme?
Optional. Whether to use an unsecure HTTP scheme. Defaults to false (HTTPS).
Corresponds to the JSON property unsecureScheme
6390 6391 6392 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6390 def unsecure_scheme @unsecure_scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6398 6399 6400 6401 6402 6403 6404 6405 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6398 def update!(**args) @hec_token = args[:hec_token] if args.key?(:hec_token) @host = args[:host] if args.key?(:host) @port_number = args[:port_number] if args.key?(:port_number) @reporting_settings = args[:reporting_settings] if args.key?(:reporting_settings) @source = args[:source] if args.key?(:source) @unsecure_scheme = args[:unsecure_scheme] if args.key?(:unsecure_scheme) end |