Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SplunkConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb

Overview

Splunk connector config.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SplunkConfig

Returns a new instance of GoogleChromeManagementVersionsV1SplunkConfig.



6204
6205
6206
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6204

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hec_tokenString

Required. Input only. The data input's HTTP Event Collector token to use as an Authorization header. Corresponds to the JSON property hecToken

Returns:

  • (String)


6175
6176
6177
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6175

def hec_token
  @hec_token
end

#hostString

Required. Host to identify the customer specific server to receive the events. Corresponds to the JSON property host

Returns:

  • (String)


6180
6181
6182
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6180

def host
  @host
end

#port_numberFixnum

Optional. The port number to use. If not set, the default Splunk port is used. Corresponds to the JSON property portNumber

Returns:

  • (Fixnum)


6185
6186
6187
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6185

def port_number
  @port_number
end

#reporting_settingsGoogle::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings

Reporting settings for connector configs. Corresponds to the JSON property reportingSettings



6190
6191
6192
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6190

def reporting_settings
  @reporting_settings
end

#sourceString

Optional. Optional source name to override the default one set in the Splunk admin console. Corresponds to the JSON property source

Returns:

  • (String)


6196
6197
6198
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6196

def source
  @source
end

#unsecure_schemeBoolean Also known as: unsecure_scheme?

Optional. Whether to use an unsecure HTTP scheme. Defaults to false (HTTPS). Corresponds to the JSON property unsecureScheme

Returns:

  • (Boolean)


6201
6202
6203
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6201

def unsecure_scheme
  @unsecure_scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6209
6210
6211
6212
6213
6214
6215
6216
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6209

def update!(**args)
  @hec_token = args[:hec_token] if args.key?(:hec_token)
  @host = args[:host] if args.key?(:host)
  @port_number = args[:port_number] if args.key?(:port_number)
  @reporting_settings = args[:reporting_settings] if args.key?(:reporting_settings)
  @source = args[:source] if args.key?(:source)
  @unsecure_scheme = args[:unsecure_scheme] if args.key?(:unsecure_scheme)
end