Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SplunkConfig
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1SplunkConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
Splunk connector config.
Instance Attribute Summary collapse
-
#hec_token ⇒ String
Required.
-
#host ⇒ String
Required.
-
#port_number ⇒ Fixnum
Optional.
-
#reporting_settings ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings
Reporting settings for connector configs.
-
#source ⇒ String
Optional.
-
#unsecure_scheme ⇒ Boolean
(also: #unsecure_scheme?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SplunkConfig
constructor
A new instance of GoogleChromeManagementVersionsV1SplunkConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1SplunkConfig
Returns a new instance of GoogleChromeManagementVersionsV1SplunkConfig.
6112 6113 6114 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hec_token ⇒ String
Required. Input only. The data input's HTTP Event Collector token to use as an
Authorization header.
Corresponds to the JSON property hecToken
6083 6084 6085 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6083 def hec_token @hec_token end |
#host ⇒ String
Required. Host to identify the customer specific server to receive the events.
Corresponds to the JSON property host
6088 6089 6090 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6088 def host @host end |
#port_number ⇒ Fixnum
Optional. The port number to use. If not set, the default Splunk port is used.
Corresponds to the JSON property portNumber
6093 6094 6095 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6093 def port_number @port_number end |
#reporting_settings ⇒ Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ReportingSettings
Reporting settings for connector configs.
Corresponds to the JSON property reportingSettings
6098 6099 6100 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6098 def reporting_settings @reporting_settings end |
#source ⇒ String
Optional. Optional source name to override the default one set in the Splunk
admin console.
Corresponds to the JSON property source
6104 6105 6106 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6104 def source @source end |
#unsecure_scheme ⇒ Boolean Also known as: unsecure_scheme?
Optional. Whether to use an unsecure HTTP scheme. Defaults to false (HTTPS).
Corresponds to the JSON property unsecureScheme
6109 6110 6111 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6109 def unsecure_scheme @unsecure_scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6117 6118 6119 6120 6121 6122 6123 6124 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6117 def update!(**args) @hec_token = args[:hec_token] if args.key?(:hec_token) @host = args[:host] if args.key?(:host) @port_number = args[:port_number] if args.key?(:port_number) @reporting_settings = args[:reporting_settings] if args.key?(:reporting_settings) @source = args[:source] if args.key?(:source) @unsecure_scheme = args[:unsecure_scheme] if args.key?(:unsecure_scheme) end |