Class: Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ThirdPartyProfileUser
- Inherits:
-
Object
- Object
- Google::Apis::ChromemanagementV1::GoogleChromeManagementVersionsV1ThirdPartyProfileUser
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/chromemanagement_v1/classes.rb,
lib/google/apis/chromemanagement_v1/representations.rb,
lib/google/apis/chromemanagement_v1/representations.rb
Overview
A representation of non-Google (third party) user that is associated with a managed Chrome profile.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#org_unit_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ThirdPartyProfileUser
constructor
A new instance of GoogleChromeManagementVersionsV1ThirdPartyProfileUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleChromeManagementVersionsV1ThirdPartyProfileUser
Returns a new instance of GoogleChromeManagementVersionsV1ThirdPartyProfileUser.
6066 6067 6068 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. Format: customers/customer_id/thirdPartyProfileUsers/
third_party_profile_user_id
Corresponds to the JSON property name
6059 6060 6061 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6059 def name @name end |
#org_unit_id ⇒ String
Output only. The ID of the organizational unit assigned to the user.
Corresponds to the JSON property orgUnitId
6064 6065 6066 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6064 def org_unit_id @org_unit_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6071 6072 6073 6074 |
# File 'lib/google/apis/chromemanagement_v1/classes.rb', line 6071 def update!(**args) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) end |